# Ads Data Hub v1 REST API Java Samples

These samples demonstrate basic usage of the Ads Data Hub v1 REST API.

The included com.google.adsdatahub.v1 package, in combination with the
google-api-java-client library, makes it easier to write Java clients to
programmatically access the Ads Data Hub v1 REST API. The complete documentation
for the Ads Data Hub API is available from
<https://developers.google.com/ads-data-hub/>.

## Prerequisites

-   [`Java 7+`](http://java.com)
-   [`Maven`](http://maven.apache.org)

## Before you start

These instructions assume you have already created a project in the
[Google Developers Console](https://console.developers.google.com/) to store
your query results in Big Query and have worked with the Ads Data Hub support
team to grant it access to the Ads Data Hub API. **If you have not done so
already, you should reach out to Ads Data Hub
[support](https://developers.google.com/ads-data-hub/support) to configure your
access to the API.**

## Setup

To run these samples, you'll need to do the following:

### Authorization Setup

The API uses OAuth2 for security, you can read about the options for connecting
at <https://developers.google.com/accounts/docs/OAuth2>

These samples use the (installed application
flow)[https://developers.google.com/identity/protocols/OAuth2InstalledApp], and
require that you generate a client ID, and download a JSON client secrets file
from the [Google Developers Console](https://console.developers.google.com).

If you haven't already created a client ID and downloaded a client secrets JSON
file for stepping through the OAuth 2.0 installed application flow, follow these
steps:

1.  Launch the
    [Google Developers Console](https://console.developers.google.com). From the
    drop-down menu, select your Big Query project. If you have not yet created
    the project, you can learn how to get started via the (Big Query
    Documentation)[https://cloud.google.com/bigquery/docs/projects].
1.  Click on the hamburger button on the top left corner of the page and click
    **APIs & services > Credentials**.
1.  If you have not done so already, create a new OAuth 2.0 client ID by
    clicking the **Create credentials** button and select **OAuth client ID**.
    For the **Application type** select **Other** and optionally enter a name to
    be associated with the client ID. Click **Create** to create the new Client
    ID and a dialog will appear to show you your client ID and secret. On the
    [Credentials page](https://console.developers.google.com/apis/credentials)
    for your project, find your new client ID listed under **OAuth 2.0 client
    IDs**, and click the corresponding download icon. The downloaded file will
    contain your credentials, which will be needed to step through the OAuth 2.0
    installed application flow.
1.  Open **AdsDataHubSample.java** and update the `CLIENT_SECRETS_FILE` field to
    represent the full path to the credentials file you downloaded in the
    previous step.
1.  When you run the samples for the first time, you will need to step through
    the installed application flow. Credentials will be saved locally so that
    you don't need to repeat this in every subsequent run.

### Setup the environment

#### Via the command line

1.  Execute the following command:

    ```shell
    $ mvn compile
    ```

#### Via Eclipse

1.  Setup Eclipse preferences:
    1.  Window > Preferences .. (or on Mac, Eclipse > Preferences)
    2.  Select Maven
    3.  Select "Download Artifact Sources"
    4.  Select "Download Artifact JavaDoc"
2.  Import the sample project
    1.  File > Import...
    2.  Select General > Existing Project into Workspace and click "Next"
    3.  Click "Browse" next to "Select root directory", find the sample
        directory and click "Next"
    4.  Click "Finish"

### Running the Examples

Once you've checked out the code:

1.  Run AdsDataHubSample.java

    1.  Via the command line, execute the following command:

        ```shell
        $ mvn -q exec:java
        ```

    2.  Via eclipse, right-click on the project and select Run As > Java
        Application

## Technical support

For technical questions and support relating to these samples or the API, please
contact our support alias: adh-api-support@google.com
