/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Represents an advertising data link.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AdsDataLink extends com.google.api.client.json.GenericJson {

  /**
   * Related child entities, if any. If the linked entity is a Google Ads customer that corresponds
   * to a customer-manager link, then child_entities will include a fully expanded set of Google Ads
   * customers with data imported into Ads Data Hub through this link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Entity> childEntities;

  static {
    // hack to force ProGuard to consider Entity used, since otherwise it would be stripped out
    // see https://github.com/google/google-api-java-client/issues/543
    com.google.api.client.util.Data.nullOf(Entity.class);
  }

  /**
   * Time the link was created.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String createTime;

  /**
   * Customer link through which the linked data can be accessed. Only name, customer ID, and
   * display_name are populated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private CustomerLink customerLink;

  /**
   * Types of data that will be exported for Display & Video 360 links. Only populated when platform
   * is GOOGLE_MARKETING_PLATFORM. If empty then unspecified and any combination of these may be
   * available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.lang.String> gmpExportScopes;

  /**
   * Entity linked through this AdsDataLink.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Entity linkedEntity;

  /**
   * Metrics accessible through this data link. If empty, no metric restrictions are applied. This
   * field is currently only singlar, and only supported when link entity type is
   * GOOGLE_ADS_CAMPAIGN or YT_RESERVE_LINE_ITEM.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.lang.String> metrics;

  /**
   * Name that uniquely identifies an AdsDataLink resource. It has the form
   * customers/[customer_id]/adsDataLinks/[resource_id]. The resource ID is generated by the server.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String name;

  /**
   * Related parent entity, if any. If the linked entity is a Google Ads campaign, this field will
   * contain a corresponding Google Ads customer to which the campaign belongs.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Entity parentEntity;

  /**
   * Advertising platform associated with the linked entity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String platform;

  /**
   * Status of the data link.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String status;

  /**
   * Time the link status was last updated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String updateTime;

  /**
   * Vendor client ID, if any.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String vendorClientId;

  /**
   * Related child entities, if any. If the linked entity is a Google Ads customer that corresponds
   * to a customer-manager link, then child_entities will include a fully expanded set of Google Ads
   * customers with data imported into Ads Data Hub through this link.
   * @return value or {@code null} for none
   */
  public java.util.List<Entity> getChildEntities() {
    return childEntities;
  }

  /**
   * Related child entities, if any. If the linked entity is a Google Ads customer that corresponds
   * to a customer-manager link, then child_entities will include a fully expanded set of Google Ads
   * customers with data imported into Ads Data Hub through this link.
   * @param childEntities childEntities or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setChildEntities(java.util.List<Entity> childEntities) {
    this.childEntities = childEntities;
    return this;
  }

  /**
   * Time the link was created.
   * @return value or {@code null} for none
   */
  public String getCreateTime() {
    return createTime;
  }

  /**
   * Time the link was created.
   * @param createTime createTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setCreateTime(String createTime) {
    this.createTime = createTime;
    return this;
  }

  /**
   * Customer link through which the linked data can be accessed. Only name, customer ID, and
   * display_name are populated.
   * @return value or {@code null} for none
   */
  public CustomerLink getCustomerLink() {
    return customerLink;
  }

  /**
   * Customer link through which the linked data can be accessed. Only name, customer ID, and
   * display_name are populated.
   * @param customerLink customerLink or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setCustomerLink(CustomerLink customerLink) {
    this.customerLink = customerLink;
    return this;
  }

  /**
   * Types of data that will be exported for Display & Video 360 links. Only populated when platform
   * is GOOGLE_MARKETING_PLATFORM. If empty then unspecified and any combination of these may be
   * available.
   * @return value or {@code null} for none
   */
  public java.util.List<java.lang.String> getGmpExportScopes() {
    return gmpExportScopes;
  }

  /**
   * Types of data that will be exported for Display & Video 360 links. Only populated when platform
   * is GOOGLE_MARKETING_PLATFORM. If empty then unspecified and any combination of these may be
   * available.
   * @param gmpExportScopes gmpExportScopes or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setGmpExportScopes(java.util.List<java.lang.String> gmpExportScopes) {
    this.gmpExportScopes = gmpExportScopes;
    return this;
  }

  /**
   * Entity linked through this AdsDataLink.
   * @return value or {@code null} for none
   */
  public Entity getLinkedEntity() {
    return linkedEntity;
  }

  /**
   * Entity linked through this AdsDataLink.
   * @param linkedEntity linkedEntity or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setLinkedEntity(Entity linkedEntity) {
    this.linkedEntity = linkedEntity;
    return this;
  }

  /**
   * Metrics accessible through this data link. If empty, no metric restrictions are applied. This
   * field is currently only singlar, and only supported when link entity type is
   * GOOGLE_ADS_CAMPAIGN or YT_RESERVE_LINE_ITEM.
   * @return value or {@code null} for none
   */
  public java.util.List<java.lang.String> getMetrics() {
    return metrics;
  }

  /**
   * Metrics accessible through this data link. If empty, no metric restrictions are applied. This
   * field is currently only singlar, and only supported when link entity type is
   * GOOGLE_ADS_CAMPAIGN or YT_RESERVE_LINE_ITEM.
   * @param metrics metrics or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setMetrics(java.util.List<java.lang.String> metrics) {
    this.metrics = metrics;
    return this;
  }

  /**
   * Name that uniquely identifies an AdsDataLink resource. It has the form
   * customers/[customer_id]/adsDataLinks/[resource_id]. The resource ID is generated by the server.
   * @return value or {@code null} for none
   */
  public java.lang.String getName() {
    return name;
  }

  /**
   * Name that uniquely identifies an AdsDataLink resource. It has the form
   * customers/[customer_id]/adsDataLinks/[resource_id]. The resource ID is generated by the server.
   * @param name name or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setName(java.lang.String name) {
    this.name = name;
    return this;
  }

  /**
   * Related parent entity, if any. If the linked entity is a Google Ads campaign, this field will
   * contain a corresponding Google Ads customer to which the campaign belongs.
   * @return value or {@code null} for none
   */
  public Entity getParentEntity() {
    return parentEntity;
  }

  /**
   * Related parent entity, if any. If the linked entity is a Google Ads campaign, this field will
   * contain a corresponding Google Ads customer to which the campaign belongs.
   * @param parentEntity parentEntity or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setParentEntity(Entity parentEntity) {
    this.parentEntity = parentEntity;
    return this;
  }

  /**
   * Advertising platform associated with the linked entity.
   * @return value or {@code null} for none
   */
  public java.lang.String getPlatform() {
    return platform;
  }

  /**
   * Advertising platform associated with the linked entity.
   * @param platform platform or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setPlatform(java.lang.String platform) {
    this.platform = platform;
    return this;
  }

  /**
   * Status of the data link.
   * @return value or {@code null} for none
   */
  public java.lang.String getStatus() {
    return status;
  }

  /**
   * Status of the data link.
   * @param status status or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setStatus(java.lang.String status) {
    this.status = status;
    return this;
  }

  /**
   * Time the link status was last updated.
   * @return value or {@code null} for none
   */
  public String getUpdateTime() {
    return updateTime;
  }

  /**
   * Time the link status was last updated.
   * @param updateTime updateTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setUpdateTime(String updateTime) {
    this.updateTime = updateTime;
    return this;
  }

  /**
   * Vendor client ID, if any.
   * @return value or {@code null} for none
   */
  public java.lang.String getVendorClientId() {
    return vendorClientId;
  }

  /**
   * Vendor client ID, if any.
   * @param vendorClientId vendorClientId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AdsDataLink setVendorClientId(java.lang.String vendorClientId) {
    this.vendorClientId = vendorClientId;
    return this;
  }

  @Override
  public AdsDataLink set(String fieldName, Object value) {
    return (AdsDataLink) super.set(fieldName, value);
  }

  @Override
  public AdsDataLink clone() {
    return (AdsDataLink) super.clone();
  }

}
