/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Defines an analysis query that can be executed within Ads Data Hub.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AnalysisQuery extends com.google.api.client.json.GenericJson {

  /**
   * Email address of user who created the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String createEmail;

  /**
   * Time the query was created.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String createTime;

  /**
   * Define how to combine rows dropped for privacy reasons into a single merged row. The merged row
   * will be included in the final output if the merged row meets privacy requirements.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private FilteredRowSummary filteredRowSummary;

  /**
   * If true, a filtered row summary is generated automatically.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.Boolean generateFilteredRowSummaryAutomatically;

  /**
   * Instructions for row merging. If present, then any rows that would have been dropped for
   * privacy reasons will be combined into a single merged row. The merged row will be in the final
   * output if the merged row meets privacy requirements.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private MergeSpec mergeSpec;

  /**
   * Name that uniquely identifies a query. It has the form
   * customers/[customer_id]/analysisQueries/[resource_id], e.g.
   * 'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String name;

  /**
   * Any additional parameters expected by the query. Maps each argument name to its argument type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, ParameterType> parameterTypes;

  /**
   * Indicates ways that a query may be shared beyond the owning Ads Data Hub customer.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<QueryShare> queryShare;

  /**
   * Query state.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String queryState;

  /**
   * Query text written in Standard SQL. See
   * https://cloud.google.com/bigquery/docs/reference/standard-sql/.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String queryText;

  /**
   * Query title, which is unique within a single Ads Data Hub customer and query type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String title;

  /**
   * Email address of user who last updated the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String updateEmail;

  /**
   * Time the query was last updated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String updateTime;

  /**
   * Email address of user who created the query.
   * @return value or {@code null} for none
   */
  public java.lang.String getCreateEmail() {
    return createEmail;
  }

  /**
   * Email address of user who created the query.
   * @param createEmail createEmail or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setCreateEmail(java.lang.String createEmail) {
    this.createEmail = createEmail;
    return this;
  }

  /**
   * Time the query was created.
   * @return value or {@code null} for none
   */
  public String getCreateTime() {
    return createTime;
  }

  /**
   * Time the query was created.
   * @param createTime createTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setCreateTime(String createTime) {
    this.createTime = createTime;
    return this;
  }

  /**
   * Define how to combine rows dropped for privacy reasons into a single merged row. The merged row
   * will be included in the final output if the merged row meets privacy requirements.
   * @return value or {@code null} for none
   */
  public FilteredRowSummary getFilteredRowSummary() {
    return filteredRowSummary;
  }

  /**
   * Define how to combine rows dropped for privacy reasons into a single merged row. The merged row
   * will be included in the final output if the merged row meets privacy requirements.
   * @param filteredRowSummary filteredRowSummary or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setFilteredRowSummary(FilteredRowSummary filteredRowSummary) {
    this.filteredRowSummary = filteredRowSummary;
    return this;
  }

  /**
   * If true, a filtered row summary is generated automatically.
   * @return value or {@code null} for none
   */
  public java.lang.Boolean getGenerateFilteredRowSummaryAutomatically() {
    return generateFilteredRowSummaryAutomatically;
  }

  /**
   * If true, a filtered row summary is generated automatically.
   * @param generateFilteredRowSummaryAutomatically generateFilteredRowSummaryAutomatically or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setGenerateFilteredRowSummaryAutomatically(java.lang.Boolean generateFilteredRowSummaryAutomatically) {
    this.generateFilteredRowSummaryAutomatically = generateFilteredRowSummaryAutomatically;
    return this;
  }

  /**
   * Instructions for row merging. If present, then any rows that would have been dropped for
   * privacy reasons will be combined into a single merged row. The merged row will be in the final
   * output if the merged row meets privacy requirements.
   * @return value or {@code null} for none
   */
  public MergeSpec getMergeSpec() {
    return mergeSpec;
  }

  /**
   * Instructions for row merging. If present, then any rows that would have been dropped for
   * privacy reasons will be combined into a single merged row. The merged row will be in the final
   * output if the merged row meets privacy requirements.
   * @param mergeSpec mergeSpec or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setMergeSpec(MergeSpec mergeSpec) {
    this.mergeSpec = mergeSpec;
    return this;
  }

  /**
   * Name that uniquely identifies a query. It has the form
   * customers/[customer_id]/analysisQueries/[resource_id], e.g.
   * 'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
   * @return value or {@code null} for none
   */
  public java.lang.String getName() {
    return name;
  }

  /**
   * Name that uniquely identifies a query. It has the form
   * customers/[customer_id]/analysisQueries/[resource_id], e.g.
   * 'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
   * @param name name or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setName(java.lang.String name) {
    this.name = name;
    return this;
  }

  /**
   * Any additional parameters expected by the query. Maps each argument name to its argument type.
   * @return value or {@code null} for none
   */
  public java.util.Map<String, ParameterType> getParameterTypes() {
    return parameterTypes;
  }

  /**
   * Any additional parameters expected by the query. Maps each argument name to its argument type.
   * @param parameterTypes parameterTypes or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setParameterTypes(java.util.Map<String, ParameterType> parameterTypes) {
    this.parameterTypes = parameterTypes;
    return this;
  }

  /**
   * Indicates ways that a query may be shared beyond the owning Ads Data Hub customer.
   * @return value or {@code null} for none
   */
  public java.util.List<QueryShare> getQueryShare() {
    return queryShare;
  }

  /**
   * Indicates ways that a query may be shared beyond the owning Ads Data Hub customer.
   * @param queryShare queryShare or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setQueryShare(java.util.List<QueryShare> queryShare) {
    this.queryShare = queryShare;
    return this;
  }

  /**
   * Query state.
   * @return value or {@code null} for none
   */
  public java.lang.String getQueryState() {
    return queryState;
  }

  /**
   * Query state.
   * @param queryState queryState or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setQueryState(java.lang.String queryState) {
    this.queryState = queryState;
    return this;
  }

  /**
   * Query text written in Standard SQL. See
   * https://cloud.google.com/bigquery/docs/reference/standard-sql/.
   * @return value or {@code null} for none
   */
  public java.lang.String getQueryText() {
    return queryText;
  }

  /**
   * Query text written in Standard SQL. See
   * https://cloud.google.com/bigquery/docs/reference/standard-sql/.
   * @param queryText queryText or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setQueryText(java.lang.String queryText) {
    this.queryText = queryText;
    return this;
  }

  /**
   * Query title, which is unique within a single Ads Data Hub customer and query type.
   * @return value or {@code null} for none
   */
  public java.lang.String getTitle() {
    return title;
  }

  /**
   * Query title, which is unique within a single Ads Data Hub customer and query type.
   * @param title title or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setTitle(java.lang.String title) {
    this.title = title;
    return this;
  }

  /**
   * Email address of user who last updated the query.
   * @return value or {@code null} for none
   */
  public java.lang.String getUpdateEmail() {
    return updateEmail;
  }

  /**
   * Email address of user who last updated the query.
   * @param updateEmail updateEmail or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setUpdateEmail(java.lang.String updateEmail) {
    this.updateEmail = updateEmail;
    return this;
  }

  /**
   * Time the query was last updated.
   * @return value or {@code null} for none
   */
  public String getUpdateTime() {
    return updateTime;
  }

  /**
   * Time the query was last updated.
   * @param updateTime updateTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public AnalysisQuery setUpdateTime(String updateTime) {
    this.updateTime = updateTime;
    return this;
  }

  @Override
  public AnalysisQuery set(String fieldName, Object value) {
    return (AnalysisQuery) super.set(fieldName, value);
  }

  @Override
  public AnalysisQuery clone() {
    return (AnalysisQuery) super.clone();
  }

}
