/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Defines an Ads Data Hub-managed custom bidding algorithm.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CustomBiddingAlgorithm extends com.google.api.client.json.GenericJson {

  /**
   * Immutable. Linked Ads Data Hub customer ID associated with this custom bidding algorithm. This
   * customer's data is used when running ScoreImpressionsForCustomBidding on this custom bidding
   * algorithm.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long adsDataCustomerId;

  /**
   * Output only. Email address of the user that created this custom bidding algorithm.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String createEmail;

  /**
   * Output only. Custom Bidding Algorithm ID. This field is generated by the service and is used in
   * DV360 to reference this algorithm when setting the bidding strategy.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long customBiddingAlgorithmId;

  /**
   * Required. Immutable. The Ads Data Hub custom bidding query resource that specifies how
   * impressions are scored for this custom bidding algorithm.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String customBiddingQuery;

  /**
   * Output only. If set, the time this custom bidding algorithm was deleted. If unset, this custom
   * bidding algortihm is active.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String deleteTime;

  /**
   * DV360 Advertiser IDs that can use this custom bidding algorithm.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.util.List<java.lang.Long> dv360AdvertiserId;

  /**
   * Immutable. DV360 Partner ID that this custom bidding algorithm is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long dv360PartnerId;

  /**
   * Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It has the
   * form customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String name;

  /**
   * Required. Custom Bidding Algorithm title, which is unique for the specified
   * ads_data_customer_id.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String title;

  /**
   * Immutable. Linked Ads Data Hub customer ID associated with this custom bidding algorithm. This
   * customer's data is used when running ScoreImpressionsForCustomBidding on this custom bidding
   * algorithm.
   * @return value or {@code null} for none
   */
  public java.lang.Long getAdsDataCustomerId() {
    return adsDataCustomerId;
  }

  /**
   * Immutable. Linked Ads Data Hub customer ID associated with this custom bidding algorithm. This
   * customer's data is used when running ScoreImpressionsForCustomBidding on this custom bidding
   * algorithm.
   * @param adsDataCustomerId adsDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
    this.adsDataCustomerId = adsDataCustomerId;
    return this;
  }

  /**
   * Output only. Email address of the user that created this custom bidding algorithm.
   * @return value or {@code null} for none
   */
  public java.lang.String getCreateEmail() {
    return createEmail;
  }

  /**
   * Output only. Email address of the user that created this custom bidding algorithm.
   * @param createEmail createEmail or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setCreateEmail(java.lang.String createEmail) {
    this.createEmail = createEmail;
    return this;
  }

  /**
   * Output only. Custom Bidding Algorithm ID. This field is generated by the service and is used in
   * DV360 to reference this algorithm when setting the bidding strategy.
   * @return value or {@code null} for none
   */
  public java.lang.Long getCustomBiddingAlgorithmId() {
    return customBiddingAlgorithmId;
  }

  /**
   * Output only. Custom Bidding Algorithm ID. This field is generated by the service and is used in
   * DV360 to reference this algorithm when setting the bidding strategy.
   * @param customBiddingAlgorithmId customBiddingAlgorithmId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setCustomBiddingAlgorithmId(java.lang.Long customBiddingAlgorithmId) {
    this.customBiddingAlgorithmId = customBiddingAlgorithmId;
    return this;
  }

  /**
   * Required. Immutable. The Ads Data Hub custom bidding query resource that specifies how
   * impressions are scored for this custom bidding algorithm.
   * @return value or {@code null} for none
   */
  public java.lang.String getCustomBiddingQuery() {
    return customBiddingQuery;
  }

  /**
   * Required. Immutable. The Ads Data Hub custom bidding query resource that specifies how
   * impressions are scored for this custom bidding algorithm.
   * @param customBiddingQuery customBiddingQuery or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setCustomBiddingQuery(java.lang.String customBiddingQuery) {
    this.customBiddingQuery = customBiddingQuery;
    return this;
  }

  /**
   * Output only. If set, the time this custom bidding algorithm was deleted. If unset, this custom
   * bidding algortihm is active.
   * @return value or {@code null} for none
   */
  public String getDeleteTime() {
    return deleteTime;
  }

  /**
   * Output only. If set, the time this custom bidding algorithm was deleted. If unset, this custom
   * bidding algortihm is active.
   * @param deleteTime deleteTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setDeleteTime(String deleteTime) {
    this.deleteTime = deleteTime;
    return this;
  }

  /**
   * DV360 Advertiser IDs that can use this custom bidding algorithm.
   * @return value or {@code null} for none
   */
  public java.util.List<java.lang.Long> getDv360AdvertiserId() {
    return dv360AdvertiserId;
  }

  /**
   * DV360 Advertiser IDs that can use this custom bidding algorithm.
   * @param dv360AdvertiserId dv360AdvertiserId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setDv360AdvertiserId(java.util.List<java.lang.Long> dv360AdvertiserId) {
    this.dv360AdvertiserId = dv360AdvertiserId;
    return this;
  }

  /**
   * Immutable. DV360 Partner ID that this custom bidding algorithm is for.
   * @return value or {@code null} for none
   */
  public java.lang.Long getDv360PartnerId() {
    return dv360PartnerId;
  }

  /**
   * Immutable. DV360 Partner ID that this custom bidding algorithm is for.
   * @param dv360PartnerId dv360PartnerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setDv360PartnerId(java.lang.Long dv360PartnerId) {
    this.dv360PartnerId = dv360PartnerId;
    return this;
  }

  /**
   * Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It has the
   * form customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
   * @return value or {@code null} for none
   */
  public java.lang.String getName() {
    return name;
  }

  /**
   * Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It has the
   * form customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
   * @param name name or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setName(java.lang.String name) {
    this.name = name;
    return this;
  }

  /**
   * Required. Custom Bidding Algorithm title, which is unique for the specified
   * ads_data_customer_id.
   * @return value or {@code null} for none
   */
  public java.lang.String getTitle() {
    return title;
  }

  /**
   * Required. Custom Bidding Algorithm title, which is unique for the specified
   * ads_data_customer_id.
   * @param title title or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public CustomBiddingAlgorithm setTitle(java.lang.String title) {
    this.title = title;
    return this;
  }

  @Override
  public CustomBiddingAlgorithm set(String fieldName, Object value) {
    return (CustomBiddingAlgorithm) super.set(fieldName, value);
  }

  @Override
  public CustomBiddingAlgorithm clone() {
    return (CustomBiddingAlgorithm) super.clone();
  }

}
