/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Defines the query execution parameters.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class QueryExecutionSpec extends com.google.api.client.json.GenericJson {

  /**
   * Optional. Linked Ads Data Hub customer ID that owns the ads data used in the query. If absent,
   * then the query will be run using the ads data owned by the Ads Data Hub customer running the
   * query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long adsDataCustomerId;

  /**
   * The end date (inclusive) for the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Date endDate;

  /**
   * Optional. Job ID for the query operation. The resulting operation will have the name
   * "operations/[job_id]", e.g. "operations/job_123". If an operation with the same job ID already
   * exists, this will result in an error. If absent, a job ID will be generated by the server.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String jobId;

  /**
   * Optional. Linked Ads Data Hub customer ID that owns the match data for the query. If absent,
   * then the query will be run using the match data owned by the Ads Data Hub customer ID running
   * the query, if applicable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long matchDataCustomerId;

  /**
   * Any additional parameters expected by the query. Maps each parameter name to its bound value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, ParameterValue> parameterValues;

  static {
    // hack to force ProGuard to consider ParameterValue used, since otherwise it would be stripped out
    // see https://github.com/google/google-api-java-client/issues/543
    com.google.api.client.util.Data.nullOf(ParameterValue.class);
  }

  /**
   * The start date (inclusive) for the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Date startDate;

  /**
   * Optional. The time zone for the query start and end dates. If not specified, defaults to 'UTC'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String timeZone;

  /**
   * Optional. Linked Ads Data Hub customer ID that owns the ads data used in the query. If absent,
   * then the query will be run using the ads data owned by the Ads Data Hub customer running the
   * query.
   * @return value or {@code null} for none
   */
  public java.lang.Long getAdsDataCustomerId() {
    return adsDataCustomerId;
  }

  /**
   * Optional. Linked Ads Data Hub customer ID that owns the ads data used in the query. If absent,
   * then the query will be run using the ads data owned by the Ads Data Hub customer running the
   * query.
   * @param adsDataCustomerId adsDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
    this.adsDataCustomerId = adsDataCustomerId;
    return this;
  }

  /**
   * The end date (inclusive) for the query.
   * @return value or {@code null} for none
   */
  public Date getEndDate() {
    return endDate;
  }

  /**
   * The end date (inclusive) for the query.
   * @param endDate endDate or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setEndDate(Date endDate) {
    this.endDate = endDate;
    return this;
  }

  /**
   * Optional. Job ID for the query operation. The resulting operation will have the name
   * "operations/[job_id]", e.g. "operations/job_123". If an operation with the same job ID already
   * exists, this will result in an error. If absent, a job ID will be generated by the server.
   * @return value or {@code null} for none
   */
  public java.lang.String getJobId() {
    return jobId;
  }

  /**
   * Optional. Job ID for the query operation. The resulting operation will have the name
   * "operations/[job_id]", e.g. "operations/job_123". If an operation with the same job ID already
   * exists, this will result in an error. If absent, a job ID will be generated by the server.
   * @param jobId jobId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setJobId(java.lang.String jobId) {
    this.jobId = jobId;
    return this;
  }

  /**
   * Optional. Linked Ads Data Hub customer ID that owns the match data for the query. If absent,
   * then the query will be run using the match data owned by the Ads Data Hub customer ID running
   * the query, if applicable.
   * @return value or {@code null} for none
   */
  public java.lang.Long getMatchDataCustomerId() {
    return matchDataCustomerId;
  }

  /**
   * Optional. Linked Ads Data Hub customer ID that owns the match data for the query. If absent,
   * then the query will be run using the match data owned by the Ads Data Hub customer ID running
   * the query, if applicable.
   * @param matchDataCustomerId matchDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
    this.matchDataCustomerId = matchDataCustomerId;
    return this;
  }

  /**
   * Any additional parameters expected by the query. Maps each parameter name to its bound value.
   * @return value or {@code null} for none
   */
  public java.util.Map<String, ParameterValue> getParameterValues() {
    return parameterValues;
  }

  /**
   * Any additional parameters expected by the query. Maps each parameter name to its bound value.
   * @param parameterValues parameterValues or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setParameterValues(java.util.Map<String, ParameterValue> parameterValues) {
    this.parameterValues = parameterValues;
    return this;
  }

  /**
   * The start date (inclusive) for the query.
   * @return value or {@code null} for none
   */
  public Date getStartDate() {
    return startDate;
  }

  /**
   * The start date (inclusive) for the query.
   * @param startDate startDate or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setStartDate(Date startDate) {
    this.startDate = startDate;
    return this;
  }

  /**
   * Optional. The time zone for the query start and end dates. If not specified, defaults to 'UTC'.
   * @return value or {@code null} for none
   */
  public java.lang.String getTimeZone() {
    return timeZone;
  }

  /**
   * Optional. The time zone for the query start and end dates. If not specified, defaults to 'UTC'.
   * @param timeZone timeZone or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryExecutionSpec setTimeZone(java.lang.String timeZone) {
    this.timeZone = timeZone;
    return this;
  }

  @Override
  public QueryExecutionSpec set(String fieldName, Object value) {
    return (QueryExecutionSpec) super.set(fieldName, value);
  }

  @Override
  public QueryExecutionSpec clone() {
    return (QueryExecutionSpec) super.clone();
  }

}
