/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Metadata about a query execution job. This is stored in the metadata field of the
 * google.longrunning.Operation returned by a query execution request.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class QueryMetadata extends com.google.api.client.json.GenericJson {

  /**
   * Ads Data Hub customer ID used for ads data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long adsDataCustomerId;

  /**
   * The Ads Data Hub customer ID that executed the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long customerId;

  /**
   * Destination table for query results. Used for analysis queries.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String destTable;

  /**
   * Query execution end time.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String endTime;

  /**
   * Ads Data Hub customer ID used for match table data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long matchDataCustomerId;

  /**
   * Parameter values used in the query. Maps each argument name to its bound value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, ParameterValue> parameterValues;

  static {
    // hack to force ProGuard to consider ParameterValue used, since otherwise it would be stripped out
    // see https://github.com/google/google-api-java-client/issues/543
    com.google.api.client.util.Data.nullOf(ParameterValue.class);
  }

  /**
   * Name of the query resource that was executed, e.g. customers/123/analysisQueries/abcd1234 Only
   * present for stored query execution.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String queryResourceName;

  /**
   * Text of the query executed. Note that this field will only be set in the response of
   * google.longrunning.Operations.GetOperation call. It will be omitted in the response of
   * google.longrunning.Operations.ListOperations call or any other calls.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String queryText;

  /**
   * Title of the query executed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String queryTitle;

  /**
   * Query execution start time.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String startTime;

  /**
   * User list to populate with query results. Used for user list queries.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long userListId;

  /**
   * Ads Data Hub customer ID used for ads data.
   * @return value or {@code null} for none
   */
  public java.lang.Long getAdsDataCustomerId() {
    return adsDataCustomerId;
  }

  /**
   * Ads Data Hub customer ID used for ads data.
   * @param adsDataCustomerId adsDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
    this.adsDataCustomerId = adsDataCustomerId;
    return this;
  }

  /**
   * The Ads Data Hub customer ID that executed the query.
   * @return value or {@code null} for none
   */
  public java.lang.Long getCustomerId() {
    return customerId;
  }

  /**
   * The Ads Data Hub customer ID that executed the query.
   * @param customerId customerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setCustomerId(java.lang.Long customerId) {
    this.customerId = customerId;
    return this;
  }

  /**
   * Destination table for query results. Used for analysis queries.
   * @return value or {@code null} for none
   */
  public java.lang.String getDestTable() {
    return destTable;
  }

  /**
   * Destination table for query results. Used for analysis queries.
   * @param destTable destTable or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setDestTable(java.lang.String destTable) {
    this.destTable = destTable;
    return this;
  }

  /**
   * Query execution end time.
   * @return value or {@code null} for none
   */
  public String getEndTime() {
    return endTime;
  }

  /**
   * Query execution end time.
   * @param endTime endTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setEndTime(String endTime) {
    this.endTime = endTime;
    return this;
  }

  /**
   * Ads Data Hub customer ID used for match table data.
   * @return value or {@code null} for none
   */
  public java.lang.Long getMatchDataCustomerId() {
    return matchDataCustomerId;
  }

  /**
   * Ads Data Hub customer ID used for match table data.
   * @param matchDataCustomerId matchDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
    this.matchDataCustomerId = matchDataCustomerId;
    return this;
  }

  /**
   * Parameter values used in the query. Maps each argument name to its bound value.
   * @return value or {@code null} for none
   */
  public java.util.Map<String, ParameterValue> getParameterValues() {
    return parameterValues;
  }

  /**
   * Parameter values used in the query. Maps each argument name to its bound value.
   * @param parameterValues parameterValues or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setParameterValues(java.util.Map<String, ParameterValue> parameterValues) {
    this.parameterValues = parameterValues;
    return this;
  }

  /**
   * Name of the query resource that was executed, e.g. customers/123/analysisQueries/abcd1234 Only
   * present for stored query execution.
   * @return value or {@code null} for none
   */
  public java.lang.String getQueryResourceName() {
    return queryResourceName;
  }

  /**
   * Name of the query resource that was executed, e.g. customers/123/analysisQueries/abcd1234 Only
   * present for stored query execution.
   * @param queryResourceName queryResourceName or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setQueryResourceName(java.lang.String queryResourceName) {
    this.queryResourceName = queryResourceName;
    return this;
  }

  /**
   * Text of the query executed. Note that this field will only be set in the response of
   * google.longrunning.Operations.GetOperation call. It will be omitted in the response of
   * google.longrunning.Operations.ListOperations call or any other calls.
   * @return value or {@code null} for none
   */
  public java.lang.String getQueryText() {
    return queryText;
  }

  /**
   * Text of the query executed. Note that this field will only be set in the response of
   * google.longrunning.Operations.GetOperation call. It will be omitted in the response of
   * google.longrunning.Operations.ListOperations call or any other calls.
   * @param queryText queryText or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setQueryText(java.lang.String queryText) {
    this.queryText = queryText;
    return this;
  }

  /**
   * Title of the query executed.
   * @return value or {@code null} for none
   */
  public java.lang.String getQueryTitle() {
    return queryTitle;
  }

  /**
   * Title of the query executed.
   * @param queryTitle queryTitle or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setQueryTitle(java.lang.String queryTitle) {
    this.queryTitle = queryTitle;
    return this;
  }

  /**
   * Query execution start time.
   * @return value or {@code null} for none
   */
  public String getStartTime() {
    return startTime;
  }

  /**
   * Query execution start time.
   * @param startTime startTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setStartTime(String startTime) {
    this.startTime = startTime;
    return this;
  }

  /**
   * User list to populate with query results. Used for user list queries.
   * @return value or {@code null} for none
   */
  public java.lang.Long getUserListId() {
    return userListId;
  }

  /**
   * User list to populate with query results. Used for user list queries.
   * @param userListId userListId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public QueryMetadata setUserListId(java.lang.Long userListId) {
    this.userListId = userListId;
    return this;
  }

  @Override
  public QueryMetadata set(String fieldName, Object value) {
    return (QueryMetadata) super.set(fieldName, value);
  }

  @Override
  public QueryMetadata clone() {
    return (QueryMetadata) super.clone();
  }

}
