/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Defines a temp table created by an Ads Data Hub query. Temp tables are created using CREATE TABLE
 * temp_table AS (...) in an Ads Data Hub query. Temp tables remain active for 72 hours before
 * needing to be refreshed.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class TempTable extends com.google.api.client.json.GenericJson {

  /**
   * Linked Ads Data Hub customer ID used when executing the original temp table query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long adsDataCustomerId;

  /**
   * A list of table columns.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Column> columns;

  static {
    // hack to force ProGuard to consider Column used, since otherwise it would be stripped out
    // see https://github.com/google/google-api-java-client/issues/543
    com.google.api.client.util.Data.nullOf(Column.class);
  }

  /**
   * Timestamp when the temp table is created, in micros.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String createTime;

  /**
   * Linked Ads Data Hub customer ID used when executing the original temp table query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long matchDataCustomerId;

  /**
   * Name that uniquely identifies a table. It has the form
   * customers/[customer_id]/tempTables/[resource_id]. The resource ID is generated by the server.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String name;

  /**
   * Operation that created the temp table. It has the form operations/[jobId]
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String operation;

  /**
   * Type of query that created the table. Temp tables are only accessible to to queries of the same
   * type unless usable_query_types is set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String queryType;

  /**
   * Fully qualified table path, e.g. 'tmp.table'
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String tablePath;

  /**
   * Types of queries that can access this temp table. If empty, this temp table is only accessible
   * to queries of the same type as its query_type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.lang.String> usableQueryTypes;

  /**
   * Linked Ads Data Hub customer ID used when executing the original temp table query.
   * @return value or {@code null} for none
   */
  public java.lang.Long getAdsDataCustomerId() {
    return adsDataCustomerId;
  }

  /**
   * Linked Ads Data Hub customer ID used when executing the original temp table query.
   * @param adsDataCustomerId adsDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
    this.adsDataCustomerId = adsDataCustomerId;
    return this;
  }

  /**
   * A list of table columns.
   * @return value or {@code null} for none
   */
  public java.util.List<Column> getColumns() {
    return columns;
  }

  /**
   * A list of table columns.
   * @param columns columns or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setColumns(java.util.List<Column> columns) {
    this.columns = columns;
    return this;
  }

  /**
   * Timestamp when the temp table is created, in micros.
   * @return value or {@code null} for none
   */
  public String getCreateTime() {
    return createTime;
  }

  /**
   * Timestamp when the temp table is created, in micros.
   * @param createTime createTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setCreateTime(String createTime) {
    this.createTime = createTime;
    return this;
  }

  /**
   * Linked Ads Data Hub customer ID used when executing the original temp table query.
   * @return value or {@code null} for none
   */
  public java.lang.Long getMatchDataCustomerId() {
    return matchDataCustomerId;
  }

  /**
   * Linked Ads Data Hub customer ID used when executing the original temp table query.
   * @param matchDataCustomerId matchDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
    this.matchDataCustomerId = matchDataCustomerId;
    return this;
  }

  /**
   * Name that uniquely identifies a table. It has the form
   * customers/[customer_id]/tempTables/[resource_id]. The resource ID is generated by the server.
   * @return value or {@code null} for none
   */
  public java.lang.String getName() {
    return name;
  }

  /**
   * Name that uniquely identifies a table. It has the form
   * customers/[customer_id]/tempTables/[resource_id]. The resource ID is generated by the server.
   * @param name name or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setName(java.lang.String name) {
    this.name = name;
    return this;
  }

  /**
   * Operation that created the temp table. It has the form operations/[jobId]
   * @return value or {@code null} for none
   */
  public java.lang.String getOperation() {
    return operation;
  }

  /**
   * Operation that created the temp table. It has the form operations/[jobId]
   * @param operation operation or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setOperation(java.lang.String operation) {
    this.operation = operation;
    return this;
  }

  /**
   * Type of query that created the table. Temp tables are only accessible to to queries of the same
   * type unless usable_query_types is set.
   * @return value or {@code null} for none
   */
  public java.lang.String getQueryType() {
    return queryType;
  }

  /**
   * Type of query that created the table. Temp tables are only accessible to to queries of the same
   * type unless usable_query_types is set.
   * @param queryType queryType or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setQueryType(java.lang.String queryType) {
    this.queryType = queryType;
    return this;
  }

  /**
   * Fully qualified table path, e.g. 'tmp.table'
   * @return value or {@code null} for none
   */
  public java.lang.String getTablePath() {
    return tablePath;
  }

  /**
   * Fully qualified table path, e.g. 'tmp.table'
   * @param tablePath tablePath or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setTablePath(java.lang.String tablePath) {
    this.tablePath = tablePath;
    return this;
  }

  /**
   * Types of queries that can access this temp table. If empty, this temp table is only accessible
   * to queries of the same type as its query_type.
   * @return value or {@code null} for none
   */
  public java.util.List<java.lang.String> getUsableQueryTypes() {
    return usableQueryTypes;
  }

  /**
   * Types of queries that can access this temp table. If empty, this temp table is only accessible
   * to queries of the same type as its query_type.
   * @param usableQueryTypes usableQueryTypes or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public TempTable setUsableQueryTypes(java.util.List<java.lang.String> usableQueryTypes) {
    this.usableQueryTypes = usableQueryTypes;
    return this;
  }

  @Override
  public TempTable set(String fieldName, Object value) {
    return (TempTable) super.set(fieldName, value);
  }

  @Override
  public TempTable clone() {
    return (TempTable) super.clone();
  }

}
