/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Defines an Ads Data Hub-managed user list.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class UserList extends com.google.api.client.json.GenericJson {

  /**
   * Immutable. Linked Ads Data Hub customer ID associated with this user list. This ID must be
   * specified as the ads_data_customer_id when running UserListQuery jobs using this user list. If
   * absent, the parent customer will be used. This cannot be changed after the list is created.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long adsDataCustomerId;

  /**
   * Output only. Email address of the user that created this user list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String createEmail;

  /**
   * Required. User list description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String description;

  /**
   * User list for frequency capping.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private FrequencyBasedListInfo frequencyList;

  /**
   * Output only. The number of users on the user list. List size update may be delayed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long listSize;

  /**
   * Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
   * customers/[customer_id]/userLists/[user_list_id]
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String name;

  /**
   * Output only. Time the list was last populated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String populateTime;

  /**
   * AdsDataLinks to entities that this user list is shared with. Has the form of
   * customers/[customer_id]/adsDataLinks/[resource_id] Supported entities are: - Google Ads
   * Customer - DV360 Partner - DV360 Advertiser
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.lang.String> recipientAdsDataLinks;

  /**
   * Remarketing list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RemarketingListInfo remarketingList;

  /**
   * Output only. State of the user list (Active/Deleted). This value is Read Only and will
   * accessible on get/list requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String state;

  /**
   * Required. User list title, which is unique for the specified ads_data_customer_id.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String title;

  /**
   * Output only. UserList type values should be consistent with the user_list. This value is Read
   * Only and will accessible on get/list requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String type;

  /**
   * Output only. User list ID. This field is generated by the service and is used to populate the
   * UserList.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long userListId;

  /**
   * Immutable. Linked Ads Data Hub customer ID associated with this user list. This ID must be
   * specified as the ads_data_customer_id when running UserListQuery jobs using this user list. If
   * absent, the parent customer will be used. This cannot be changed after the list is created.
   * @return value or {@code null} for none
   */
  public java.lang.Long getAdsDataCustomerId() {
    return adsDataCustomerId;
  }

  /**
   * Immutable. Linked Ads Data Hub customer ID associated with this user list. This ID must be
   * specified as the ads_data_customer_id when running UserListQuery jobs using this user list. If
   * absent, the parent customer will be used. This cannot be changed after the list is created.
   * @param adsDataCustomerId adsDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
    this.adsDataCustomerId = adsDataCustomerId;
    return this;
  }

  /**
   * Output only. Email address of the user that created this user list.
   * @return value or {@code null} for none
   */
  public java.lang.String getCreateEmail() {
    return createEmail;
  }

  /**
   * Output only. Email address of the user that created this user list.
   * @param createEmail createEmail or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setCreateEmail(java.lang.String createEmail) {
    this.createEmail = createEmail;
    return this;
  }

  /**
   * Required. User list description.
   * @return value or {@code null} for none
   */
  public java.lang.String getDescription() {
    return description;
  }

  /**
   * Required. User list description.
   * @param description description or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setDescription(java.lang.String description) {
    this.description = description;
    return this;
  }

  /**
   * User list for frequency capping.
   * @return value or {@code null} for none
   */
  public FrequencyBasedListInfo getFrequencyList() {
    return frequencyList;
  }

  /**
   * User list for frequency capping.
   * @param frequencyList frequencyList or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setFrequencyList(FrequencyBasedListInfo frequencyList) {
    this.frequencyList = frequencyList;
    return this;
  }

  /**
   * Output only. The number of users on the user list. List size update may be delayed.
   * @return value or {@code null} for none
   */
  public java.lang.Long getListSize() {
    return listSize;
  }

  /**
   * Output only. The number of users on the user list. List size update may be delayed.
   * @param listSize listSize or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setListSize(java.lang.Long listSize) {
    this.listSize = listSize;
    return this;
  }

  /**
   * Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
   * customers/[customer_id]/userLists/[user_list_id]
   * @return value or {@code null} for none
   */
  public java.lang.String getName() {
    return name;
  }

  /**
   * Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
   * customers/[customer_id]/userLists/[user_list_id]
   * @param name name or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setName(java.lang.String name) {
    this.name = name;
    return this;
  }

  /**
   * Output only. Time the list was last populated.
   * @return value or {@code null} for none
   */
  public String getPopulateTime() {
    return populateTime;
  }

  /**
   * Output only. Time the list was last populated.
   * @param populateTime populateTime or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setPopulateTime(String populateTime) {
    this.populateTime = populateTime;
    return this;
  }

  /**
   * AdsDataLinks to entities that this user list is shared with. Has the form of
   * customers/[customer_id]/adsDataLinks/[resource_id] Supported entities are: - Google Ads
   * Customer - DV360 Partner - DV360 Advertiser
   * @return value or {@code null} for none
   */
  public java.util.List<java.lang.String> getRecipientAdsDataLinks() {
    return recipientAdsDataLinks;
  }

  /**
   * AdsDataLinks to entities that this user list is shared with. Has the form of
   * customers/[customer_id]/adsDataLinks/[resource_id] Supported entities are: - Google Ads
   * Customer - DV360 Partner - DV360 Advertiser
   * @param recipientAdsDataLinks recipientAdsDataLinks or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setRecipientAdsDataLinks(java.util.List<java.lang.String> recipientAdsDataLinks) {
    this.recipientAdsDataLinks = recipientAdsDataLinks;
    return this;
  }

  /**
   * Remarketing list.
   * @return value or {@code null} for none
   */
  public RemarketingListInfo getRemarketingList() {
    return remarketingList;
  }

  /**
   * Remarketing list.
   * @param remarketingList remarketingList or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setRemarketingList(RemarketingListInfo remarketingList) {
    this.remarketingList = remarketingList;
    return this;
  }

  /**
   * Output only. State of the user list (Active/Deleted). This value is Read Only and will
   * accessible on get/list requests.
   * @return value or {@code null} for none
   */
  public java.lang.String getState() {
    return state;
  }

  /**
   * Output only. State of the user list (Active/Deleted). This value is Read Only and will
   * accessible on get/list requests.
   * @param state state or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setState(java.lang.String state) {
    this.state = state;
    return this;
  }

  /**
   * Required. User list title, which is unique for the specified ads_data_customer_id.
   * @return value or {@code null} for none
   */
  public java.lang.String getTitle() {
    return title;
  }

  /**
   * Required. User list title, which is unique for the specified ads_data_customer_id.
   * @param title title or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setTitle(java.lang.String title) {
    this.title = title;
    return this;
  }

  /**
   * Output only. UserList type values should be consistent with the user_list. This value is Read
   * Only and will accessible on get/list requests.
   * @return value or {@code null} for none
   */
  public java.lang.String getType() {
    return type;
  }

  /**
   * Output only. UserList type values should be consistent with the user_list. This value is Read
   * Only and will accessible on get/list requests.
   * @param type type or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setType(java.lang.String type) {
    this.type = type;
    return this;
  }

  /**
   * Output only. User list ID. This field is generated by the service and is used to populate the
   * UserList.
   * @return value or {@code null} for none
   */
  public java.lang.Long getUserListId() {
    return userListId;
  }

  /**
   * Output only. User list ID. This field is generated by the service and is used to populate the
   * UserList.
   * @param userListId userListId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public UserList setUserListId(java.lang.Long userListId) {
    this.userListId = userListId;
    return this;
  }

  @Override
  public UserList set(String fieldName, Object value) {
    return (UserList) super.set(fieldName, value);
  }

  @Override
  public UserList clone() {
    return (UserList) super.clone();
  }

}
