/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1.model;

/**
 * Request to validate an analysis query.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ads Data Hub API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ValidateAnalysisQueryRequest extends com.google.api.client.json.GenericJson {

  /**
   * Optional. Specific linked Ads Data Hub customer ID to use for validating ads data and temp
   * table access. Defaults to all the linked customers. Deprecated. Use the ads_data_customer_id
   * inside query_execution_spec.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long adsDataCustomerId;

  /**
   * Optional. If true, call BigQuery to dry run the query to collect some performance info. It may
   * take longer compared to only validating the query. The start_date, end_date and parameters
   * inside query_execution_spec need to be set for the dry run.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.Boolean includePerformanceInfo;

  /**
   * Optional. Specific linked Ads Data Hub customer ID to use for validating match data and temp
   * table access. Defaults to all the linked customers. Deprecated. Use the match_table_customer_id
   * inside query_execution_spec.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long matchDataCustomerId;

  /**
   * The query to validate.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private AnalysisQuery query;

  /**
   * Optional. The duplicated fields inside query_execution_spec will override the fields outside.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private QueryExecutionSpec spec;

  /**
   * Optional. Specific linked Ads Data Hub customer ID to use for validating ads data and temp
   * table access. Defaults to all the linked customers. Deprecated. Use the ads_data_customer_id
   * inside query_execution_spec.
   * @return value or {@code null} for none
   */
  public java.lang.Long getAdsDataCustomerId() {
    return adsDataCustomerId;
  }

  /**
   * Optional. Specific linked Ads Data Hub customer ID to use for validating ads data and temp
   * table access. Defaults to all the linked customers. Deprecated. Use the ads_data_customer_id
   * inside query_execution_spec.
   * @param adsDataCustomerId adsDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public ValidateAnalysisQueryRequest setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
    this.adsDataCustomerId = adsDataCustomerId;
    return this;
  }

  /**
   * Optional. If true, call BigQuery to dry run the query to collect some performance info. It may
   * take longer compared to only validating the query. The start_date, end_date and parameters
   * inside query_execution_spec need to be set for the dry run.
   * @return value or {@code null} for none
   */
  public java.lang.Boolean getIncludePerformanceInfo() {
    return includePerformanceInfo;
  }

  /**
   * Optional. If true, call BigQuery to dry run the query to collect some performance info. It may
   * take longer compared to only validating the query. The start_date, end_date and parameters
   * inside query_execution_spec need to be set for the dry run.
   * @param includePerformanceInfo includePerformanceInfo or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public ValidateAnalysisQueryRequest setIncludePerformanceInfo(java.lang.Boolean includePerformanceInfo) {
    this.includePerformanceInfo = includePerformanceInfo;
    return this;
  }

  /**
   * Optional. Specific linked Ads Data Hub customer ID to use for validating match data and temp
   * table access. Defaults to all the linked customers. Deprecated. Use the match_table_customer_id
   * inside query_execution_spec.
   * @return value or {@code null} for none
   */
  public java.lang.Long getMatchDataCustomerId() {
    return matchDataCustomerId;
  }

  /**
   * Optional. Specific linked Ads Data Hub customer ID to use for validating match data and temp
   * table access. Defaults to all the linked customers. Deprecated. Use the match_table_customer_id
   * inside query_execution_spec.
   * @param matchDataCustomerId matchDataCustomerId or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public ValidateAnalysisQueryRequest setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
    this.matchDataCustomerId = matchDataCustomerId;
    return this;
  }

  /**
   * The query to validate.
   * @return value or {@code null} for none
   */
  public AnalysisQuery getQuery() {
    return query;
  }

  /**
   * The query to validate.
   * @param query query or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public ValidateAnalysisQueryRequest setQuery(AnalysisQuery query) {
    this.query = query;
    return this;
  }

  /**
   * Optional. The duplicated fields inside query_execution_spec will override the fields outside.
   * @return value or {@code null} for none
   */
  public QueryExecutionSpec getSpec() {
    return spec;
  }

  /**
   * Optional. The duplicated fields inside query_execution_spec will override the fields outside.
   * @param spec spec or {@code null} for none
   */
  @com.google.errorprone.annotations.CanIgnoreReturnValue
  public ValidateAnalysisQueryRequest setSpec(QueryExecutionSpec spec) {
    this.spec = spec;
    return this;
  }

  @Override
  public ValidateAnalysisQueryRequest set(String fieldName, Object value) {
    return (ValidateAnalysisQueryRequest) super.set(fieldName, value);
  }

  @Override
  public ValidateAnalysisQueryRequest clone() {
    return (ValidateAnalysisQueryRequest) super.clone();
  }

}
