/*
 * Copyright (c) 2019 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.api.services.samples.adsdatahub.cmdline;

import com.google.api.services.adsdatahub.v1.AdsDataHub;
import com.google.api.services.adsdatahub.v1.model.AddRecipientsRequest;
import com.google.api.services.adsdatahub.v1.model.UserList;
import java.io.IOException;
import java.util.List;

/**
 * This sample illustrates how to add recipients to a user list.
 *
 * <p>See the <a
 * href="https://developers.google.com/ads-data-hub/reference/rest/v1/customers.userLists/addRecipients">
 * customers.userLists/addRecipients reference documentation</a> for more details.
 */
public class AddRecipientsToUserList extends BaseSample {

  @Override
  public String getName() {
    return "Add user list recipients";
  }

  @Override
  public String getDescription() {
    return "Adds recipients (linked customers in other systems) for a user list.";
  }

  @Override
  public void execute(AdsDataHub client) throws IOException {
    String name =
        getStringInput(
            "name",
            "Enter the fully qualified resource name of the existing"
                + " user list (Format: \"customers/[customer_id]/userLists/[user_list_id]\")");
    List<String> recipients =
        getStringListInput(
            "recipientAdsDataLinks",
            "Enter a comma separated list of fully qualified resource names for the AdsDataLinks"
                + " that represent customers in other systems that should have access to the user"
                + " list (Format: \"customers/[customer_id]/adsDataLinks/[resource_id]\")");

    UserList updatedUserList =
        client
            .customers()
            .userLists()
            .addRecipients(name, new AddRecipientsRequest().setRecipientAdsDataLinks(recipients))
            .execute();

    System.out.println("========================================");
    System.out.printf("Updated user list: \"%s\"%n", name);
    System.out.println("========================================");
    System.out.printf("Name: %s\n", updatedUserList.getName());
    System.out.printf("\tUser list ID: %s\n", updatedUserList.getUserListId());
    System.out.printf("\tUser list title: %s\n", updatedUserList.getTitle());
    System.out.printf("\tAds data customer ID: %s\n", updatedUserList.getAdsDataCustomerId());
    System.out.printf(
        "\tRecipient Ads Data Links: %s\n", updatedUserList.getRecipientAdsDataLinks());
  }
}
