/*
 * Copyright (c) 2019 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.api.services.samples.adsdatahub.cmdline;

import com.google.api.services.adsdatahub.v1.AdsDataHub;
import com.google.api.services.adsdatahub.v1.model.GenerateFrequencyListMembershipsRequest;
import com.google.api.services.adsdatahub.v1.model.Operation;
import com.google.api.services.adsdatahub.v1.model.Status;
import java.io.IOException;

/**
 * This sample illustrates how to generate frequency list memberships for a specified list.
 *
 * <p>See the <a href="customers.userLists.generateFrequencyListMemberships reference
 * documentation">https://developers.google.com/ads-data-hub/reference/rest/v1/customers.userLists/generateFrequencyListMemberships</a>
 * for more details.
 */
public class GenerateFrequencyListMemberships extends BaseSample {

  @Override
  public String getName() {
    return "Start generate frequency list memberships job";
  }

  @Override
  public String getDescription() {
    return "Starts a job to generate frequency list memberships.";
  }

  @Override
  public void execute(AdsDataHub client) throws IOException {

    String name =
        getStringInput(
            "userListName",
            "Enter the fully qualified resource name for the query to be run (Format:"
                + " \"customers/[customer_id]/userLists/[resource_id]\")");

    Operation operation =
        client
            .customers()
            .userLists()
            .generateFrequencyListMemberships(name, new GenerateFrequencyListMembershipsRequest())
            .execute();
    Boolean done = operation.getDone();

    System.out.println("========================================");
    System.out.printf("Generating members for frequency list with name \"%s\" via the following operation:%n", name);
    System.out.println("========================================");
    System.out.printf("Name: %s\n", operation.getName());
    System.out.printf("\tMetadata: %s\n", operation.getMetadata());
    System.out.printf("\tDone: %s\n", done != null ? done : false);

    if (done != null && done.equals(true)) {
      Status error = operation.getError();
      if (error != null) {
        System.out.printf("\tError: %s\n", error);
      }
    }
  }
}
