/*
 * Copyright (c) 2019 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.api.services.samples.adsdatahub.cmdline;

import com.google.api.services.adsdatahub.v1.AdsDataHub;
import com.google.api.services.adsdatahub.v1.model.AdsDataLink;
import com.google.api.services.adsdatahub.v1.model.ListAdsDataLinksResponse;
import java.io.IOException;
import java.util.List;

/**
 * This sample illustrates how to retrieve all user lists managed by the specified customer.
 *
 * <p>See the <a
 * href="https://developers.google.com/ads-data-hub/reference/rest/v1/customers.adsDataLinks/list">
 * customers.adsDataLinks/list reference documentation</a> for more details.
 */
public class ListAdsDataLinks extends BaseSample {

  @Override
  public String getName() {
    return "List ads data links";
  }

  @Override
  public String getDescription() {
    return "Lists ads data links for the specified customer.";
  }

  @Override
  public void execute(AdsDataHub client) throws IOException {
    Long customerId = getLongInput("customerId", "Enter the customer ID");
    String pageToken = null;
    boolean noData = true;

    System.out.println("========================================");
    System.out.printf("Listing of ads data links for customer: %s\n", customerId);
    System.out.println("========================================");

    do {
      ListAdsDataLinksResponse response =
          client
              .customers()
              .adsDataLinks()
              .list("customers/" + customerId)
              .setPageToken(pageToken)
              .execute();
      pageToken = response.getNextPageToken();
      List<AdsDataLink> adsDataLinks = response.getLinks();

      if (adsDataLinks != null && adsDataLinks.size() > 0) {
        noData = false;
        for (AdsDataLink adsDataLink : adsDataLinks) {
          System.out.printf("* Display Name: %s\n", adsDataLink.getLinkedEntity().getDisplayName());
          System.out.printf("\tAds Data Link resource name: %s\n", adsDataLink.getName());
          System.out.printf(
              "\tAds Data Link Entity Type: %s\n", adsDataLink.getLinkedEntity().getType());
          System.out.printf(
              "\tAds Data Link Entity Id: %s\n", adsDataLink.getLinkedEntity().getEntityId());
          System.out.printf("\tAds Data Link status: %s\n", adsDataLink.getStatus());
        }
      }
    } while (pageToken != null);

    if (noData) {
      System.out.println("No ads data links were found.");
    }
  }
}
