/*
 * Copyright (c) 2019 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.api.services.samples.adsdatahub.cmdline;

import com.google.api.services.adsdatahub.v1.AdsDataHub;
import com.google.api.services.adsdatahub.v1.AdsDataHub.Customers.UserListQueries.Patch;
import com.google.api.services.adsdatahub.v1.model.ParameterType;
import com.google.api.services.adsdatahub.v1.model.UserListQuery;
import com.google.common.collect.ImmutableMap;
import java.io.IOException;
import java.util.Map;

/**
 * This sample illustrates how to create a user list query for the specified customer.
 *
 * <p>See the <a href="customers.userListQueries.create reference
 * documentation">https://developers.google.com/ads-data-hub/reference/rest/v1/customers.userListQueries/create</a>
 * for more details.
 */
public class UpdateUserListQuery extends BaseSample {

  private static String QUERY_TEXT =
      "CREATE TABLE distinct_users AS (SELECT DISTINCT user_id FROM adh.google_ads_clicks_audience)";

  private static Map<String, ParameterType> PARAM_TYPES = ImmutableMap.of();

  @Override
  public String getName() {
    return "Update user list query";
  }

  @Override
  public String getDescription() {
    return "Updatess a user list query for the specified customer.";
  }

  @Override
  public void execute(AdsDataHub client) throws IOException {
    String name = getStringInput("name", "Enter the name of the existing query");
    String title = getStringInput("title", "Enter a new unique title for the query");

    UserListQuery query = new UserListQuery();
    query.setTitle(title);
    query.setQueryText(QUERY_TEXT);
    query.setParameterTypes(PARAM_TYPES);

    Patch request = client.customers().userListQueries().patch(name, query);
    UserListQuery updatedQuery = request.execute();

    System.out.println("========================================");
    System.out.printf("User list query updated with name: \"%s\"%n", name);
    System.out.println("========================================");
    System.out.printf("Name: %s\n", updatedQuery.getName());
    System.out.printf("\tQuery title: \n\"%s\"\n", updatedQuery.getTitle());
    System.out.printf("\tQuery text: \n\"%s\"\n", updatedQuery.getQueryText());
    System.out.printf("\tParameter types: %s\n\n", updatedQuery.getParameterTypes());
  }
}
