/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * Modify at your own risk.
 */

package com.google.api.services.adsdatahub.v1;

/**
 * Service definition for AdsDataHub (v1).
 *
 * <p>
 * API for executing Ads Data Hub queries.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/ads-data-hub/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link AdsDataHubRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class AdsDataHub extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        (com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION >= 15) ||
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION >= 2,
        "You are currently running with version %s of google-api-client. " +
        "You need at least version 1.15 of google-api-client to run version " +
        "1.25.0-SNAPSHOT of the Ads Data Hub API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://adsdatahub.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "";

  /**
   * The default encoded batch path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.23
   */
  public static final String DEFAULT_BATCH_PATH = "batch";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public AdsDataHub(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  AdsDataHub(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Customers collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
   *   {@code AdsDataHub.Customers.List request = adsdatahub.customers().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Customers customers() {
    return new Customers();
  }

  /**
   * The "customers" collection of methods.
   */
  public class Customers {

    /**
     * Describes the valid DV360 AdvertiserIds
     *
     * Create a request for the method "customers.describeValidDv360AdvertiserIds".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link DescribeValidDv360AdvertiserIds#execute()} method to invoke the
     * remote operation.
     *
     * @param customer Required. Customer resource name, e.g. 'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.DescribeValidDv360AdvertiserIdsRequest}
     * @return the request
     */
    public DescribeValidDv360AdvertiserIds describeValidDv360AdvertiserIds(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.DescribeValidDv360AdvertiserIdsRequest content) throws java.io.IOException {
      DescribeValidDv360AdvertiserIds result = new DescribeValidDv360AdvertiserIds(customer, content);
      initialize(result);
      return result;
    }

    public class DescribeValidDv360AdvertiserIds extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.DescribeValidDv360AdvertiserIdsResponse> {

      private static final String REST_PATH = "v1/{+customer}:describeValidDv360AdvertiserIds";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Describes the valid DV360 AdvertiserIds
       *
       * Create a request for the method "customers.describeValidDv360AdvertiserIds".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link DescribeValidDv360AdvertiserIds#execute()} method to
       * invoke the remote operation. <p> {@link DescribeValidDv360AdvertiserIds#initialize(com.google.a
       * pi.client.googleapis.services.AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param customer Required. Customer resource name, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.DescribeValidDv360AdvertiserIdsRequest}
       * @since 1.13
       */
      protected DescribeValidDv360AdvertiserIds(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.DescribeValidDv360AdvertiserIdsRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.DescribeValidDv360AdvertiserIdsResponse.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds set$Xgafv(java.lang.String $Xgafv) {
        return (DescribeValidDv360AdvertiserIds) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setAccessToken(java.lang.String accessToken) {
        return (DescribeValidDv360AdvertiserIds) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setAlt(java.lang.String alt) {
        return (DescribeValidDv360AdvertiserIds) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setCallback(java.lang.String callback) {
        return (DescribeValidDv360AdvertiserIds) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setFields(java.lang.String fields) {
        return (DescribeValidDv360AdvertiserIds) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setKey(java.lang.String key) {
        return (DescribeValidDv360AdvertiserIds) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setOauthToken(java.lang.String oauthToken) {
        return (DescribeValidDv360AdvertiserIds) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (DescribeValidDv360AdvertiserIds) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setQuotaUser(java.lang.String quotaUser) {
        return (DescribeValidDv360AdvertiserIds) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setUploadType(java.lang.String uploadType) {
        return (DescribeValidDv360AdvertiserIds) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds setUploadProtocol(java.lang.String uploadProtocol) {
        return (DescribeValidDv360AdvertiserIds) super.setUploadProtocol(uploadProtocol);
      }

      /** Required. Customer resource name, e.g. 'customers/123'. */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Required. Customer resource name, e.g. 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /** Required. Customer resource name, e.g. 'customers/123'. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public DescribeValidDv360AdvertiserIds setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidDv360AdvertiserIds set(String parameterName, Object value) {
        return (DescribeValidDv360AdvertiserIds) super.set(parameterName, value);
      }
    }
    /**
     * Lists valid event matchers along with their metadata for frequency capping audience lists. Each
     * event matcher has metadata that includes, for example, an owning AdsDataLink.Entity and a name
     * for the corresponding campaign or line item.
     *
     * Create a request for the method "customers.describeValidFrequencyLimitingEventMatchers".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link DescribeValidFrequencyLimitingEventMatchers#execute()} method to
     * invoke the remote operation.
     *
     * @param customer Customer resource name, e.g. 'customers/123'.
     * @return the request
     */
    public DescribeValidFrequencyLimitingEventMatchers describeValidFrequencyLimitingEventMatchers(java.lang.String customer) throws java.io.IOException {
      DescribeValidFrequencyLimitingEventMatchers result = new DescribeValidFrequencyLimitingEventMatchers(customer);
      initialize(result);
      return result;
    }

    public class DescribeValidFrequencyLimitingEventMatchers extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.DescribeValidFrequencyLimitingEventMatchersResponse> {

      private static final String REST_PATH = "v1/{+customer}:describeValidFrequencyLimitingEventMatchers";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Lists valid event matchers along with their metadata for frequency capping audience lists. Each
       * event matcher has metadata that includes, for example, an owning AdsDataLink.Entity and a name
       * for the corresponding campaign or line item.
       *
       * Create a request for the method "customers.describeValidFrequencyLimitingEventMatchers".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link DescribeValidFrequencyLimitingEventMatchers#execute()}
       * method to invoke the remote operation. <p> {@link DescribeValidFrequencyLimitingEventMatchers#i
       * nitialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customer Customer resource name, e.g. 'customers/123'.
       * @since 1.13
       */
      protected DescribeValidFrequencyLimitingEventMatchers(java.lang.String customer) {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.DescribeValidFrequencyLimitingEventMatchersResponse.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers set$Xgafv(java.lang.String $Xgafv) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setAccessToken(java.lang.String accessToken) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setAlt(java.lang.String alt) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setCallback(java.lang.String callback) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setFields(java.lang.String fields) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setKey(java.lang.String key) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setOauthToken(java.lang.String oauthToken) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setQuotaUser(java.lang.String quotaUser) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setUploadType(java.lang.String uploadType) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers setUploadProtocol(java.lang.String uploadProtocol) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.setUploadProtocol(uploadProtocol);
      }

      /** Customer resource name, e.g. 'customers/123'. */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Customer resource name, e.g. 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /** Customer resource name, e.g. 'customers/123'. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public DescribeValidFrequencyLimitingEventMatchers setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      /** Ads Data Owning customer's ID, e.g. 456. */
      @com.google.api.client.util.Key
      private java.lang.Long adsDataCustomerId;

      /** Ads Data Owning customer's ID, e.g. 456.
       */
      public java.lang.Long getAdsDataCustomerId() {
        return adsDataCustomerId;
      }

      /** Ads Data Owning customer's ID, e.g. 456. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public DescribeValidFrequencyLimitingEventMatchers setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
        this.adsDataCustomerId = adsDataCustomerId;
        return this;
      }

      /**
       * Maximum number of items to return. If 0, the server will determine the number of linked
       * customers to return.
       */
      @com.google.api.client.util.Key
      private java.lang.Integer pageSize;

      /** Maximum number of items to return. If 0, the server will determine the number of linked customers
     to return.
       */
      public java.lang.Integer getPageSize() {
        return pageSize;
      }

      /**
       * Maximum number of items to return. If 0, the server will determine the number of linked
       * customers to return.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public DescribeValidFrequencyLimitingEventMatchers setPageSize(java.lang.Integer pageSize) {
        this.pageSize = pageSize;
        return this;
      }

      /**
       * Page token, returned by a previous call, used to request the next page of results, if any.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** Page token, returned by a previous call, used to request the next page of results, if any.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * Page token, returned by a previous call, used to request the next page of results, if any.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public DescribeValidFrequencyLimitingEventMatchers setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
       * Restrict which event matchers are returned. Accepts filters on all the sub-fields of
       * event_matcher, event_matcher_metadata.entity, and
       * event_matcher_metadata.parent_event_matcher. Example filters: event_matcher.value = 1234
       * event_matcher.match_type = DV360_LINE_ITEM_ID OR event_matcher.match_type =
       * DV360_INSERTION_ORDER_ID event_matcher_metadata.display_name = "Campaign 456"
       * event_matcher_metadata.entity.entity_id = 5678 event_matcher_metadata.entity.display_name =
       * "Customer 123" event_matcher_metadata.entity.type = GMP_DV360_ADVERTISER
       * event_matcher_metadata.parent_event_matcher.value = 6789
       * event_matcher_metadata.parent_event_matcher.match_type = DV360_INSERTION_ORDER_ID
       */
      @com.google.api.client.util.Key
      private java.lang.String filter;

      /** Restrict which event matchers are returned. Accepts filters on all the sub-fields of event_matcher,
     event_matcher_metadata.entity, and event_matcher_metadata.parent_event_matcher. Example filters:
     event_matcher.value = 1234 event_matcher.match_type = DV360_LINE_ITEM_ID OR
     event_matcher.match_type = DV360_INSERTION_ORDER_ID event_matcher_metadata.display_name = "Campaign
     456" event_matcher_metadata.entity.entity_id = 5678 event_matcher_metadata.entity.display_name =
     "Customer 123" event_matcher_metadata.entity.type = GMP_DV360_ADVERTISER
     event_matcher_metadata.parent_event_matcher.value = 6789
     event_matcher_metadata.parent_event_matcher.match_type = DV360_INSERTION_ORDER_ID
       */
      public java.lang.String getFilter() {
        return filter;
      }

      /**
       * Restrict which event matchers are returned. Accepts filters on all the sub-fields of
       * event_matcher, event_matcher_metadata.entity, and
       * event_matcher_metadata.parent_event_matcher. Example filters: event_matcher.value = 1234
       * event_matcher.match_type = DV360_LINE_ITEM_ID OR event_matcher.match_type =
       * DV360_INSERTION_ORDER_ID event_matcher_metadata.display_name = "Campaign 456"
       * event_matcher_metadata.entity.entity_id = 5678 event_matcher_metadata.entity.display_name =
       * "Customer 123" event_matcher_metadata.entity.type = GMP_DV360_ADVERTISER
       * event_matcher_metadata.parent_event_matcher.value = 6789
       * event_matcher_metadata.parent_event_matcher.match_type = DV360_INSERTION_ORDER_ID
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public DescribeValidFrequencyLimitingEventMatchers setFilter(java.lang.String filter) {
        this.filter = filter;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public DescribeValidFrequencyLimitingEventMatchers set(String parameterName, Object value) {
        return (DescribeValidFrequencyLimitingEventMatchers) super.set(parameterName, value);
      }
    }
    /**
     * Exports job history of a customer account to customer-selected BigQuery dataset.
     *
     * Create a request for the method "customers.exportJobHistory".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link ExportJobHistory#execute()} method to invoke the remote operation.
     *
     * @param customer Required. ADH customer ID to fetch jobs for, with the format 'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.ExportJobHistoryRequest}
     * @return the request
     */
    public ExportJobHistory exportJobHistory(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.ExportJobHistoryRequest content) throws java.io.IOException {
      ExportJobHistory result = new ExportJobHistory(customer, content);
      initialize(result);
      return result;
    }

    public class ExportJobHistory extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+customer}:exportJobHistory";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Exports job history of a customer account to customer-selected BigQuery dataset.
       *
       * Create a request for the method "customers.exportJobHistory".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link ExportJobHistory#execute()} method to invoke the remote
       * operation. <p> {@link ExportJobHistory#initialize(com.google.api.client.googleapis.services.Abs
       * tractGoogleClientRequest)} must be called to initialize this instance immediately after
       * invoking the constructor. </p>
       *
       * @param customer Required. ADH customer ID to fetch jobs for, with the format 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.ExportJobHistoryRequest}
       * @since 1.13
       */
      protected ExportJobHistory(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.ExportJobHistoryRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory set$Xgafv(java.lang.String $Xgafv) {
        return (ExportJobHistory) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setAccessToken(java.lang.String accessToken) {
        return (ExportJobHistory) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setAlt(java.lang.String alt) {
        return (ExportJobHistory) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setCallback(java.lang.String callback) {
        return (ExportJobHistory) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setFields(java.lang.String fields) {
        return (ExportJobHistory) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setKey(java.lang.String key) {
        return (ExportJobHistory) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setOauthToken(java.lang.String oauthToken) {
        return (ExportJobHistory) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (ExportJobHistory) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setQuotaUser(java.lang.String quotaUser) {
        return (ExportJobHistory) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setUploadType(java.lang.String uploadType) {
        return (ExportJobHistory) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory setUploadProtocol(java.lang.String uploadProtocol) {
        return (ExportJobHistory) super.setUploadProtocol(uploadProtocol);
      }

      /** Required. ADH customer ID to fetch jobs for, with the format 'customers/123'. */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Required. ADH customer ID to fetch jobs for, with the format 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /** Required. ADH customer ID to fetch jobs for, with the format 'customers/123'. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public ExportJobHistory setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public ExportJobHistory set(String parameterName, Object value) {
        return (ExportJobHistory) super.set(parameterName, value);
      }
    }
    /**
     * Starts the execution of a query to retrieve invalid traffic viewability metrics for the DV360
     * platform. The results will be written to the specified BigQuery destination table. The returned
     * operation name can be used to poll for query completion status.
     *
     * Create a request for the method "customers.generateDv360IvtVideoViewabilityReport".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link GenerateDv360IvtVideoViewabilityReport#execute()} method to invoke
     * the remote operation.
     *
     * @param customer Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'. e.g.
     *        'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.GenerateDv360IvtVideoViewabilityReportRequest}
     * @return the request
     */
    public GenerateDv360IvtVideoViewabilityReport generateDv360IvtVideoViewabilityReport(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.GenerateDv360IvtVideoViewabilityReportRequest content) throws java.io.IOException {
      GenerateDv360IvtVideoViewabilityReport result = new GenerateDv360IvtVideoViewabilityReport(customer, content);
      initialize(result);
      return result;
    }

    public class GenerateDv360IvtVideoViewabilityReport extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+customer}:generateDv360IvtVideoViewabilityReport";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Starts the execution of a query to retrieve invalid traffic viewability metrics for the DV360
       * platform. The results will be written to the specified BigQuery destination table. The returned
       * operation name can be used to poll for query completion status.
       *
       * Create a request for the method "customers.generateDv360IvtVideoViewabilityReport".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link GenerateDv360IvtVideoViewabilityReport#execute()} method
       * to invoke the remote operation. <p> {@link GenerateDv360IvtVideoViewabilityReport#initialize(co
       * m.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be called to
       * initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customer Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'. e.g.
     *        'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.GenerateDv360IvtVideoViewabilityReportRequest}
       * @since 1.13
       */
      protected GenerateDv360IvtVideoViewabilityReport(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.GenerateDv360IvtVideoViewabilityReportRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport set$Xgafv(java.lang.String $Xgafv) {
        return (GenerateDv360IvtVideoViewabilityReport) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setAccessToken(java.lang.String accessToken) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setAlt(java.lang.String alt) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setCallback(java.lang.String callback) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setFields(java.lang.String fields) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setKey(java.lang.String key) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setOauthToken(java.lang.String oauthToken) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setQuotaUser(java.lang.String quotaUser) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setUploadType(java.lang.String uploadType) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport setUploadProtocol(java.lang.String uploadProtocol) {
        return (GenerateDv360IvtVideoViewabilityReport) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'.
       * e.g. 'customers/123'.
       */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'. e.g.
     'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /**
       * Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'.
       * e.g. 'customers/123'.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GenerateDv360IvtVideoViewabilityReport setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateDv360IvtVideoViewabilityReport set(String parameterName, Object value) {
        return (GenerateDv360IvtVideoViewabilityReport) super.set(parameterName, value);
      }
    }
    /**
     * Starts the execution of a query to retrieve a day-by-day summary of invalid traffic counts for a
     * specific platform. The results will be written to the specified BigQuery destination table. The
     * returned operation name can be used to poll for query completion status. The output table
     * contains 5 rows for each day in the date range. 1 row for each of the 4 device types, and 1 row
     * for all device types. The All row is the sum of the 4 device types for that day. As a result,
     * each column contains twice the total of the number of impressions. If ADH redacts rows due to
     * privacy constraints, the [filtered row summary](https://developers.google.com/ads-data-
     * hub/guides/filtered-row-summary) (the row with no day) will contain the sum of redacted rows.
     *
     * Create a request for the method "customers.generateIvtReport".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link GenerateIvtReport#execute()} method to invoke the remote operation.
     *
     * @param name Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'. e.g.
     *        'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.GenerateIvtReportRequest}
     * @return the request
     */
    public GenerateIvtReport generateIvtReport(java.lang.String name, com.google.api.services.adsdatahub.v1.model.GenerateIvtReportRequest content) throws java.io.IOException {
      GenerateIvtReport result = new GenerateIvtReport(name, content);
      initialize(result);
      return result;
    }

    public class GenerateIvtReport extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+name}:generateIvtReport";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Starts the execution of a query to retrieve a day-by-day summary of invalid traffic counts for
       * a specific platform. The results will be written to the specified BigQuery destination table.
       * The returned operation name can be used to poll for query completion status. The output table
       * contains 5 rows for each day in the date range. 1 row for each of the 4 device types, and 1 row
       * for all device types. The All row is the sum of the 4 device types for that day. As a result,
       * each column contains twice the total of the number of impressions. If ADH redacts rows due to
       * privacy constraints, the [filtered row summary](https://developers.google.com/ads-data-
       * hub/guides/filtered-row-summary) (the row with no day) will contain the sum of redacted rows.
       *
       * Create a request for the method "customers.generateIvtReport".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link GenerateIvtReport#execute()} method to invoke the remote
       * operation. <p> {@link GenerateIvtReport#initialize(com.google.api.client.googleapis.services.Ab
       * stractGoogleClientRequest)} must be called to initialize this instance immediately after
       * invoking the constructor. </p>
       *
       * @param name Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'. e.g.
     *        'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.GenerateIvtReportRequest}
       * @since 1.13
       */
      protected GenerateIvtReport(java.lang.String name, com.google.api.services.adsdatahub.v1.model.GenerateIvtReportRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport set$Xgafv(java.lang.String $Xgafv) {
        return (GenerateIvtReport) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setAccessToken(java.lang.String accessToken) {
        return (GenerateIvtReport) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setAlt(java.lang.String alt) {
        return (GenerateIvtReport) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setCallback(java.lang.String callback) {
        return (GenerateIvtReport) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setFields(java.lang.String fields) {
        return (GenerateIvtReport) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setKey(java.lang.String key) {
        return (GenerateIvtReport) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setOauthToken(java.lang.String oauthToken) {
        return (GenerateIvtReport) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (GenerateIvtReport) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setQuotaUser(java.lang.String quotaUser) {
        return (GenerateIvtReport) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setUploadType(java.lang.String uploadType) {
        return (GenerateIvtReport) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport setUploadProtocol(java.lang.String uploadProtocol) {
        return (GenerateIvtReport) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'.
       * e.g. 'customers/123'.
       */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'. e.g.
     'customers/123'.
       */
      public java.lang.String getName() {
        return name;
      }

      /**
       * Ads Data Hub customer making the request. This is in the form of 'customers/[customer_id]'.
       * e.g. 'customers/123'.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GenerateIvtReport setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.name = name;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GenerateIvtReport set(String parameterName, Object value) {
        return (GenerateIvtReport) super.set(parameterName, value);
      }
    }
    /**
     * Retrieves the requested Ads Data Hub customer.
     *
     * Create a request for the method "customers.get".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param name Required. Full resource name, e.g. 'customers/123'.
     * @return the request
     */
    public Get get(java.lang.String name) throws java.io.IOException {
      Get result = new Get(name);
      initialize(result);
      return result;
    }

    public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Customer> {

      private static final String REST_PATH = "v1/{+name}";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Retrieves the requested Ads Data Hub customer.
       *
       * Create a request for the method "customers.get".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param name Required. Full resource name, e.g. 'customers/123'.
       * @since 1.13
       */
      protected Get(java.lang.String name) {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.Customer.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get set$Xgafv(java.lang.String $Xgafv) {
        return (Get) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setAccessToken(java.lang.String accessToken) {
        return (Get) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setCallback(java.lang.String callback) {
        return (Get) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setUploadType(java.lang.String uploadType) {
        return (Get) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setUploadProtocol(java.lang.String uploadProtocol) {
        return (Get) super.setUploadProtocol(uploadProtocol);
      }

      /** Required. Full resource name, e.g. 'customers/123'. */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** Required. Full resource name, e.g. 'customers/123'.
       */
      public java.lang.String getName() {
        return name;
      }

      /** Required. Full resource name, e.g. 'customers/123'. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public Get setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.name = name;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Returns the percentage of Google data across all customers that has successfully been ingested
     * into ADH on the given date. The returned value is one of the buckets "less than 95%", "at least
     * 95%", "at least 99%", and "at least 99.9%".
     *
     * Create a request for the method "customers.getImportCompletionStatus".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link GetImportCompletionStatus#execute()} method to invoke the remote
     * operation.
     *
     * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
     * @return the request
     */
    public GetImportCompletionStatus getImportCompletionStatus(java.lang.String customer) throws java.io.IOException {
      GetImportCompletionStatus result = new GetImportCompletionStatus(customer);
      initialize(result);
      return result;
    }

    public class GetImportCompletionStatus extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ImportCompletionStatus> {

      private static final String REST_PATH = "v1/{+customer}/importCompletionStatus";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Returns the percentage of Google data across all customers that has successfully been ingested
       * into ADH on the given date. The returned value is one of the buckets "less than 95%", "at least
       * 95%", "at least 99%", and "at least 99.9%".
       *
       * Create a request for the method "customers.getImportCompletionStatus".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link GetImportCompletionStatus#execute()} method to invoke the
       * remote operation. <p> {@link GetImportCompletionStatus#initialize(com.google.api.client.googlea
       * pis.services.AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
       * @since 1.13
       */
      protected GetImportCompletionStatus(java.lang.String customer) {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ImportCompletionStatus.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus set$Xgafv(java.lang.String $Xgafv) {
        return (GetImportCompletionStatus) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setAccessToken(java.lang.String accessToken) {
        return (GetImportCompletionStatus) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setAlt(java.lang.String alt) {
        return (GetImportCompletionStatus) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setCallback(java.lang.String callback) {
        return (GetImportCompletionStatus) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setFields(java.lang.String fields) {
        return (GetImportCompletionStatus) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setKey(java.lang.String key) {
        return (GetImportCompletionStatus) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setOauthToken(java.lang.String oauthToken) {
        return (GetImportCompletionStatus) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (GetImportCompletionStatus) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setQuotaUser(java.lang.String quotaUser) {
        return (GetImportCompletionStatus) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setUploadType(java.lang.String uploadType) {
        return (GetImportCompletionStatus) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus setUploadProtocol(java.lang.String uploadProtocol) {
        return (GetImportCompletionStatus) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Required. Ads Data Hub customer making the request. This is in the form of
     'customers/[customer_id]'. e.g. 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GetImportCompletionStatus setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      /** Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year. */
      @com.google.api.client.util.Key("date.year")
      private java.lang.Integer dateYear;

      /** Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year.
       */
      public java.lang.Integer getDateYear() {
        return dateYear;
      }

      /** Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GetImportCompletionStatus setDateYear(java.lang.Integer dateYear) {
        this.dateYear = dateYear;
        return this;
      }

      /** Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day. */
      @com.google.api.client.util.Key("date.month")
      private java.lang.Integer dateMonth;

      /** Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
       */
      public java.lang.Integer getDateMonth() {
        return dateMonth;
      }

      /** Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GetImportCompletionStatus setDateMonth(java.lang.Integer dateMonth) {
        this.dateMonth = dateMonth;
        return this;
      }

      /**
       * Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a
       * year by itself or a year and month where the day isn't significant.
       */
      @com.google.api.client.util.Key("date.day")
      private java.lang.Integer dateDay;

      /** Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by
     itself or a year and month where the day isn't significant.
       */
      public java.lang.Integer getDateDay() {
        return dateDay;
      }

      /**
       * Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a
       * year by itself or a year and month where the day isn't significant.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GetImportCompletionStatus setDateDay(java.lang.Integer dateDay) {
        this.dateDay = dateDay;
        return this;
      }

      /**
       * Time zone used when determining the period to retrieve results for. Supported values are
       * "America/Los_Angeles" and "America/New_York". Defaults to "America/Los_Angeles".
       */
      @com.google.api.client.util.Key
      private java.lang.String timeZone;

      /** Time zone used when determining the period to retrieve results for. Supported values are
     "America/Los_Angeles" and "America/New_York". Defaults to "America/Los_Angeles".
       */
      public java.lang.String getTimeZone() {
        return timeZone;
      }

      /**
       * Time zone used when determining the period to retrieve results for. Supported values are
       * "America/Los_Angeles" and "America/New_York". Defaults to "America/Los_Angeles".
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public GetImportCompletionStatus setTimeZone(java.lang.String timeZone) {
        this.timeZone = timeZone;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public GetImportCompletionStatus set(String parameterName, Object value) {
        return (GetImportCompletionStatus) super.set(parameterName, value);
      }
    }
    /**
     * Lists Ads Data Hub customers to which the current user has access.
     *
     * Create a request for the method "customers.list".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListCustomersResponse> {

      private static final String REST_PATH = "v1/customers";

      /**
       * Lists Ads Data Hub customers to which the current user has access.
       *
       * Create a request for the method "customers.list".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListCustomersResponse.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List set$Xgafv(java.lang.String $Xgafv) {
        return (List) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setAccessToken(java.lang.String accessToken) {
        return (List) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setCallback(java.lang.String callback) {
        return (List) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setUploadType(java.lang.String uploadType) {
        return (List) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setUploadProtocol(java.lang.String uploadProtocol) {
        return (List) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Maximum number of items to return. If 0, the server will determine the number of customers
       * to return.
       */
      @com.google.api.client.util.Key
      private java.lang.Integer pageSize;

      /** Maximum number of items to return. If 0, the server will determine the number of customers to
     return.
       */
      public java.lang.Integer getPageSize() {
        return pageSize;
      }

      /**
       * Maximum number of items to return. If 0, the server will determine the number of customers
       * to return.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setPageSize(java.lang.Integer pageSize) {
        this.pageSize = pageSize;
        return this;
      }

      /** Page token, returned by previous call, to request the next page of results, if any. */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** Page token, returned by previous call, to request the next page of results, if any.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** Page token, returned by previous call, to request the next page of results, if any. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }
    /**
     * Starts ADH import of a specified BigQuery table populated with the vendor's Brand Safety score
     * file. This is called by the vendor to trigger ADH to import the scores to CNS for the brand
     * safety discrepancy workflow.
     *
     * Create a request for the method "customers.submitBrandSafetyScores".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link SubmitBrandSafetyScores#execute()} method to invoke the remote
     * operation.
     *
     * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.SubmitBrandSafetyScoresRequest}
     * @return the request
     */
    public SubmitBrandSafetyScores submitBrandSafetyScores(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.SubmitBrandSafetyScoresRequest content) throws java.io.IOException {
      SubmitBrandSafetyScores result = new SubmitBrandSafetyScores(customer, content);
      initialize(result);
      return result;
    }

    public class SubmitBrandSafetyScores extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+customer}:submitBrandSafetyScores";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Starts ADH import of a specified BigQuery table populated with the vendor's Brand Safety score
       * file. This is called by the vendor to trigger ADH to import the scores to CNS for the brand
       * safety discrepancy workflow.
       *
       * Create a request for the method "customers.submitBrandSafetyScores".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link SubmitBrandSafetyScores#execute()} method to invoke the
       * remote operation. <p> {@link SubmitBrandSafetyScores#initialize(com.google.api.client.googleapi
       * s.services.AbstractGoogleClientRequest)} must be called to initialize this instance immediately
       * after invoking the constructor. </p>
       *
       * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.SubmitBrandSafetyScoresRequest}
       * @since 1.13
       */
      protected SubmitBrandSafetyScores(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.SubmitBrandSafetyScoresRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores set$Xgafv(java.lang.String $Xgafv) {
        return (SubmitBrandSafetyScores) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setAccessToken(java.lang.String accessToken) {
        return (SubmitBrandSafetyScores) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setAlt(java.lang.String alt) {
        return (SubmitBrandSafetyScores) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setCallback(java.lang.String callback) {
        return (SubmitBrandSafetyScores) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setFields(java.lang.String fields) {
        return (SubmitBrandSafetyScores) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setKey(java.lang.String key) {
        return (SubmitBrandSafetyScores) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setOauthToken(java.lang.String oauthToken) {
        return (SubmitBrandSafetyScores) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (SubmitBrandSafetyScores) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setQuotaUser(java.lang.String quotaUser) {
        return (SubmitBrandSafetyScores) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setUploadType(java.lang.String uploadType) {
        return (SubmitBrandSafetyScores) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores setUploadProtocol(java.lang.String uploadProtocol) {
        return (SubmitBrandSafetyScores) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Required. Ads Data Hub customer making the request. This is in the form of
     'customers/[customer_id]'. e.g. 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public SubmitBrandSafetyScores setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitBrandSafetyScores set(String parameterName, Object value) {
        return (SubmitBrandSafetyScores) super.set(parameterName, value);
      }
    }
    /**
     * Starts ADH import of a specified BigQuery table populated with the vendor's summary report for a
     * given metric. This is called by the vendor to trigger ADH to generate a discrepancy report based
     * on the Google-computed version of the same data, which will be written to a discrepancy status
     * table.
     *
     * Create a request for the method "customers.submitVendorAggregatesReport".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link SubmitVendorAggregatesReport#execute()} method to invoke the remote
     * operation.
     *
     * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.SubmitVendorAggregatesReportRequest}
     * @return the request
     */
    public SubmitVendorAggregatesReport submitVendorAggregatesReport(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.SubmitVendorAggregatesReportRequest content) throws java.io.IOException {
      SubmitVendorAggregatesReport result = new SubmitVendorAggregatesReport(customer, content);
      initialize(result);
      return result;
    }

    public class SubmitVendorAggregatesReport extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+customer}:submitVendorAggregatesReport";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Starts ADH import of a specified BigQuery table populated with the vendor's summary report for
       * a given metric. This is called by the vendor to trigger ADH to generate a discrepancy report
       * based on the Google-computed version of the same data, which will be written to a discrepancy
       * status table.
       *
       * Create a request for the method "customers.submitVendorAggregatesReport".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link SubmitVendorAggregatesReport#execute()} method to invoke
       * the remote operation. <p> {@link SubmitVendorAggregatesReport#initialize(com.google.api.client.
       * googleapis.services.AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.SubmitVendorAggregatesReportRequest}
       * @since 1.13
       */
      protected SubmitVendorAggregatesReport(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.SubmitVendorAggregatesReportRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport set$Xgafv(java.lang.String $Xgafv) {
        return (SubmitVendorAggregatesReport) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setAccessToken(java.lang.String accessToken) {
        return (SubmitVendorAggregatesReport) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setAlt(java.lang.String alt) {
        return (SubmitVendorAggregatesReport) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setCallback(java.lang.String callback) {
        return (SubmitVendorAggregatesReport) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setFields(java.lang.String fields) {
        return (SubmitVendorAggregatesReport) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setKey(java.lang.String key) {
        return (SubmitVendorAggregatesReport) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setOauthToken(java.lang.String oauthToken) {
        return (SubmitVendorAggregatesReport) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (SubmitVendorAggregatesReport) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setQuotaUser(java.lang.String quotaUser) {
        return (SubmitVendorAggregatesReport) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setUploadType(java.lang.String uploadType) {
        return (SubmitVendorAggregatesReport) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport setUploadProtocol(java.lang.String uploadProtocol) {
        return (SubmitVendorAggregatesReport) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Required. Ads Data Hub customer making the request. This is in the form of
     'customers/[customer_id]'. e.g. 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public SubmitVendorAggregatesReport setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorAggregatesReport set(String parameterName, Object value) {
        return (SubmitVendorAggregatesReport) super.set(parameterName, value);
      }
    }
    /**
     * Starts ADH import of a specified BigQuery table populated with the mapping between customer
     * defined report ID and Google campaign ID. This is called by the customer to trigger ADH to import
     * the mapping to CNS.
     *
     * Create a request for the method "customers.submitVendorReportIdMapping".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link SubmitVendorReportIdMapping#execute()} method to invoke the remote
     * operation.
     *
     * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.SubmitVendorReportIdMappingRequest}
     * @return the request
     */
    public SubmitVendorReportIdMapping submitVendorReportIdMapping(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.SubmitVendorReportIdMappingRequest content) throws java.io.IOException {
      SubmitVendorReportIdMapping result = new SubmitVendorReportIdMapping(customer, content);
      initialize(result);
      return result;
    }

    public class SubmitVendorReportIdMapping extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+customer}:submitVendorReportIdMapping";

      private final java.util.regex.Pattern CUSTOMER_PATTERN =
          java.util.regex.Pattern.compile("^customers/[^/]+$");

      /**
       * Starts ADH import of a specified BigQuery table populated with the mapping between customer
       * defined report ID and Google campaign ID. This is called by the customer to trigger ADH to
       * import the mapping to CNS.
       *
       * Create a request for the method "customers.submitVendorReportIdMapping".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link SubmitVendorReportIdMapping#execute()} method to invoke
       * the remote operation. <p> {@link SubmitVendorReportIdMapping#initialize(com.google.api.client.g
       * oogleapis.services.AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param customer Required. Ads Data Hub customer making the request. This is in the form of
     *        'customers/[customer_id]'. e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.SubmitVendorReportIdMappingRequest}
       * @since 1.13
       */
      protected SubmitVendorReportIdMapping(java.lang.String customer, com.google.api.services.adsdatahub.v1.model.SubmitVendorReportIdMappingRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.customer = com.google.api.client.util.Preconditions.checkNotNull(customer, "Required parameter customer must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping set$Xgafv(java.lang.String $Xgafv) {
        return (SubmitVendorReportIdMapping) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setAccessToken(java.lang.String accessToken) {
        return (SubmitVendorReportIdMapping) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setAlt(java.lang.String alt) {
        return (SubmitVendorReportIdMapping) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setCallback(java.lang.String callback) {
        return (SubmitVendorReportIdMapping) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setFields(java.lang.String fields) {
        return (SubmitVendorReportIdMapping) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setKey(java.lang.String key) {
        return (SubmitVendorReportIdMapping) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setOauthToken(java.lang.String oauthToken) {
        return (SubmitVendorReportIdMapping) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (SubmitVendorReportIdMapping) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setQuotaUser(java.lang.String quotaUser) {
        return (SubmitVendorReportIdMapping) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setUploadType(java.lang.String uploadType) {
        return (SubmitVendorReportIdMapping) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping setUploadProtocol(java.lang.String uploadProtocol) {
        return (SubmitVendorReportIdMapping) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.api.client.util.Key
      private java.lang.String customer;

      /** Required. Ads Data Hub customer making the request. This is in the form of
     'customers/[customer_id]'. e.g. 'customers/123'.
       */
      public java.lang.String getCustomer() {
        return customer;
      }

      /**
       * Required. Ads Data Hub customer making the request. This is in the form of
       * 'customers/[customer_id]'. e.g. 'customers/123'.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public SubmitVendorReportIdMapping setCustomer(java.lang.String customer) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CUSTOMER_PATTERN.matcher(customer).matches(),
              "Parameter customer must conform to the pattern " +
              "^customers/[^/]+$");
        }
        this.customer = customer;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public SubmitVendorReportIdMapping set(String parameterName, Object value) {
        return (SubmitVendorReportIdMapping) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the AdsDataCustomers collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.AdsDataCustomers.List request = adsdatahub.adsDataCustomers().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public AdsDataCustomers adsDataCustomers() {
      return new AdsDataCustomers();
    }

    /**
     * The "adsDataCustomers" collection of methods.
     */
    public class AdsDataCustomers {

      /**
       * Retrieves the requested Ads Data Hub customer.
       *
       * Create a request for the method "adsDataCustomers.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/adsDataCustomers/456'.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.AdsDataCustomer> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/adsDataCustomers/[^/]+$");

        /**
         * Retrieves the requested Ads Data Hub customer.
         *
         * Create a request for the method "adsDataCustomers.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/adsDataCustomers/456'.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.AdsDataCustomer.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/adsDataCustomers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/adsDataCustomers/456'. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/adsDataCustomers/456'.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/adsDataCustomers/456'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/adsDataCustomers/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Retrieves the data access budget for the requested ads data source for the last 366 days.
       *
       * Create a request for the method "adsDataCustomers.getDataAccessBudget".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link GetDataAccessBudget#execute()} method to invoke the remote operation.
       *
       * @param name Required. Name of the data access budget. Format:
       *        customers/{customer_id}/adsDataCustomers/{ads_data_customer_id}/dataAccessBudget e.g.
       *        'customers/123/adsDataCustomers/456/dataAccessBudget'.
       * @return the request
       */
      public GetDataAccessBudget getDataAccessBudget(java.lang.String name) throws java.io.IOException {
        GetDataAccessBudget result = new GetDataAccessBudget(name);
        initialize(result);
        return result;
      }

      public class GetDataAccessBudget extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.DataAccessBudget> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/adsDataCustomers/[^/]+/dataAccessBudget$");

        /**
         * Retrieves the data access budget for the requested ads data source for the last 366 days.
         *
         * Create a request for the method "adsDataCustomers.getDataAccessBudget".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link GetDataAccessBudget#execute()} method to invoke the remote
         * operation. <p> {@link GetDataAccessBudget#initialize(com.google.api.client.googleapis.services.
         * AbstractGoogleClientRequest)} must be called to initialize this instance immediately after
         * invoking the constructor. </p>
         *
         * @param name Required. Name of the data access budget. Format:
       *        customers/{customer_id}/adsDataCustomers/{ads_data_customer_id}/dataAccessBudget e.g.
       *        'customers/123/adsDataCustomers/456/dataAccessBudget'.
         * @since 1.13
         */
        protected GetDataAccessBudget(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.DataAccessBudget.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/adsDataCustomers/[^/]+/dataAccessBudget$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget set$Xgafv(java.lang.String $Xgafv) {
          return (GetDataAccessBudget) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setAccessToken(java.lang.String accessToken) {
          return (GetDataAccessBudget) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setAlt(java.lang.String alt) {
          return (GetDataAccessBudget) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setCallback(java.lang.String callback) {
          return (GetDataAccessBudget) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setFields(java.lang.String fields) {
          return (GetDataAccessBudget) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setKey(java.lang.String key) {
          return (GetDataAccessBudget) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setOauthToken(java.lang.String oauthToken) {
          return (GetDataAccessBudget) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (GetDataAccessBudget) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setQuotaUser(java.lang.String quotaUser) {
          return (GetDataAccessBudget) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setUploadType(java.lang.String uploadType) {
          return (GetDataAccessBudget) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget setUploadProtocol(java.lang.String uploadProtocol) {
          return (GetDataAccessBudget) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Name of the data access budget. Format:
         * customers/{customer_id}/adsDataCustomers/{ads_data_customer_id}/dataAccessBudget e.g.
         * 'customers/123/adsDataCustomers/456/dataAccessBudget'.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Name of the data access budget. Format:
       customers/{customer_id}/adsDataCustomers/{ads_data_customer_id}/dataAccessBudget e.g.
       'customers/123/adsDataCustomers/456/dataAccessBudget'.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Required. Name of the data access budget. Format:
         * customers/{customer_id}/adsDataCustomers/{ads_data_customer_id}/dataAccessBudget e.g.
         * 'customers/123/adsDataCustomers/456/dataAccessBudget'.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public GetDataAccessBudget setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/adsDataCustomers/[^/]+/dataAccessBudget$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GetDataAccessBudget set(String parameterName, Object value) {
          return (GetDataAccessBudget) super.set(parameterName, value);
        }
      }
      /**
       * Lists ads data customers accessible from the customer.
       *
       * Create a request for the method "adsDataCustomers.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. The customer associated with these ads data customers. Format: customers/{customer}
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListAdsDataCustomersResponse> {

        private static final String REST_PATH = "v1/{+parent}/adsDataCustomers";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists ads data customers accessible from the customer.
         *
         * Create a request for the method "adsDataCustomers.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. The customer associated with these ads data customers. Format: customers/{customer}
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListAdsDataCustomersResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The customer associated with these ads data customers. Format:
         * customers/{customer}
         */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. The customer associated with these ads data customers. Format: customers/{customer}
         */
        public java.lang.String getParent() {
          return parent;
        }

        /**
         * Required. The customer associated with these ads data customers. Format:
         * customers/{customer}
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of ads data
         * customers to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of ads data customers
       to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of ads data
         * customers to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /** Page token, returned by previous call, to request the next page of results, if any. */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by previous call, to request the next page of results, if any.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /** Page token, returned by previous call, to request the next page of results, if any. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the AdsDataLinks collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.AdsDataLinks.List request = adsdatahub.adsDataLinks().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public AdsDataLinks adsDataLinks() {
      return new AdsDataLinks();
    }

    /**
     * The "adsDataLinks" collection of methods.
     */
    public class AdsDataLinks {

      /**
       * Approve a list of pending ads data links.
       *
       * Create a request for the method "adsDataLinks.batchApprove".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link BatchApprove#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'. All links to approve must be under
       *        this customer.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.BatchApproveAdsDataLinksRequest}
       * @return the request
       */
      public BatchApprove batchApprove(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.BatchApproveAdsDataLinksRequest content) throws java.io.IOException {
        BatchApprove result = new BatchApprove(parent, content);
        initialize(result);
        return result;
      }

      public class BatchApprove extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.BatchApproveAdsDataLinksResponse> {

        private static final String REST_PATH = "v1/{+parent}/adsDataLinks:batchApprove";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Approve a list of pending ads data links.
         *
         * Create a request for the method "adsDataLinks.batchApprove".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link BatchApprove#execute()} method to invoke the remote
         * operation. <p> {@link
         * BatchApprove#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'. All links to approve must be under
       *        this customer.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.BatchApproveAdsDataLinksRequest}
         * @since 1.13
         */
        protected BatchApprove(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.BatchApproveAdsDataLinksRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.BatchApproveAdsDataLinksResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove set$Xgafv(java.lang.String $Xgafv) {
          return (BatchApprove) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setAccessToken(java.lang.String accessToken) {
          return (BatchApprove) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setAlt(java.lang.String alt) {
          return (BatchApprove) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setCallback(java.lang.String callback) {
          return (BatchApprove) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setFields(java.lang.String fields) {
          return (BatchApprove) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setKey(java.lang.String key) {
          return (BatchApprove) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setOauthToken(java.lang.String oauthToken) {
          return (BatchApprove) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (BatchApprove) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setQuotaUser(java.lang.String quotaUser) {
          return (BatchApprove) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setUploadType(java.lang.String uploadType) {
          return (BatchApprove) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove setUploadProtocol(java.lang.String uploadProtocol) {
          return (BatchApprove) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Parent customer resource name, e.g. 'customers/123'. All links to approve must
         * be under this customer.
         */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'. All links to approve must be under
       this customer.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /**
         * Required. Parent customer resource name, e.g. 'customers/123'. All links to approve must
         * be under this customer.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public BatchApprove setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchApprove set(String parameterName, Object value) {
          return (BatchApprove) super.set(parameterName, value);
        }
      }
      /**
       * Reject a list of pending ads data links.
       *
       * Create a request for the method "adsDataLinks.batchReject".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link BatchReject#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'. All links to reject must be under
       *        this customer.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.BatchRejectAdsDataLinksRequest}
       * @return the request
       */
      public BatchReject batchReject(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.BatchRejectAdsDataLinksRequest content) throws java.io.IOException {
        BatchReject result = new BatchReject(parent, content);
        initialize(result);
        return result;
      }

      public class BatchReject extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.BatchRejectAdsDataLinksResponse> {

        private static final String REST_PATH = "v1/{+parent}/adsDataLinks:batchReject";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Reject a list of pending ads data links.
         *
         * Create a request for the method "adsDataLinks.batchReject".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link BatchReject#execute()} method to invoke the remote
         * operation. <p> {@link
         * BatchReject#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'. All links to reject must be under
       *        this customer.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.BatchRejectAdsDataLinksRequest}
         * @since 1.13
         */
        protected BatchReject(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.BatchRejectAdsDataLinksRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.BatchRejectAdsDataLinksResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject set$Xgafv(java.lang.String $Xgafv) {
          return (BatchReject) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setAccessToken(java.lang.String accessToken) {
          return (BatchReject) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setAlt(java.lang.String alt) {
          return (BatchReject) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setCallback(java.lang.String callback) {
          return (BatchReject) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setFields(java.lang.String fields) {
          return (BatchReject) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setKey(java.lang.String key) {
          return (BatchReject) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setOauthToken(java.lang.String oauthToken) {
          return (BatchReject) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (BatchReject) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setQuotaUser(java.lang.String quotaUser) {
          return (BatchReject) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setUploadType(java.lang.String uploadType) {
          return (BatchReject) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject setUploadProtocol(java.lang.String uploadProtocol) {
          return (BatchReject) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Parent customer resource name, e.g. 'customers/123'. All links to reject must
         * be under this customer.
         */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'. All links to reject must be under
       this customer.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /**
         * Required. Parent customer resource name, e.g. 'customers/123'. All links to reject must
         * be under this customer.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public BatchReject setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public BatchReject set(String parameterName, Object value) {
          return (BatchReject) super.set(parameterName, value);
        }
      }
      /**
       * Lists links between the specified customer and other Google advertising entities.
       *
       * Create a request for the method "adsDataLinks.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListAdsDataLinksResponse> {

        private static final String REST_PATH = "v1/{+parent}/adsDataLinks";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists links between the specified customer and other Google advertising entities.
         *
         * Create a request for the method "adsDataLinks.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListAdsDataLinksResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of linked
         * customers to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of linked customers
       to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of linked
         * customers to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results, if any.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name="customers/1/adsDataLinks/CNC0w8IFEAEYAQ" platform=”GOOGLE_ADS” status=”PENDING”
         * create_time>unix_seconds uptdate_time>unix_seconds vendor_client_id="vendor_customer"
         * metrics="VIEWABILITY"
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Filters your response. Works using the following fields / formatting:
       name="customers/1/adsDataLinks/CNC0w8IFEAEYAQ" platform=”GOOGLE_ADS” status=”PENDING”
       create_time>unix_seconds uptdate_time>unix_seconds vendor_client_id="vendor_customer"
       metrics="VIEWABILITY"
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name="customers/1/adsDataLinks/CNC0w8IFEAEYAQ" platform=”GOOGLE_ADS” status=”PENDING”
         * create_time>unix_seconds uptdate_time>unix_seconds vendor_client_id="vendor_customer"
         * metrics="VIEWABILITY"
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the AnalysisQueries collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.AnalysisQueries.List request = adsdatahub.analysisQueries().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public AnalysisQueries analysisQueries() {
      return new AnalysisQueries();
    }

    /**
     * The "analysisQueries" collection of methods.
     */
    public class AnalysisQueries {

      /**
       * Creates an analysis query for later execution. No query validation is performed at this time.
       *
       * Create a request for the method "analysisQueries.create".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Create#execute()} method to invoke the remote operation.
       *
       * @param parent Required. The parent resource name that owns the query, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.AnalysisQuery}
       * @return the request
       */
      public Create create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.AnalysisQuery content) throws java.io.IOException {
        Create result = new Create(parent, content);
        initialize(result);
        return result;
      }

      public class Create extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.AnalysisQuery> {

        private static final String REST_PATH = "v1/{+parent}/analysisQueries";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Creates an analysis query for later execution. No query validation is performed at this time.
         *
         * Create a request for the method "analysisQueries.create".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Create#execute()} method to invoke the remote operation.
         * <p> {@link
         * Create#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. The parent resource name that owns the query, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.AnalysisQuery}
         * @since 1.13
         */
        protected Create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.AnalysisQuery content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.AnalysisQuery.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set$Xgafv(java.lang.String $Xgafv) {
          return (Create) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAccessToken(java.lang.String accessToken) {
          return (Create) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAlt(java.lang.String alt) {
          return (Create) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setCallback(java.lang.String callback) {
          return (Create) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setFields(java.lang.String fields) {
          return (Create) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setKey(java.lang.String key) {
          return (Create) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setOauthToken(java.lang.String oauthToken) {
          return (Create) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Create) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setQuotaUser(java.lang.String quotaUser) {
          return (Create) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadType(java.lang.String uploadType) {
          return (Create) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadProtocol(java.lang.String uploadProtocol) {
          return (Create) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. The parent resource name that owns the query, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Create setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set(String parameterName, Object value) {
          return (Create) super.set(parameterName, value);
        }
      }
      /**
       * Deletes an analysis query.
       *
       * Create a request for the method "analysisQueries.delete".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       *
       * @param name Required. The full name of the analysis query to delete. This is of the form
       *        'customers/[customer_id]/analysisQueries/[resource_id]', e.g.
       *        'customers/123/analysisQueries/resource123'.
       * @return the request
       */
      public Delete delete(java.lang.String name) throws java.io.IOException {
        Delete result = new Delete(name);
        initialize(result);
        return result;
      }

      public class Delete extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Empty> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/analysisQueries/[^/]+$");

        /**
         * Deletes an analysis query.
         *
         * Create a request for the method "analysisQueries.delete".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
         * <p> {@link
         * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. The full name of the analysis query to delete. This is of the form
       *        'customers/[customer_id]/analysisQueries/[resource_id]', e.g.
       *        'customers/123/analysisQueries/resource123'.
         * @since 1.13
         */
        protected Delete(java.lang.String name) {
          super(AdsDataHub.this, "DELETE", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.Empty.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set$Xgafv(java.lang.String $Xgafv) {
          return (Delete) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAccessToken(java.lang.String accessToken) {
          return (Delete) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAlt(java.lang.String alt) {
          return (Delete) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setCallback(java.lang.String callback) {
          return (Delete) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setFields(java.lang.String fields) {
          return (Delete) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setKey(java.lang.String key) {
          return (Delete) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setOauthToken(java.lang.String oauthToken) {
          return (Delete) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Delete) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setQuotaUser(java.lang.String quotaUser) {
          return (Delete) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadType(java.lang.String uploadType) {
          return (Delete) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadProtocol(java.lang.String uploadProtocol) {
          return (Delete) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The full name of the analysis query to delete. This is of the form
         * 'customers/[customer_id]/analysisQueries/[resource_id]', e.g.
         * 'customers/123/analysisQueries/resource123'.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. The full name of the analysis query to delete. This is of the form
       'customers/[customer_id]/analysisQueries/[resource_id]', e.g.
       'customers/123/analysisQueries/resource123'.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Required. The full name of the analysis query to delete. This is of the form
         * 'customers/[customer_id]/analysisQueries/[resource_id]', e.g.
         * 'customers/123/analysisQueries/resource123'.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Delete setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set(String parameterName, Object value) {
          return (Delete) super.set(parameterName, value);
        }
      }
      /**
       * Retrieves the requested analysis query.
       *
       * Create a request for the method "analysisQueries.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.AnalysisQuery> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/analysisQueries/[^/]+$");

        /**
         * Retrieves the requested analysis query.
         *
         * Create a request for the method "analysisQueries.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.AnalysisQuery.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists the analysis queries owned by the specified customer.
       *
       * Create a request for the method "analysisQueries.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListAnalysisQueriesResponse> {

        private static final String REST_PATH = "v1/{+parent}/analysisQueries";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists the analysis queries owned by the specified customer.
         *
         * Create a request for the method "analysisQueries.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListAnalysisQueriesResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, The server will determine the number of queries
         * to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, The server will determine the number of queries to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, The server will determine the number of queries
         * to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results, if any.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name=”customers/271828/analysisQueries/pi314159265359” title=”up_and_right”
         * query_text="SELECT LN(2.7182818284);" query_state="RUNNABLE" update_time>unix_seconds
         * update_email=”abc@gmail.com” create_time>unix_seconds create_email=”abc@gmail.com”
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Filters your response. Works using the following fields / formatting:
       name=”customers/271828/analysisQueries/pi314159265359” title=”up_and_right” query_text="SELECT
       LN(2.7182818284);" query_state="RUNNABLE" update_time>unix_seconds update_email=”abc@gmail.com”
       create_time>unix_seconds create_email=”abc@gmail.com”
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name=”customers/271828/analysisQueries/pi314159265359” title=”up_and_right”
         * query_text="SELECT LN(2.7182818284);" query_state="RUNNABLE" update_time>unix_seconds
         * update_email=”abc@gmail.com” create_time>unix_seconds create_email=”abc@gmail.com”
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }
      /**
       * Updates an existing analysis query. Partial updates are supported. The following query fields
       * cannot be updated using this method and will be ignored: - query_state - create_time -
       * create_email - update_time - update_email
       *
       * Create a request for the method "analysisQueries.patch".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       *
       * @param name Name that uniquely identifies a query. It has the form
       *        customers/[customer_id]/analysisQueries/[resource_id], e.g.
       *        'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.AnalysisQuery}
       * @return the request
       */
      public Patch patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.AnalysisQuery content) throws java.io.IOException {
        Patch result = new Patch(name, content);
        initialize(result);
        return result;
      }

      public class Patch extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.AnalysisQuery> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/analysisQueries/[^/]+$");

        /**
         * Updates an existing analysis query. Partial updates are supported. The following query fields
         * cannot be updated using this method and will be ignored: - query_state - create_time -
         * create_email - update_time - update_email
         *
         * Create a request for the method "analysisQueries.patch".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
         * <p> {@link
         * Patch#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Name that uniquely identifies a query. It has the form
       *        customers/[customer_id]/analysisQueries/[resource_id], e.g.
       *        'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.AnalysisQuery}
         * @since 1.13
         */
        protected Patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.AnalysisQuery content) {
          super(AdsDataHub.this, "PATCH", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.AnalysisQuery.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set$Xgafv(java.lang.String $Xgafv) {
          return (Patch) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAccessToken(java.lang.String accessToken) {
          return (Patch) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAlt(java.lang.String alt) {
          return (Patch) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setCallback(java.lang.String callback) {
          return (Patch) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setFields(java.lang.String fields) {
          return (Patch) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setKey(java.lang.String key) {
          return (Patch) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setOauthToken(java.lang.String oauthToken) {
          return (Patch) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Patch) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setQuotaUser(java.lang.String quotaUser) {
          return (Patch) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadType(java.lang.String uploadType) {
          return (Patch) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadProtocol(java.lang.String uploadProtocol) {
          return (Patch) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Name that uniquely identifies a query. It has the form
         * customers/[customer_id]/analysisQueries/[resource_id], e.g.
         * 'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Name that uniquely identifies a query. It has the form
       customers/[customer_id]/analysisQueries/[resource_id], e.g.
       'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Name that uniquely identifies a query. It has the form
         * customers/[customer_id]/analysisQueries/[resource_id], e.g.
         * 'customers/123/analysisQueries/abcd1234'. The resource ID is generated by the server.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        /** Field mask used to support partial updates. */
        @com.google.api.client.util.Key
        private String updateMask;

        /** Field mask used to support partial updates.
         */
        public String getUpdateMask() {
          return updateMask;
        }

        /** Field mask used to support partial updates. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setUpdateMask(String updateMask) {
          this.updateMask = updateMask;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set(String parameterName, Object value) {
          return (Patch) super.set(parameterName, value);
        }
      }
      /**
       * Starts execution on a stored analysis query. The results will be written to the specified
       * BigQuery destination table. The returned operation name can be used to poll for query completion
       * status.
       *
       * Create a request for the method "analysisQueries.start".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Start#execute()} method to invoke the remote operation.
       *
       * @param name Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartAnalysisQueryRequest}
       * @return the request
       */
      public Start start(java.lang.String name, com.google.api.services.adsdatahub.v1.model.StartAnalysisQueryRequest content) throws java.io.IOException {
        Start result = new Start(name, content);
        initialize(result);
        return result;
      }

      public class Start extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

        private static final String REST_PATH = "v1/{+name}:start";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/analysisQueries/[^/]+$");

        /**
         * Starts execution on a stored analysis query. The results will be written to the specified
         * BigQuery destination table. The returned operation name can be used to poll for query
         * completion status.
         *
         * Create a request for the method "analysisQueries.start".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Start#execute()} method to invoke the remote operation.
         * <p> {@link
         * Start#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartAnalysisQueryRequest}
         * @since 1.13
         */
        protected Start(java.lang.String name, com.google.api.services.adsdatahub.v1.model.StartAnalysisQueryRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start set$Xgafv(java.lang.String $Xgafv) {
          return (Start) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setAccessToken(java.lang.String accessToken) {
          return (Start) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setAlt(java.lang.String alt) {
          return (Start) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setCallback(java.lang.String callback) {
          return (Start) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setFields(java.lang.String fields) {
          return (Start) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setKey(java.lang.String key) {
          return (Start) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setOauthToken(java.lang.String oauthToken) {
          return (Start) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Start) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setQuotaUser(java.lang.String quotaUser) {
          return (Start) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setUploadType(java.lang.String uploadType) {
          return (Start) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setUploadProtocol(java.lang.String uploadProtocol) {
          return (Start) super.setUploadProtocol(uploadProtocol);
        }

        /** Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Full resource name, e.g. 'customers/123/analysisQueries/abcd1234'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Start setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/analysisQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start set(String parameterName, Object value) {
          return (Start) super.set(parameterName, value);
        }
      }
      /**
       * Starts execution on a transient analysis query. The results will be written to the specified
       * BigQuery destination table. The returned operation name can be used to poll for query completion
       * status.
       *
       * Create a request for the method "analysisQueries.startTransient".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link StartTransient#execute()} method to invoke the remote operation.
       *
       * @param parent Full resource name of the customer executing the query, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartTransientAnalysisQueryRequest}
       * @return the request
       */
      public StartTransient startTransient(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.StartTransientAnalysisQueryRequest content) throws java.io.IOException {
        StartTransient result = new StartTransient(parent, content);
        initialize(result);
        return result;
      }

      public class StartTransient extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

        private static final String REST_PATH = "v1/{+parent}/analysisQueries:startTransient";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Starts execution on a transient analysis query. The results will be written to the specified
         * BigQuery destination table. The returned operation name can be used to poll for query
         * completion status.
         *
         * Create a request for the method "analysisQueries.startTransient".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link StartTransient#execute()} method to invoke the remote
         * operation. <p> {@link StartTransient#initialize(com.google.api.client.googleapis.services.Abstr
         * actGoogleClientRequest)} must be called to initialize this instance immediately after invoking
         * the constructor. </p>
         *
         * @param parent Full resource name of the customer executing the query, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartTransientAnalysisQueryRequest}
         * @since 1.13
         */
        protected StartTransient(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.StartTransientAnalysisQueryRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient set$Xgafv(java.lang.String $Xgafv) {
          return (StartTransient) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setAccessToken(java.lang.String accessToken) {
          return (StartTransient) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setAlt(java.lang.String alt) {
          return (StartTransient) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setCallback(java.lang.String callback) {
          return (StartTransient) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setFields(java.lang.String fields) {
          return (StartTransient) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setKey(java.lang.String key) {
          return (StartTransient) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setOauthToken(java.lang.String oauthToken) {
          return (StartTransient) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (StartTransient) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setQuotaUser(java.lang.String quotaUser) {
          return (StartTransient) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setUploadType(java.lang.String uploadType) {
          return (StartTransient) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setUploadProtocol(java.lang.String uploadProtocol) {
          return (StartTransient) super.setUploadProtocol(uploadProtocol);
        }

        /** Full resource name of the customer executing the query, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Full resource name of the customer executing the query, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Full resource name of the customer executing the query, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public StartTransient setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient set(String parameterName, Object value) {
          return (StartTransient) super.set(parameterName, value);
        }
      }
      /**
       * Performs static validation checks on the provided analysis query.
       *
       * Create a request for the method "analysisQueries.validate".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Validate#execute()} method to invoke the remote operation.
       *
       * @param parent The parent resource name that owns the query, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.ValidateAnalysisQueryRequest}
       * @return the request
       */
      public Validate validate(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.ValidateAnalysisQueryRequest content) throws java.io.IOException {
        Validate result = new Validate(parent, content);
        initialize(result);
        return result;
      }

      public class Validate extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ValidateAnalysisQueryResponse> {

        private static final String REST_PATH = "v1/{+parent}/analysisQueries:validate";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Performs static validation checks on the provided analysis query.
         *
         * Create a request for the method "analysisQueries.validate".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Validate#execute()} method to invoke the remote operation.
         * <p> {@link
         * Validate#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent The parent resource name that owns the query, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.ValidateAnalysisQueryRequest}
         * @since 1.13
         */
        protected Validate(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.ValidateAnalysisQueryRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.ValidateAnalysisQueryResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate set$Xgafv(java.lang.String $Xgafv) {
          return (Validate) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setAccessToken(java.lang.String accessToken) {
          return (Validate) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setAlt(java.lang.String alt) {
          return (Validate) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setCallback(java.lang.String callback) {
          return (Validate) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setFields(java.lang.String fields) {
          return (Validate) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setKey(java.lang.String key) {
          return (Validate) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setOauthToken(java.lang.String oauthToken) {
          return (Validate) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Validate) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setQuotaUser(java.lang.String quotaUser) {
          return (Validate) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setUploadType(java.lang.String uploadType) {
          return (Validate) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setUploadProtocol(java.lang.String uploadProtocol) {
          return (Validate) super.setUploadProtocol(uploadProtocol);
        }

        /** The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** The parent resource name that owns the query, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Validate setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate set(String parameterName, Object value) {
          return (Validate) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the CustomBiddingAlgorithms collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.CustomBiddingAlgorithms.List request = adsdatahub.customBiddingAlgorithms().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public CustomBiddingAlgorithms customBiddingAlgorithms() {
      return new CustomBiddingAlgorithms();
    }

    /**
     * The "customBiddingAlgorithms" collection of methods.
     */
    public class CustomBiddingAlgorithms {

      /**
       * Add a DV360 advertiser to the custom bidding algorithm's advertisers.
       *
       * Create a request for the method "customBiddingAlgorithms.addAdvertiser".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link AddAdvertiser#execute()} method to invoke the remote operation.
       *
       * @param customBiddingAlgorithm Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.AddAdvertiserRequest}
       * @return the request
       */
      public AddAdvertiser addAdvertiser(java.lang.String customBiddingAlgorithm, com.google.api.services.adsdatahub.v1.model.AddAdvertiserRequest content) throws java.io.IOException {
        AddAdvertiser result = new AddAdvertiser(customBiddingAlgorithm, content);
        initialize(result);
        return result;
      }

      public class AddAdvertiser extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm> {

        private static final String REST_PATH = "v1/{+customBiddingAlgorithm}:addAdvertiser";

        private final java.util.regex.Pattern CUSTOM_BIDDING_ALGORITHM_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/customBiddingAlgorithms/[^/]+$");

        /**
         * Add a DV360 advertiser to the custom bidding algorithm's advertisers.
         *
         * Create a request for the method "customBiddingAlgorithms.addAdvertiser".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link AddAdvertiser#execute()} method to invoke the remote
         * operation. <p> {@link AddAdvertiser#initialize(com.google.api.client.googleapis.services.Abstra
         * ctGoogleClientRequest)} must be called to initialize this instance immediately after invoking
         * the constructor. </p>
         *
         * @param customBiddingAlgorithm Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.AddAdvertiserRequest}
         * @since 1.13
         */
        protected AddAdvertiser(java.lang.String customBiddingAlgorithm, com.google.api.services.adsdatahub.v1.model.AddAdvertiserRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm.class);
          this.customBiddingAlgorithm = com.google.api.client.util.Preconditions.checkNotNull(customBiddingAlgorithm, "Required parameter customBiddingAlgorithm must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(CUSTOM_BIDDING_ALGORITHM_PATTERN.matcher(customBiddingAlgorithm).matches(),
                "Parameter customBiddingAlgorithm must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser set$Xgafv(java.lang.String $Xgafv) {
          return (AddAdvertiser) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setAccessToken(java.lang.String accessToken) {
          return (AddAdvertiser) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setAlt(java.lang.String alt) {
          return (AddAdvertiser) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setCallback(java.lang.String callback) {
          return (AddAdvertiser) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setFields(java.lang.String fields) {
          return (AddAdvertiser) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setKey(java.lang.String key) {
          return (AddAdvertiser) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setOauthToken(java.lang.String oauthToken) {
          return (AddAdvertiser) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (AddAdvertiser) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setQuotaUser(java.lang.String quotaUser) {
          return (AddAdvertiser) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setUploadType(java.lang.String uploadType) {
          return (AddAdvertiser) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser setUploadProtocol(java.lang.String uploadProtocol) {
          return (AddAdvertiser) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.api.client.util.Key
        private java.lang.String customBiddingAlgorithm;

        /** Required. Full resource name of a custom bidding algorithm, e.g.
       'customers/123/customBiddingAlgorithms/12345678.
         */
        public java.lang.String getCustomBiddingAlgorithm() {
          return customBiddingAlgorithm;
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public AddAdvertiser setCustomBiddingAlgorithm(java.lang.String customBiddingAlgorithm) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(CUSTOM_BIDDING_ALGORITHM_PATTERN.matcher(customBiddingAlgorithm).matches(),
                "Parameter customBiddingAlgorithm must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
          this.customBiddingAlgorithm = customBiddingAlgorithm;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddAdvertiser set(String parameterName, Object value) {
          return (AddAdvertiser) super.set(parameterName, value);
        }
      }
      /**
       * Creates an Ads Data Hub-managed custom bidding algorithm.
       *
       * Create a request for the method "customBiddingAlgorithms.create".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Create#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resournce name, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm}
       * @return the request
       */
      public Create create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm content) throws java.io.IOException {
        Create result = new Create(parent, content);
        initialize(result);
        return result;
      }

      public class Create extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm> {

        private static final String REST_PATH = "v1/{+parent}/customBiddingAlgorithms";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Creates an Ads Data Hub-managed custom bidding algorithm.
         *
         * Create a request for the method "customBiddingAlgorithms.create".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Create#execute()} method to invoke the remote operation.
         * <p> {@link
         * Create#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resournce name, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm}
         * @since 1.13
         */
        protected Create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set$Xgafv(java.lang.String $Xgafv) {
          return (Create) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAccessToken(java.lang.String accessToken) {
          return (Create) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAlt(java.lang.String alt) {
          return (Create) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setCallback(java.lang.String callback) {
          return (Create) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setFields(java.lang.String fields) {
          return (Create) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setKey(java.lang.String key) {
          return (Create) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setOauthToken(java.lang.String oauthToken) {
          return (Create) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Create) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setQuotaUser(java.lang.String quotaUser) {
          return (Create) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadType(java.lang.String uploadType) {
          return (Create) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadProtocol(java.lang.String uploadProtocol) {
          return (Create) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resournce name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resournce name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resournce name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Create setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set(String parameterName, Object value) {
          return (Create) super.set(parameterName, value);
        }
      }
      /**
       * Delete this custom bidding algorithm. Note that this cannot be undone. Deleted custom bidding
       * algorithms cannot be executed.
       *
       * Create a request for the method "customBiddingAlgorithms.delete".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
       * @return the request
       */
      public Delete delete(java.lang.String name) throws java.io.IOException {
        Delete result = new Delete(name);
        initialize(result);
        return result;
      }

      public class Delete extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/customBiddingAlgorithms/[^/]+$");

        /**
         * Delete this custom bidding algorithm. Note that this cannot be undone. Deleted custom bidding
         * algorithms cannot be executed.
         *
         * Create a request for the method "customBiddingAlgorithms.delete".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
         * <p> {@link
         * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
         * @since 1.13
         */
        protected Delete(java.lang.String name) {
          super(AdsDataHub.this, "DELETE", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set$Xgafv(java.lang.String $Xgafv) {
          return (Delete) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAccessToken(java.lang.String accessToken) {
          return (Delete) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAlt(java.lang.String alt) {
          return (Delete) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setCallback(java.lang.String callback) {
          return (Delete) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setFields(java.lang.String fields) {
          return (Delete) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setKey(java.lang.String key) {
          return (Delete) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setOauthToken(java.lang.String oauthToken) {
          return (Delete) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Delete) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setQuotaUser(java.lang.String quotaUser) {
          return (Delete) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadType(java.lang.String uploadType) {
          return (Delete) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadProtocol(java.lang.String uploadProtocol) {
          return (Delete) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name of a custom bidding algorithm, e.g.
       'customers/123/customBiddingAlgorithms/12345678.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Delete setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set(String parameterName, Object value) {
          return (Delete) super.set(parameterName, value);
        }
      }
      /**
       * Scores the last 30 days of impressions for the custom bidding models.
       *
       * Create a request for the method "customBiddingAlgorithms.execute".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Execute#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.ExecuteCustomBiddingAlgorithmRequest}
       * @return the request
       */
      public Execute execute(java.lang.String name, com.google.api.services.adsdatahub.v1.model.ExecuteCustomBiddingAlgorithmRequest content) throws java.io.IOException {
        Execute result = new Execute(name, content);
        initialize(result);
        return result;
      }

      public class Execute extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

        private static final String REST_PATH = "v1/{+name}:execute";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/customBiddingAlgorithms/[^/]+$");

        /**
         * Scores the last 30 days of impressions for the custom bidding models.
         *
         * Create a request for the method "customBiddingAlgorithms.execute".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Execute#execute()} method to invoke the remote operation.
         * <p> {@link
         * Execute#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.ExecuteCustomBiddingAlgorithmRequest}
         * @since 1.13
         */
        protected Execute(java.lang.String name, com.google.api.services.adsdatahub.v1.model.ExecuteCustomBiddingAlgorithmRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute set$Xgafv(java.lang.String $Xgafv) {
          return (Execute) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setAccessToken(java.lang.String accessToken) {
          return (Execute) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setAlt(java.lang.String alt) {
          return (Execute) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setCallback(java.lang.String callback) {
          return (Execute) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setFields(java.lang.String fields) {
          return (Execute) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setKey(java.lang.String key) {
          return (Execute) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setOauthToken(java.lang.String oauthToken) {
          return (Execute) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Execute) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setQuotaUser(java.lang.String quotaUser) {
          return (Execute) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setUploadType(java.lang.String uploadType) {
          return (Execute) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute setUploadProtocol(java.lang.String uploadProtocol) {
          return (Execute) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name of a custom bidding algorithm, e.g.
       'customers/123/customBiddingAlgorithms/12345678.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Execute setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Execute set(String parameterName, Object value) {
          return (Execute) super.set(parameterName, value);
        }
      }
      /**
       * Retrieves the requested Ads Data Hub-managed custom bidding algorithm.
       *
       * Create a request for the method "customBiddingAlgorithms.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/customBiddingAlgorithms/12345678.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/customBiddingAlgorithms/[^/]+$");

        /**
         * Retrieves the requested Ads Data Hub-managed custom bidding algorithm.
         *
         * Create a request for the method "customBiddingAlgorithms.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/customBiddingAlgorithms/12345678.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/customBiddingAlgorithms/12345678. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/customBiddingAlgorithms/12345678.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/customBiddingAlgorithms/12345678. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists the custom bidding algorithms managed by the specified Ads Data Hub customer.
       *
       * Create a request for the method "customBiddingAlgorithms.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListCustomBiddingAlgorithmsResponse> {

        private static final String REST_PATH = "v1/{+parent}/customBiddingAlgorithms";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists the custom bidding algorithms managed by the specified Ads Data Hub customer.
         *
         * Create a request for the method "customBiddingAlgorithms.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListCustomBiddingAlgorithmsResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of custom
         * bidding algorithms to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of custom bidding
       algorithms to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of custom
         * bidding algorithms to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /** Page token, returned by a previous call, used to request the next page of results. */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /** Page token, returned by a previous call, used to request the next page of results. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** If set to true, deleted custom bidding algorithms will be included in the response. */
        @com.google.api.client.util.Key
        private java.lang.Boolean showDeleted;

        /** If set to true, deleted custom bidding algorithms will be included in the response.
         */
        public java.lang.Boolean getShowDeleted() {
          return showDeleted;
        }

        /** If set to true, deleted custom bidding algorithms will be included in the response. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setShowDeleted(java.lang.Boolean showDeleted) {
          this.showDeleted = showDeleted;
          return this;
        }

        /**
         * Example filter: title = "cba name" AND dv360_partner_id = 1 AND custom_bidding_query =
         * "customers/744124092/customBiddingQueries/1a65fdb103db4e9e9e30085ce6381e26" AND
         * delete_time > "2012-04-21T11:30:00-04:00" AND create_email = "creator@email.com"
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Example filter: title = "cba name" AND dv360_partner_id = 1 AND custom_bidding_query =
       "customers/744124092/customBiddingQueries/1a65fdb103db4e9e9e30085ce6381e26" AND delete_time >
       "2012-04-21T11:30:00-04:00" AND create_email = "creator@email.com"
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Example filter: title = "cba name" AND dv360_partner_id = 1 AND custom_bidding_query =
         * "customers/744124092/customBiddingQueries/1a65fdb103db4e9e9e30085ce6381e26" AND
         * delete_time > "2012-04-21T11:30:00-04:00" AND create_email = "creator@email.com"
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }
      /**
       * Updates the requested Ads Data Hub-managed custom bidding algorithm.
       *
       * Create a request for the method "customBiddingAlgorithms.patch".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       *
       * @param name Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It has the form
       *        customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm}
       * @return the request
       */
      public Patch patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm content) throws java.io.IOException {
        Patch result = new Patch(name, content);
        initialize(result);
        return result;
      }

      public class Patch extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/customBiddingAlgorithms/[^/]+$");

        /**
         * Updates the requested Ads Data Hub-managed custom bidding algorithm.
         *
         * Create a request for the method "customBiddingAlgorithms.patch".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
         * <p> {@link
         * Patch#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It has the form
       *        customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm}
         * @since 1.13
         */
        protected Patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm content) {
          super(AdsDataHub.this, "PATCH", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set$Xgafv(java.lang.String $Xgafv) {
          return (Patch) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAccessToken(java.lang.String accessToken) {
          return (Patch) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAlt(java.lang.String alt) {
          return (Patch) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setCallback(java.lang.String callback) {
          return (Patch) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setFields(java.lang.String fields) {
          return (Patch) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setKey(java.lang.String key) {
          return (Patch) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setOauthToken(java.lang.String oauthToken) {
          return (Patch) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Patch) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setQuotaUser(java.lang.String quotaUser) {
          return (Patch) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadType(java.lang.String uploadType) {
          return (Patch) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadProtocol(java.lang.String uploadProtocol) {
          return (Patch) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It
         * has the form
         * customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It has the
       form customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Output only. Name that uniquely identifies an Ads Data Hub custom bidding algorithm. It
         * has the form
         * customers/[customer_id]/customBiddingAlgorithms/[custom_bidding_algorithm_id]
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
          this.name = name;
          return this;
        }

        /**
         * Required. Field mask to support partial updates. Only the following paths may be updated
         * via the API: - title - dv360_advertiser_id
         */
        @com.google.api.client.util.Key
        private String updateMask;

        /** Required. Field mask to support partial updates. Only the following paths may be updated via the
       API: - title - dv360_advertiser_id
         */
        public String getUpdateMask() {
          return updateMask;
        }

        /**
         * Required. Field mask to support partial updates. Only the following paths may be updated
         * via the API: - title - dv360_advertiser_id
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setUpdateMask(String updateMask) {
          this.updateMask = updateMask;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set(String parameterName, Object value) {
          return (Patch) super.set(parameterName, value);
        }
      }
      /**
       * Remove a DV360 advertiser from the custom bidding algorithm's advertisers.
       *
       * Create a request for the method "customBiddingAlgorithms.removeAdvertiser".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link RemoveAdvertiser#execute()} method to invoke the remote operation.
       *
       * @param customBiddingAlgorithm Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.RemoveAdvertiserRequest}
       * @return the request
       */
      public RemoveAdvertiser removeAdvertiser(java.lang.String customBiddingAlgorithm, com.google.api.services.adsdatahub.v1.model.RemoveAdvertiserRequest content) throws java.io.IOException {
        RemoveAdvertiser result = new RemoveAdvertiser(customBiddingAlgorithm, content);
        initialize(result);
        return result;
      }

      public class RemoveAdvertiser extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm> {

        private static final String REST_PATH = "v1/{+customBiddingAlgorithm}:removeAdvertiser";

        private final java.util.regex.Pattern CUSTOM_BIDDING_ALGORITHM_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/customBiddingAlgorithms/[^/]+$");

        /**
         * Remove a DV360 advertiser from the custom bidding algorithm's advertisers.
         *
         * Create a request for the method "customBiddingAlgorithms.removeAdvertiser".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link RemoveAdvertiser#execute()} method to invoke the remote
         * operation. <p> {@link RemoveAdvertiser#initialize(com.google.api.client.googleapis.services.Abs
         * tractGoogleClientRequest)} must be called to initialize this instance immediately after
         * invoking the constructor. </p>
         *
         * @param customBiddingAlgorithm Required. Full resource name of a custom bidding algorithm, e.g.
       *        'customers/123/customBiddingAlgorithms/12345678.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.RemoveAdvertiserRequest}
         * @since 1.13
         */
        protected RemoveAdvertiser(java.lang.String customBiddingAlgorithm, com.google.api.services.adsdatahub.v1.model.RemoveAdvertiserRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.CustomBiddingAlgorithm.class);
          this.customBiddingAlgorithm = com.google.api.client.util.Preconditions.checkNotNull(customBiddingAlgorithm, "Required parameter customBiddingAlgorithm must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(CUSTOM_BIDDING_ALGORITHM_PATTERN.matcher(customBiddingAlgorithm).matches(),
                "Parameter customBiddingAlgorithm must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser set$Xgafv(java.lang.String $Xgafv) {
          return (RemoveAdvertiser) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setAccessToken(java.lang.String accessToken) {
          return (RemoveAdvertiser) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setAlt(java.lang.String alt) {
          return (RemoveAdvertiser) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setCallback(java.lang.String callback) {
          return (RemoveAdvertiser) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setFields(java.lang.String fields) {
          return (RemoveAdvertiser) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setKey(java.lang.String key) {
          return (RemoveAdvertiser) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setOauthToken(java.lang.String oauthToken) {
          return (RemoveAdvertiser) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (RemoveAdvertiser) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setQuotaUser(java.lang.String quotaUser) {
          return (RemoveAdvertiser) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setUploadType(java.lang.String uploadType) {
          return (RemoveAdvertiser) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser setUploadProtocol(java.lang.String uploadProtocol) {
          return (RemoveAdvertiser) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.api.client.util.Key
        private java.lang.String customBiddingAlgorithm;

        /** Required. Full resource name of a custom bidding algorithm, e.g.
       'customers/123/customBiddingAlgorithms/12345678.
         */
        public java.lang.String getCustomBiddingAlgorithm() {
          return customBiddingAlgorithm;
        }

        /**
         * Required. Full resource name of a custom bidding algorithm, e.g.
         * 'customers/123/customBiddingAlgorithms/12345678.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public RemoveAdvertiser setCustomBiddingAlgorithm(java.lang.String customBiddingAlgorithm) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(CUSTOM_BIDDING_ALGORITHM_PATTERN.matcher(customBiddingAlgorithm).matches(),
                "Parameter customBiddingAlgorithm must conform to the pattern " +
                "^customers/[^/]+/customBiddingAlgorithms/[^/]+$");
          }
          this.customBiddingAlgorithm = customBiddingAlgorithm;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveAdvertiser set(String parameterName, Object value) {
          return (RemoveAdvertiser) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the InboundCustomerLinks collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.InboundCustomerLinks.List request = adsdatahub.inboundCustomerLinks().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public InboundCustomerLinks inboundCustomerLinks() {
      return new InboundCustomerLinks();
    }

    /**
     * The "inboundCustomerLinks" collection of methods.
     */
    public class InboundCustomerLinks {

      /**
       * Lists links where another Ads Data Hub customer has granted access to the specified customer.
       * Both direct and indirect (propagated through management) links are included.
       *
       * Create a request for the method "inboundCustomerLinks.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListCustomerLinksResponse> {

        private static final String REST_PATH = "v1/{+parent}/inboundCustomerLinks";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists links where another Ads Data Hub customer has granted access to the specified customer.
         * Both direct and indirect (propagated through management) links are included.
         *
         * Create a request for the method "inboundCustomerLinks.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListCustomerLinksResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of linked
         * customers to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of linked customers
       to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of linked
         * customers to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results, if any.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name="customers/1/outboundCustomerLinks/3141" customer_id="314159" display_name="Some
         * account" status="REJECTED" update_time.seconds>unix_time
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Filters your response. Works using the following fields / formatting:
       name="customers/1/outboundCustomerLinks/3141" customer_id="314159" display_name="Some account"
       status="REJECTED" update_time.seconds>unix_time
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name="customers/1/outboundCustomerLinks/3141" customer_id="314159" display_name="Some
         * account" status="REJECTED" update_time.seconds>unix_time
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the OutboundCustomerLinks collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.OutboundCustomerLinks.List request = adsdatahub.outboundCustomerLinks().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public OutboundCustomerLinks outboundCustomerLinks() {
      return new OutboundCustomerLinks();
    }

    /**
     * The "outboundCustomerLinks" collection of methods.
     */
    public class OutboundCustomerLinks {

      /**
       * Lists links where the specified customer has granted access to other Ads Data Hub customers. Only
       * direct links are included.
       *
       * Create a request for the method "outboundCustomerLinks.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListCustomerLinksResponse> {

        private static final String REST_PATH = "v1/{+parent}/outboundCustomerLinks";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists links where the specified customer has granted access to other Ads Data Hub customers.
         * Only direct links are included.
         *
         * Create a request for the method "outboundCustomerLinks.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListCustomerLinksResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of linked
         * customers to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of linked customers
       to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of linked
         * customers to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results, if any.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name="customers/1/outboundCustomerLinks/3141" customer_id="314159" display_name="Some
         * account" status="REJECTED" update_time.seconds>unix_time
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Filters your response. Works using the following fields / formatting:
       name="customers/1/outboundCustomerLinks/3141" customer_id="314159" display_name="Some account"
       status="REJECTED" update_time.seconds>unix_time
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name="customers/1/outboundCustomerLinks/3141" customer_id="314159" display_name="Some
         * account" status="REJECTED" update_time.seconds>unix_time
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the Tables collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.Tables.List request = adsdatahub.tables().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Tables tables() {
      return new Tables();
    }

    /**
     * The "tables" collection of methods.
     */
    public class Tables {

      /**
       * Retrieves the requested Ads Data Hub table.
       *
       * Create a request for the method "tables.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/tables/adh.google_ads_impressions.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Table> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/tables/[^/]+$");

        /**
         * Retrieves the requested Ads Data Hub table.
         *
         * Create a request for the method "tables.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/tables/adh.google_ads_impressions.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.Table.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/tables/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/tables/adh.google_ads_impressions. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/tables/adh.google_ads_impressions.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/tables/adh.google_ads_impressions. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/tables/[^/]+$");
          }
          this.name = name;
          return this;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the ads data used by the
         * table. Only relevant if the table is an ADH table with ads data. Defaults to all linked
         * customers.
         */
        @com.google.api.client.util.Key
        private java.lang.Long adsDataCustomerId;

        /** Optional. Specific linked Ads Data Hub customer ID that owns the ads data used by the table. Only
       relevant if the table is an ADH table with ads data. Defaults to all linked customers.
         */
        public java.lang.Long getAdsDataCustomerId() {
          return adsDataCustomerId;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the ads data used by the
         * table. Only relevant if the table is an ADH table with ads data. Defaults to all linked
         * customers.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
          this.adsDataCustomerId = adsDataCustomerId;
          return this;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the match data for the
         * query. Only relevant if the table is an ADH table with match data. Defaults to all linked
         * customers.
         */
        @com.google.api.client.util.Key
        private java.lang.Long matchDataCustomerId;

        /** Optional. Specific linked Ads Data Hub customer ID that owns the match data for the query. Only
       relevant if the table is an ADH table with match data. Defaults to all linked customers.
         */
        public java.lang.Long getMatchDataCustomerId() {
          return matchDataCustomerId;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the match data for the
         * query. Only relevant if the table is an ADH table with match data. Defaults to all linked
         * customers.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
          this.matchDataCustomerId = matchDataCustomerId;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists the Ads Data Hub tables to which the specified customer has access.
       *
       * Create a request for the method "tables.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListTablesResponse> {

        private static final String REST_PATH = "v1/{+parent}/tables";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists the Ads Data Hub tables to which the specified customer has access.
         *
         * Create a request for the method "tables.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListTablesResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the ads data used by the
         * tables. Defaults to all the linked customers.
         */
        @com.google.api.client.util.Key
        private java.lang.Long adsDataCustomerId;

        /** Optional. Specific linked Ads Data Hub customer ID that owns the ads data used by the tables.
       Defaults to all the linked customers.
         */
        public java.lang.Long getAdsDataCustomerId() {
          return adsDataCustomerId;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the ads data used by the
         * tables. Defaults to all the linked customers.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
          this.adsDataCustomerId = adsDataCustomerId;
          return this;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the match data for the
         * query. Defaults to all the linked customers.
         */
        @com.google.api.client.util.Key
        private java.lang.Long matchDataCustomerId;

        /** Optional. Specific linked Ads Data Hub customer ID that owns the match data for the query. Defaults
       to all the linked customers.
         */
        public java.lang.Long getMatchDataCustomerId() {
          return matchDataCustomerId;
        }

        /**
         * Optional. Specific linked Ads Data Hub customer ID that owns the match data for the
         * query. Defaults to all the linked customers.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
          this.matchDataCustomerId = matchDataCustomerId;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of tables
         * to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of tables to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of tables
         * to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any. The page token must have been returned by a call with the same request parameters.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results, if any. The page
       token must have been returned by a call with the same request parameters.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any. The page token must have been returned by a call with the same request parameters.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the TempTables collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.TempTables.List request = adsdatahub.tempTables().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public TempTables tempTables() {
      return new TempTables();
    }

    /**
     * The "tempTables" collection of methods.
     */
    public class TempTables {

      /**
       * Retrieves the requested Ads Data Hub temp table.
       *
       * Create a request for the method "tempTables.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/tables/resource-id'.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.TempTable> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/tempTables/[^/]+$");

        /**
         * Retrieves the requested Ads Data Hub temp table.
         *
         * Create a request for the method "tempTables.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/tables/resource-id'.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.TempTable.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/tempTables/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/tables/resource-id'. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/tables/resource-id'.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/tables/resource-id'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/tempTables/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists the Ads Data Hub temp tables that the customer has created. Temp tables are created for a
       * specific ads data customer ID, match data customer ID, and query type.
       *
       * Create a request for the method "tempTables.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListTempTablesResponse> {

        private static final String REST_PATH = "v1/{+parent}/tempTables";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists the Ads Data Hub temp tables that the customer has created. Temp tables are created for a
         * specific ads data customer ID, match data customer ID, and query type.
         *
         * Create a request for the method "tempTables.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListTempTablesResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Optional. Linked Ads Data Hub customer ID used when executing the original temp table
         * queries. Defaults to the parent resource.
         */
        @com.google.api.client.util.Key
        private java.lang.Long adsDataCustomerId;

        /** Optional. Linked Ads Data Hub customer ID used when executing the original temp table queries.
       Defaults to the parent resource.
         */
        public java.lang.Long getAdsDataCustomerId() {
          return adsDataCustomerId;
        }

        /**
         * Optional. Linked Ads Data Hub customer ID used when executing the original temp table
         * queries. Defaults to the parent resource.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setAdsDataCustomerId(java.lang.Long adsDataCustomerId) {
          this.adsDataCustomerId = adsDataCustomerId;
          return this;
        }

        /**
         * Optional. Linked Ads Data Hub customer ID used when executing the original temp table
         * queries. Defaults to the parent resource.
         */
        @com.google.api.client.util.Key
        private java.lang.Long matchDataCustomerId;

        /** Optional. Linked Ads Data Hub customer ID used when executing the original temp table queries.
       Defaults to the parent resource.
         */
        public java.lang.Long getMatchDataCustomerId() {
          return matchDataCustomerId;
        }

        /**
         * Optional. Linked Ads Data Hub customer ID used when executing the original temp table
         * queries. Defaults to the parent resource.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setMatchDataCustomerId(java.lang.Long matchDataCustomerId) {
          this.matchDataCustomerId = matchDataCustomerId;
          return this;
        }

        /**
         * Type of query that created the tables. Temp tables are only accessible to to queries of
         * the same type.
         */
        @com.google.api.client.util.Key
        private java.lang.String queryType;

        /** Type of query that created the tables. Temp tables are only accessible to to queries of the same
       type.
         */
        public java.lang.String getQueryType() {
          return queryType;
        }

        /**
         * Type of query that created the tables. Temp tables are only accessible to to queries of
         * the same type.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setQueryType(java.lang.String queryType) {
          this.queryType = queryType;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of tables
         * to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of tables to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of tables
         * to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any. The page token must have been returned by a call with the same request parameters.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results, if any. The page
       token must have been returned by a call with the same request parameters.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Page token, returned by a previous call, used to request the next page of results, if
         * any. The page token must have been returned by a call with the same request parameters.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the UserListQueries collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.UserListQueries.List request = adsdatahub.userListQueries().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public UserListQueries userListQueries() {
      return new UserListQueries();
    }

    /**
     * The "userListQueries" collection of methods.
     */
    public class UserListQueries {

      /**
       * Creates a user list query for later execution. No query validation is performed at this time.
       *
       * Create a request for the method "userListQueries.create".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Create#execute()} method to invoke the remote operation.
       *
       * @param parent Required. The parent resource name that owns the query, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserListQuery}
       * @return the request
       */
      public Create create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.UserListQuery content) throws java.io.IOException {
        Create result = new Create(parent, content);
        initialize(result);
        return result;
      }

      public class Create extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserListQuery> {

        private static final String REST_PATH = "v1/{+parent}/userListQueries";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Creates a user list query for later execution. No query validation is performed at this time.
         *
         * Create a request for the method "userListQueries.create".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Create#execute()} method to invoke the remote operation.
         * <p> {@link
         * Create#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. The parent resource name that owns the query, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserListQuery}
         * @since 1.13
         */
        protected Create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.UserListQuery content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserListQuery.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set$Xgafv(java.lang.String $Xgafv) {
          return (Create) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAccessToken(java.lang.String accessToken) {
          return (Create) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAlt(java.lang.String alt) {
          return (Create) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setCallback(java.lang.String callback) {
          return (Create) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setFields(java.lang.String fields) {
          return (Create) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setKey(java.lang.String key) {
          return (Create) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setOauthToken(java.lang.String oauthToken) {
          return (Create) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Create) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setQuotaUser(java.lang.String quotaUser) {
          return (Create) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadType(java.lang.String uploadType) {
          return (Create) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadProtocol(java.lang.String uploadProtocol) {
          return (Create) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. The parent resource name that owns the query, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Create setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set(String parameterName, Object value) {
          return (Create) super.set(parameterName, value);
        }
      }
      /**
       * Deletes a user list query.
       *
       * Create a request for the method "userListQueries.delete".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       *
       * @param name Required. The full name of the user list query to delete. This is of the form
       *        'customers/[customer_id]/userListQueries/[resource_id]', e.g.
       *        'customers/123/userListQueries/resource123'.
       * @return the request
       */
      public Delete delete(java.lang.String name) throws java.io.IOException {
        Delete result = new Delete(name);
        initialize(result);
        return result;
      }

      public class Delete extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Empty> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userListQueries/[^/]+$");

        /**
         * Deletes a user list query.
         *
         * Create a request for the method "userListQueries.delete".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
         * <p> {@link
         * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. The full name of the user list query to delete. This is of the form
       *        'customers/[customer_id]/userListQueries/[resource_id]', e.g.
       *        'customers/123/userListQueries/resource123'.
         * @since 1.13
         */
        protected Delete(java.lang.String name) {
          super(AdsDataHub.this, "DELETE", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.Empty.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set$Xgafv(java.lang.String $Xgafv) {
          return (Delete) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAccessToken(java.lang.String accessToken) {
          return (Delete) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAlt(java.lang.String alt) {
          return (Delete) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setCallback(java.lang.String callback) {
          return (Delete) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setFields(java.lang.String fields) {
          return (Delete) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setKey(java.lang.String key) {
          return (Delete) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setOauthToken(java.lang.String oauthToken) {
          return (Delete) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Delete) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setQuotaUser(java.lang.String quotaUser) {
          return (Delete) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadType(java.lang.String uploadType) {
          return (Delete) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadProtocol(java.lang.String uploadProtocol) {
          return (Delete) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The full name of the user list query to delete. This is of the form
         * 'customers/[customer_id]/userListQueries/[resource_id]', e.g.
         * 'customers/123/userListQueries/resource123'.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. The full name of the user list query to delete. This is of the form
       'customers/[customer_id]/userListQueries/[resource_id]', e.g.
       'customers/123/userListQueries/resource123'.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Required. The full name of the user list query to delete. This is of the form
         * 'customers/[customer_id]/userListQueries/[resource_id]', e.g.
         * 'customers/123/userListQueries/resource123'.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Delete setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set(String parameterName, Object value) {
          return (Delete) super.set(parameterName, value);
        }
      }
      /**
       * Retrieves the requested user list query.
       *
       * Create a request for the method "userListQueries.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/userListQueries/abcd1234'.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserListQuery> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userListQueries/[^/]+$");

        /**
         * Retrieves the requested user list query.
         *
         * Create a request for the method "userListQueries.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/userListQueries/abcd1234'.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.UserListQuery.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/userListQueries/abcd1234'. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/userListQueries/abcd1234'.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/userListQueries/abcd1234'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists the user list queries owned by the specified customer.
       *
       * Create a request for the method "userListQueries.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListUserListQueriesResponse> {

        private static final String REST_PATH = "v1/{+parent}/userListQueries";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists the user list queries owned by the specified customer.
         *
         * Create a request for the method "userListQueries.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListUserListQueriesResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, The server will determine the number of queries
         * to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, The server will determine the number of queries to return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, The server will determine the number of queries
         * to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /** Page token, returned by a previous call, used to request the next page of results. */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /** Page token, returned by a previous call, used to request the next page of results. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name=”customers/271828/userListQueries/pi314159265359” title=”up_and_right”
         * query_text="SELECT LN(2.7182818284);" query_state="RUNNABLE" update_time>unix_seconds
         * update_email=”abc@gmail.com” create_time>unix_seconds create_email=”abc@gmail.com”
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Filters your response. Works using the following fields / formatting:
       name=”customers/271828/userListQueries/pi314159265359” title=”up_and_right” query_text="SELECT
       LN(2.7182818284);" query_state="RUNNABLE" update_time>unix_seconds update_email=”abc@gmail.com”
       create_time>unix_seconds create_email=”abc@gmail.com”
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Filters your response. Works using the following fields / formatting:
         * name=”customers/271828/userListQueries/pi314159265359” title=”up_and_right”
         * query_text="SELECT LN(2.7182818284);" query_state="RUNNABLE" update_time>unix_seconds
         * update_email=”abc@gmail.com” create_time>unix_seconds create_email=”abc@gmail.com”
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }
      /**
       * Updates an existing user list query. Partial updates are supported. The following query fields
       * cannot be updated using this method and will be ignored: - create_time - create_email -
       * update_time - update_email
       *
       * Create a request for the method "userListQueries.patch".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       *
       * @param name Name that uniquely identifies a query. It has the form
       *        customers/[customer_id]/userListQueries/[resource_id], e.g.
       *        'customers/123/userListQueries/abcd1234'. The resource ID is generated by the server.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserListQuery}
       * @return the request
       */
      public Patch patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.UserListQuery content) throws java.io.IOException {
        Patch result = new Patch(name, content);
        initialize(result);
        return result;
      }

      public class Patch extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserListQuery> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userListQueries/[^/]+$");

        /**
         * Updates an existing user list query. Partial updates are supported. The following query fields
         * cannot be updated using this method and will be ignored: - create_time - create_email -
         * update_time - update_email
         *
         * Create a request for the method "userListQueries.patch".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
         * <p> {@link
         * Patch#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Name that uniquely identifies a query. It has the form
       *        customers/[customer_id]/userListQueries/[resource_id], e.g.
       *        'customers/123/userListQueries/abcd1234'. The resource ID is generated by the server.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserListQuery}
         * @since 1.13
         */
        protected Patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.UserListQuery content) {
          super(AdsDataHub.this, "PATCH", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserListQuery.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set$Xgafv(java.lang.String $Xgafv) {
          return (Patch) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAccessToken(java.lang.String accessToken) {
          return (Patch) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAlt(java.lang.String alt) {
          return (Patch) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setCallback(java.lang.String callback) {
          return (Patch) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setFields(java.lang.String fields) {
          return (Patch) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setKey(java.lang.String key) {
          return (Patch) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setOauthToken(java.lang.String oauthToken) {
          return (Patch) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Patch) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setQuotaUser(java.lang.String quotaUser) {
          return (Patch) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadType(java.lang.String uploadType) {
          return (Patch) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadProtocol(java.lang.String uploadProtocol) {
          return (Patch) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Name that uniquely identifies a query. It has the form
         * customers/[customer_id]/userListQueries/[resource_id], e.g.
         * 'customers/123/userListQueries/abcd1234'. The resource ID is generated by the server.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Name that uniquely identifies a query. It has the form
       customers/[customer_id]/userListQueries/[resource_id], e.g.
       'customers/123/userListQueries/abcd1234'. The resource ID is generated by the server.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Name that uniquely identifies a query. It has the form
         * customers/[customer_id]/userListQueries/[resource_id], e.g.
         * 'customers/123/userListQueries/abcd1234'. The resource ID is generated by the server.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        /** Field mask used to support partial updates. */
        @com.google.api.client.util.Key
        private String updateMask;

        /** Field mask used to support partial updates.
         */
        public String getUpdateMask() {
          return updateMask;
        }

        /** Field mask used to support partial updates. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setUpdateMask(String updateMask) {
          this.updateMask = updateMask;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set(String parameterName, Object value) {
          return (Patch) super.set(parameterName, value);
        }
      }
      /**
       * Starts execution on a stored user list query. The results uploaded to the specified Google Ads
       * user list. The returned operation name can be used to poll for query completion status.
       *
       * Create a request for the method "userListQueries.start".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Start#execute()} method to invoke the remote operation.
       *
       * @param name Full resource name, e.g. 'customers/123/userListQueries/abcd1234'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartUserListQueryRequest}
       * @return the request
       */
      public Start start(java.lang.String name, com.google.api.services.adsdatahub.v1.model.StartUserListQueryRequest content) throws java.io.IOException {
        Start result = new Start(name, content);
        initialize(result);
        return result;
      }

      public class Start extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

        private static final String REST_PATH = "v1/{+name}:start";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userListQueries/[^/]+$");

        /**
         * Starts execution on a stored user list query. The results uploaded to the specified Google Ads
         * user list. The returned operation name can be used to poll for query completion status.
         *
         * Create a request for the method "userListQueries.start".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Start#execute()} method to invoke the remote operation.
         * <p> {@link
         * Start#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Full resource name, e.g. 'customers/123/userListQueries/abcd1234'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartUserListQueryRequest}
         * @since 1.13
         */
        protected Start(java.lang.String name, com.google.api.services.adsdatahub.v1.model.StartUserListQueryRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start set$Xgafv(java.lang.String $Xgafv) {
          return (Start) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setAccessToken(java.lang.String accessToken) {
          return (Start) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setAlt(java.lang.String alt) {
          return (Start) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setCallback(java.lang.String callback) {
          return (Start) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setFields(java.lang.String fields) {
          return (Start) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setKey(java.lang.String key) {
          return (Start) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setOauthToken(java.lang.String oauthToken) {
          return (Start) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Start) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setQuotaUser(java.lang.String quotaUser) {
          return (Start) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setUploadType(java.lang.String uploadType) {
          return (Start) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start setUploadProtocol(java.lang.String uploadProtocol) {
          return (Start) super.setUploadProtocol(uploadProtocol);
        }

        /** Full resource name, e.g. 'customers/123/userListQueries/abcd1234'. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Full resource name, e.g. 'customers/123/userListQueries/abcd1234'.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Full resource name, e.g. 'customers/123/userListQueries/abcd1234'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Start setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userListQueries/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Start set(String parameterName, Object value) {
          return (Start) super.set(parameterName, value);
        }
      }
      /**
       * Starts execution on a transient user list query. The results uploaded to the specified Google Ads
       * user list. The returned operation name can be used to poll for query completion status.
       *
       * Create a request for the method "userListQueries.startTransient".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link StartTransient#execute()} method to invoke the remote operation.
       *
       * @param parent Full resource name of the customer executing the query, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartTransientUserListQueryRequest}
       * @return the request
       */
      public StartTransient startTransient(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.StartTransientUserListQueryRequest content) throws java.io.IOException {
        StartTransient result = new StartTransient(parent, content);
        initialize(result);
        return result;
      }

      public class StartTransient extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

        private static final String REST_PATH = "v1/{+parent}/userListQueries:startTransient";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Starts execution on a transient user list query. The results uploaded to the specified Google
         * Ads user list. The returned operation name can be used to poll for query completion status.
         *
         * Create a request for the method "userListQueries.startTransient".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link StartTransient#execute()} method to invoke the remote
         * operation. <p> {@link StartTransient#initialize(com.google.api.client.googleapis.services.Abstr
         * actGoogleClientRequest)} must be called to initialize this instance immediately after invoking
         * the constructor. </p>
         *
         * @param parent Full resource name of the customer executing the query, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.StartTransientUserListQueryRequest}
         * @since 1.13
         */
        protected StartTransient(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.StartTransientUserListQueryRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient set$Xgafv(java.lang.String $Xgafv) {
          return (StartTransient) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setAccessToken(java.lang.String accessToken) {
          return (StartTransient) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setAlt(java.lang.String alt) {
          return (StartTransient) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setCallback(java.lang.String callback) {
          return (StartTransient) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setFields(java.lang.String fields) {
          return (StartTransient) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setKey(java.lang.String key) {
          return (StartTransient) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setOauthToken(java.lang.String oauthToken) {
          return (StartTransient) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (StartTransient) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setQuotaUser(java.lang.String quotaUser) {
          return (StartTransient) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setUploadType(java.lang.String uploadType) {
          return (StartTransient) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient setUploadProtocol(java.lang.String uploadProtocol) {
          return (StartTransient) super.setUploadProtocol(uploadProtocol);
        }

        /** Full resource name of the customer executing the query, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Full resource name of the customer executing the query, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Full resource name of the customer executing the query, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public StartTransient setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public StartTransient set(String parameterName, Object value) {
          return (StartTransient) super.set(parameterName, value);
        }
      }
      /**
       * Performs static validation checks on the provided user list query.
       *
       * Create a request for the method "userListQueries.validate".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Validate#execute()} method to invoke the remote operation.
       *
       * @param parent The parent resource name that owns the query, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.ValidateUserListQueryRequest}
       * @return the request
       */
      public Validate validate(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.ValidateUserListQueryRequest content) throws java.io.IOException {
        Validate result = new Validate(parent, content);
        initialize(result);
        return result;
      }

      public class Validate extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ValidateUserListQueryResponse> {

        private static final String REST_PATH = "v1/{+parent}/userListQueries:validate";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Performs static validation checks on the provided user list query.
         *
         * Create a request for the method "userListQueries.validate".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Validate#execute()} method to invoke the remote operation.
         * <p> {@link
         * Validate#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent The parent resource name that owns the query, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.ValidateUserListQueryRequest}
         * @since 1.13
         */
        protected Validate(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.ValidateUserListQueryRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.ValidateUserListQueryResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate set$Xgafv(java.lang.String $Xgafv) {
          return (Validate) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setAccessToken(java.lang.String accessToken) {
          return (Validate) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setAlt(java.lang.String alt) {
          return (Validate) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setCallback(java.lang.String callback) {
          return (Validate) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setFields(java.lang.String fields) {
          return (Validate) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setKey(java.lang.String key) {
          return (Validate) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setOauthToken(java.lang.String oauthToken) {
          return (Validate) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Validate) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setQuotaUser(java.lang.String quotaUser) {
          return (Validate) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setUploadType(java.lang.String uploadType) {
          return (Validate) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate setUploadProtocol(java.lang.String uploadProtocol) {
          return (Validate) super.setUploadProtocol(uploadProtocol);
        }

        /** The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** The parent resource name that owns the query, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** The parent resource name that owns the query, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Validate setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Validate set(String parameterName, Object value) {
          return (Validate) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the UserLists collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
     *   {@code AdsDataHub.UserLists.List request = adsdatahub.userLists().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public UserLists userLists() {
      return new UserLists();
    }

    /**
     * The "userLists" collection of methods.
     */
    public class UserLists {

      /**
       * Adds event matchers to a frequency-based user list. This call cannot delete existing event
       * matchers or modify frequency-based constraint metadata such as window or when a user is added.
       * The user list may already contain some event matchers. For example, this call could add:
       * AddEventMatchersRequest { user_list: "customers/1/userLists/12345" event_matchers { match_type:
       * GOOGLE_ADS_CAMPAIGN_ID value: "3456" } } For this call to succeed, user list 12345 should not
       * already contain a campaign constraint of the type GOOGLE_ADS_CAMPAIGN_ID with campaign id "3456".
       *
       * Create a request for the method "userLists.addEventMatchers".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link AddEventMatchers#execute()} method to invoke the remote operation.
       *
       * @param userList Required. Full resource name, has the form of ‘customers/[customer_id]/userLists/[userlist_id]’.
       *        UserList must have UserListType FREQUENCY_BASED.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.AddEventMatchersRequest}
       * @return the request
       */
      public AddEventMatchers addEventMatchers(java.lang.String userList, com.google.api.services.adsdatahub.v1.model.AddEventMatchersRequest content) throws java.io.IOException {
        AddEventMatchers result = new AddEventMatchers(userList, content);
        initialize(result);
        return result;
      }

      public class AddEventMatchers extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+userList}:addEventMatchers";

        private final java.util.regex.Pattern USER_LIST_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Adds event matchers to a frequency-based user list. This call cannot delete existing event
         * matchers or modify frequency-based constraint metadata such as window or when a user is added.
         * The user list may already contain some event matchers. For example, this call could add:
         * AddEventMatchersRequest { user_list: "customers/1/userLists/12345" event_matchers { match_type:
         * GOOGLE_ADS_CAMPAIGN_ID value: "3456" } } For this call to succeed, user list 12345 should not
         * already contain a campaign constraint of the type GOOGLE_ADS_CAMPAIGN_ID with campaign id
         * "3456".
         *
         * Create a request for the method "userLists.addEventMatchers".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link AddEventMatchers#execute()} method to invoke the remote
         * operation. <p> {@link AddEventMatchers#initialize(com.google.api.client.googleapis.services.Abs
         * tractGoogleClientRequest)} must be called to initialize this instance immediately after
         * invoking the constructor. </p>
         *
         * @param userList Required. Full resource name, has the form of ‘customers/[customer_id]/userLists/[userlist_id]’.
       *        UserList must have UserListType FREQUENCY_BASED.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.AddEventMatchersRequest}
         * @since 1.13
         */
        protected AddEventMatchers(java.lang.String userList, com.google.api.services.adsdatahub.v1.model.AddEventMatchersRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.userList = com.google.api.client.util.Preconditions.checkNotNull(userList, "Required parameter userList must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(USER_LIST_PATTERN.matcher(userList).matches(),
                "Parameter userList must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers set$Xgafv(java.lang.String $Xgafv) {
          return (AddEventMatchers) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setAccessToken(java.lang.String accessToken) {
          return (AddEventMatchers) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setAlt(java.lang.String alt) {
          return (AddEventMatchers) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setCallback(java.lang.String callback) {
          return (AddEventMatchers) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setFields(java.lang.String fields) {
          return (AddEventMatchers) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setKey(java.lang.String key) {
          return (AddEventMatchers) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setOauthToken(java.lang.String oauthToken) {
          return (AddEventMatchers) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (AddEventMatchers) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setQuotaUser(java.lang.String quotaUser) {
          return (AddEventMatchers) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setUploadType(java.lang.String uploadType) {
          return (AddEventMatchers) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers setUploadProtocol(java.lang.String uploadProtocol) {
          return (AddEventMatchers) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name, has the form of
         * ‘customers/[customer_id]/userLists/[userlist_id]’. UserList must have UserListType
         * FREQUENCY_BASED.
         */
        @com.google.api.client.util.Key
        private java.lang.String userList;

        /** Required. Full resource name, has the form of ‘customers/[customer_id]/userLists/[userlist_id]’.
       UserList must have UserListType FREQUENCY_BASED.
         */
        public java.lang.String getUserList() {
          return userList;
        }

        /**
         * Required. Full resource name, has the form of
         * ‘customers/[customer_id]/userLists/[userlist_id]’. UserList must have UserListType
         * FREQUENCY_BASED.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public AddEventMatchers setUserList(java.lang.String userList) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(USER_LIST_PATTERN.matcher(userList).matches(),
                "Parameter userList must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.userList = userList;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddEventMatchers set(String parameterName, Object value) {
          return (AddEventMatchers) super.set(parameterName, value);
        }
      }
      /**
       * Add entities to an Ads Data Hub-managed user list’s recipients. Supported entities are: - Google
       * Ads Customer - DV360 Partner - DV360 Advertiser These entities must be linked to the ads data
       * customer associated with the UserList.
       *
       * Create a request for the method "userLists.addRecipients".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link AddRecipients#execute()} method to invoke the remote operation.
       *
       * @param userList Required. Full resource name of the user list to be updated. Has the form of
       *        customers/[customer_id]/userLists/[userlist_id]
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.AddRecipientsRequest}
       * @return the request
       */
      public AddRecipients addRecipients(java.lang.String userList, com.google.api.services.adsdatahub.v1.model.AddRecipientsRequest content) throws java.io.IOException {
        AddRecipients result = new AddRecipients(userList, content);
        initialize(result);
        return result;
      }

      public class AddRecipients extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+userList}:addRecipients";

        private final java.util.regex.Pattern USER_LIST_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Add entities to an Ads Data Hub-managed user list’s recipients. Supported entities are: -
         * Google Ads Customer - DV360 Partner - DV360 Advertiser These entities must be linked to the ads
         * data customer associated with the UserList.
         *
         * Create a request for the method "userLists.addRecipients".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link AddRecipients#execute()} method to invoke the remote
         * operation. <p> {@link AddRecipients#initialize(com.google.api.client.googleapis.services.Abstra
         * ctGoogleClientRequest)} must be called to initialize this instance immediately after invoking
         * the constructor. </p>
         *
         * @param userList Required. Full resource name of the user list to be updated. Has the form of
       *        customers/[customer_id]/userLists/[userlist_id]
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.AddRecipientsRequest}
         * @since 1.13
         */
        protected AddRecipients(java.lang.String userList, com.google.api.services.adsdatahub.v1.model.AddRecipientsRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.userList = com.google.api.client.util.Preconditions.checkNotNull(userList, "Required parameter userList must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(USER_LIST_PATTERN.matcher(userList).matches(),
                "Parameter userList must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients set$Xgafv(java.lang.String $Xgafv) {
          return (AddRecipients) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setAccessToken(java.lang.String accessToken) {
          return (AddRecipients) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setAlt(java.lang.String alt) {
          return (AddRecipients) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setCallback(java.lang.String callback) {
          return (AddRecipients) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setFields(java.lang.String fields) {
          return (AddRecipients) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setKey(java.lang.String key) {
          return (AddRecipients) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setOauthToken(java.lang.String oauthToken) {
          return (AddRecipients) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (AddRecipients) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setQuotaUser(java.lang.String quotaUser) {
          return (AddRecipients) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setUploadType(java.lang.String uploadType) {
          return (AddRecipients) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients setUploadProtocol(java.lang.String uploadProtocol) {
          return (AddRecipients) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name of the user list to be updated. Has the form of
         * customers/[customer_id]/userLists/[userlist_id]
         */
        @com.google.api.client.util.Key
        private java.lang.String userList;

        /** Required. Full resource name of the user list to be updated. Has the form of
       customers/[customer_id]/userLists/[userlist_id]
         */
        public java.lang.String getUserList() {
          return userList;
        }

        /**
         * Required. Full resource name of the user list to be updated. Has the form of
         * customers/[customer_id]/userLists/[userlist_id]
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public AddRecipients setUserList(java.lang.String userList) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(USER_LIST_PATTERN.matcher(userList).matches(),
                "Parameter userList must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.userList = userList;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public AddRecipients set(String parameterName, Object value) {
          return (AddRecipients) super.set(parameterName, value);
        }
      }
      /**
       * Creates an Ads Data Hub-managed user list.
       *
       * Create a request for the method "userLists.create".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Create#execute()} method to invoke the remote operation.
       *
       * @param parent Required. The parent resource name that owns the user list, e.g. 'customers/123'.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserList}
       * @return the request
       */
      public Create create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.UserList content) throws java.io.IOException {
        Create result = new Create(parent, content);
        initialize(result);
        return result;
      }

      public class Create extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+parent}/userLists";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Creates an Ads Data Hub-managed user list.
         *
         * Create a request for the method "userLists.create".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Create#execute()} method to invoke the remote operation.
         * <p> {@link
         * Create#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. The parent resource name that owns the user list, e.g. 'customers/123'.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserList}
         * @since 1.13
         */
        protected Create(java.lang.String parent, com.google.api.services.adsdatahub.v1.model.UserList content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set$Xgafv(java.lang.String $Xgafv) {
          return (Create) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAccessToken(java.lang.String accessToken) {
          return (Create) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setAlt(java.lang.String alt) {
          return (Create) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setCallback(java.lang.String callback) {
          return (Create) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setFields(java.lang.String fields) {
          return (Create) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setKey(java.lang.String key) {
          return (Create) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setOauthToken(java.lang.String oauthToken) {
          return (Create) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Create) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setQuotaUser(java.lang.String quotaUser) {
          return (Create) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadType(java.lang.String uploadType) {
          return (Create) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create setUploadProtocol(java.lang.String uploadProtocol) {
          return (Create) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. The parent resource name that owns the user list, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. The parent resource name that owns the user list, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. The parent resource name that owns the user list, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Create setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Create set(String parameterName, Object value) {
          return (Create) super.set(parameterName, value);
        }
      }
      /**
       * Delete the requested Ads Data Hub-managed user list.
       *
       * Create a request for the method "userLists.delete".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/userLists/12345678.
       * @return the request
       */
      public Delete delete(java.lang.String name) throws java.io.IOException {
        Delete result = new Delete(name);
        initialize(result);
        return result;
      }

      public class Delete extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Delete the requested Ads Data Hub-managed user list.
         *
         * Create a request for the method "userLists.delete".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
         * <p> {@link
         * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/userLists/12345678.
         * @since 1.13
         */
        protected Delete(java.lang.String name) {
          super(AdsDataHub.this, "DELETE", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set$Xgafv(java.lang.String $Xgafv) {
          return (Delete) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAccessToken(java.lang.String accessToken) {
          return (Delete) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setAlt(java.lang.String alt) {
          return (Delete) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setCallback(java.lang.String callback) {
          return (Delete) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setFields(java.lang.String fields) {
          return (Delete) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setKey(java.lang.String key) {
          return (Delete) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setOauthToken(java.lang.String oauthToken) {
          return (Delete) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Delete) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setQuotaUser(java.lang.String quotaUser) {
          return (Delete) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadType(java.lang.String uploadType) {
          return (Delete) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete setUploadProtocol(java.lang.String uploadProtocol) {
          return (Delete) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/userLists/12345678. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/userLists/12345678.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/userLists/12345678. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Delete setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Delete set(String parameterName, Object value) {
          return (Delete) super.set(parameterName, value);
        }
      }
      /**
       * Generate memberships for the UserList. The UserList must have UserListType FREQUENCY_BASED.
       *
       * Create a request for the method "userLists.generateFrequencyListMemberships".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link GenerateFrequencyListMemberships#execute()} method to invoke the
       * remote operation.
       *
       * @param name Full resource name, e.g. 'customers/123/userLists/12345678'. UserList must have UserListType
       *        FREQUENCY_BASED.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.GenerateFrequencyListMembershipsRequest}
       * @return the request
       */
      public GenerateFrequencyListMemberships generateFrequencyListMemberships(java.lang.String name, com.google.api.services.adsdatahub.v1.model.GenerateFrequencyListMembershipsRequest content) throws java.io.IOException {
        GenerateFrequencyListMemberships result = new GenerateFrequencyListMemberships(name, content);
        initialize(result);
        return result;
      }

      public class GenerateFrequencyListMemberships extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

        private static final String REST_PATH = "v1/{+name}:generateFrequencyListMemberships";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Generate memberships for the UserList. The UserList must have UserListType FREQUENCY_BASED.
         *
         * Create a request for the method "userLists.generateFrequencyListMemberships".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link GenerateFrequencyListMemberships#execute()} method to
         * invoke the remote operation. <p> {@link GenerateFrequencyListMemberships#initialize(com.google.
         * api.client.googleapis.services.AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param name Full resource name, e.g. 'customers/123/userLists/12345678'. UserList must have UserListType
       *        FREQUENCY_BASED.
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.GenerateFrequencyListMembershipsRequest}
         * @since 1.13
         */
        protected GenerateFrequencyListMemberships(java.lang.String name, com.google.api.services.adsdatahub.v1.model.GenerateFrequencyListMembershipsRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships set$Xgafv(java.lang.String $Xgafv) {
          return (GenerateFrequencyListMemberships) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setAccessToken(java.lang.String accessToken) {
          return (GenerateFrequencyListMemberships) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setAlt(java.lang.String alt) {
          return (GenerateFrequencyListMemberships) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setCallback(java.lang.String callback) {
          return (GenerateFrequencyListMemberships) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setFields(java.lang.String fields) {
          return (GenerateFrequencyListMemberships) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setKey(java.lang.String key) {
          return (GenerateFrequencyListMemberships) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setOauthToken(java.lang.String oauthToken) {
          return (GenerateFrequencyListMemberships) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (GenerateFrequencyListMemberships) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setQuotaUser(java.lang.String quotaUser) {
          return (GenerateFrequencyListMemberships) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setUploadType(java.lang.String uploadType) {
          return (GenerateFrequencyListMemberships) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships setUploadProtocol(java.lang.String uploadProtocol) {
          return (GenerateFrequencyListMemberships) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Full resource name, e.g. 'customers/123/userLists/12345678'. UserList must have
         * UserListType FREQUENCY_BASED.
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Full resource name, e.g. 'customers/123/userLists/12345678'. UserList must have UserListType
       FREQUENCY_BASED.
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Full resource name, e.g. 'customers/123/userLists/12345678'. UserList must have
         * UserListType FREQUENCY_BASED.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public GenerateFrequencyListMemberships setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public GenerateFrequencyListMemberships set(String parameterName, Object value) {
          return (GenerateFrequencyListMemberships) super.set(parameterName, value);
        }
      }
      /**
       * Retrieves the requested Ads Data Hub-managed user list.
       *
       * Create a request for the method "userLists.get".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param name Required. Full resource name, e.g. 'customers/123/userLists/12345678.
       * @return the request
       */
      public Get get(java.lang.String name) throws java.io.IOException {
        Get result = new Get(name);
        initialize(result);
        return result;
      }

      public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Retrieves the requested Ads Data Hub-managed user list.
         *
         * Create a request for the method "userLists.get".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Required. Full resource name, e.g. 'customers/123/userLists/12345678.
         * @since 1.13
         */
        protected Get(java.lang.String name) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Full resource name, e.g. 'customers/123/userLists/12345678. */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Required. Full resource name, e.g. 'customers/123/userLists/12345678.
         */
        public java.lang.String getName() {
          return name;
        }

        /** Required. Full resource name, e.g. 'customers/123/userLists/12345678. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Get setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists the user lists managed by the specified Ads Data Hub customer.
       *
       * Create a request for the method "userLists.list".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
       * @return the request
       */
      public List list(java.lang.String parent) throws java.io.IOException {
        List result = new List(parent);
        initialize(result);
        return result;
      }

      public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListUserListsResponse> {

        private static final String REST_PATH = "v1/{+parent}/userLists";

        private final java.util.regex.Pattern PARENT_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+$");

        /**
         * Lists the user lists managed by the specified Ads Data Hub customer.
         *
         * Create a request for the method "userLists.list".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param parent Required. Parent customer resource name, e.g. 'customers/123'.
         * @since 1.13
         */
        protected List(java.lang.String parent) {
          super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListUserListsResponse.class);
          this.parent = com.google.api.client.util.Preconditions.checkNotNull(parent, "Required parameter parent must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.api.client.util.Key
        private java.lang.String parent;

        /** Required. Parent customer resource name, e.g. 'customers/123'.
         */
        public java.lang.String getParent() {
          return parent;
        }

        /** Required. Parent customer resource name, e.g. 'customers/123'. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setParent(java.lang.String parent) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PARENT_PATTERN.matcher(parent).matches(),
                "Parameter parent must conform to the pattern " +
                "^customers/[^/]+$");
          }
          this.parent = parent;
          return this;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of user
         * lists to return.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Maximum number of items to return. If 0, the server will determine the number of user lists to
       return.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Maximum number of items to return. If 0, the server will determine the number of user
         * lists to return.
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /** Page token, returned by a previous call, used to request the next page of results. */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Page token, returned by a previous call, used to request the next page of results.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /** Page token, returned by a previous call, used to request the next page of results. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Example filter: title = "user*" AND title = "*name*" AND -type = FREQUENCY_BASED AND
         * create_email = "creator@email.com" AND list_size > 10 AND populate_time >
         * "2012-04-21T11:30:00-04:00"
         */
        @com.google.api.client.util.Key
        private java.lang.String filter;

        /** Example filter: title = "user*" AND title = "*name*" AND -type = FREQUENCY_BASED AND create_email =
       "creator@email.com" AND list_size > 10 AND populate_time > "2012-04-21T11:30:00-04:00"
         */
        public java.lang.String getFilter() {
          return filter;
        }

        /**
         * Example filter: title = "user*" AND title = "*name*" AND -type = FREQUENCY_BASED AND
         * create_email = "creator@email.com" AND list_size > 10 AND populate_time >
         * "2012-04-21T11:30:00-04:00"
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setFilter(java.lang.String filter) {
          this.filter = filter;
          return this;
        }

        /** Specifies which fields to include in each user list. */
        @com.google.api.client.util.Key
        private java.lang.String view;

        /** Specifies which fields to include in each user list.
         */
        public java.lang.String getView() {
          return view;
        }

        /** Specifies which fields to include in each user list. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setView(java.lang.String view) {
          this.view = view;
          return this;
        }

        /** If set to true, deleted user lists will be included in the response. */
        @com.google.api.client.util.Key
        private java.lang.Boolean showDeleted;

        /** If set to true, deleted user lists will be included in the response.
         */
        public java.lang.Boolean getShowDeleted() {
          return showDeleted;
        }

        /** If set to true, deleted user lists will be included in the response. */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public List setShowDeleted(java.lang.Boolean showDeleted) {
          this.showDeleted = showDeleted;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }
      /**
       * Updates the requested Ads Data Hub-managed user list.
       *
       * Create a request for the method "userLists.patch".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       *
       * @param name Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
       *        customers/[customer_id]/userLists/[user_list_id]
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserList}
       * @return the request
       */
      public Patch patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.UserList content) throws java.io.IOException {
        Patch result = new Patch(name, content);
        initialize(result);
        return result;
      }

      public class Patch extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Updates the requested Ads Data Hub-managed user list.
         *
         * Create a request for the method "userLists.patch".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
         * <p> {@link
         * Patch#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
       *        customers/[customer_id]/userLists/[user_list_id]
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.UserList}
         * @since 1.13
         */
        protected Patch(java.lang.String name, com.google.api.services.adsdatahub.v1.model.UserList content) {
          super(AdsDataHub.this, "PATCH", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set$Xgafv(java.lang.String $Xgafv) {
          return (Patch) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAccessToken(java.lang.String accessToken) {
          return (Patch) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setAlt(java.lang.String alt) {
          return (Patch) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setCallback(java.lang.String callback) {
          return (Patch) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setFields(java.lang.String fields) {
          return (Patch) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setKey(java.lang.String key) {
          return (Patch) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setOauthToken(java.lang.String oauthToken) {
          return (Patch) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Patch) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setQuotaUser(java.lang.String quotaUser) {
          return (Patch) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadType(java.lang.String uploadType) {
          return (Patch) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch setUploadProtocol(java.lang.String uploadProtocol) {
          return (Patch) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
         * customers/[customer_id]/userLists/[user_list_id]
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
       customers/[customer_id]/userLists/[user_list_id]
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * Output only. Name that uniquely identifies an Ads Data Hub user list. It has the form
         * customers/[customer_id]/userLists/[user_list_id]
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.name = name;
          return this;
        }

        /**
         * Required. Field mask to support partial updates. Only the following paths may be updated
         * via the API: - title - description - recipient_ads_data_links
         */
        @com.google.api.client.util.Key
        private String updateMask;

        /** Required. Field mask to support partial updates. Only the following paths may be updated via the
       API: - title - description - recipient_ads_data_links
         */
        public String getUpdateMask() {
          return updateMask;
        }

        /**
         * Required. Field mask to support partial updates. Only the following paths may be updated
         * via the API: - title - description - recipient_ads_data_links
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public Patch setUpdateMask(String updateMask) {
          this.updateMask = updateMask;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public Patch set(String parameterName, Object value) {
          return (Patch) super.set(parameterName, value);
        }
      }
      /**
       * Removes entities from an Ads Data Hub-managed user list’s recipients. Supported entities are: -
       * Google Ads Customer - DV360 Partner - DV360 Advertiser These entities must be linked to the ads
       * data customer associated with the UserList.
       *
       * Create a request for the method "userLists.removeRecipients".
       *
       * This request holds the parameters needed by the adsdatahub server.  After setting any optional
       * parameters, call the {@link RemoveRecipients#execute()} method to invoke the remote operation.
       *
       * @param userList Required. Full resource name of the user list to be updated. Has the form of
       *        customers/[customer_id]/userLists/[userlist_id]
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.RemoveRecipientsRequest}
       * @return the request
       */
      public RemoveRecipients removeRecipients(java.lang.String userList, com.google.api.services.adsdatahub.v1.model.RemoveRecipientsRequest content) throws java.io.IOException {
        RemoveRecipients result = new RemoveRecipients(userList, content);
        initialize(result);
        return result;
      }

      public class RemoveRecipients extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.UserList> {

        private static final String REST_PATH = "v1/{+userList}:removeRecipients";

        private final java.util.regex.Pattern USER_LIST_PATTERN =
            java.util.regex.Pattern.compile("^customers/[^/]+/userLists/[^/]+$");

        /**
         * Removes entities from an Ads Data Hub-managed user list’s recipients. Supported entities are: -
         * Google Ads Customer - DV360 Partner - DV360 Advertiser These entities must be linked to the ads
         * data customer associated with the UserList.
         *
         * Create a request for the method "userLists.removeRecipients".
         *
         * This request holds the parameters needed by the the adsdatahub server.  After setting any
         * optional parameters, call the {@link RemoveRecipients#execute()} method to invoke the remote
         * operation. <p> {@link RemoveRecipients#initialize(com.google.api.client.googleapis.services.Abs
         * tractGoogleClientRequest)} must be called to initialize this instance immediately after
         * invoking the constructor. </p>
         *
         * @param userList Required. Full resource name of the user list to be updated. Has the form of
       *        customers/[customer_id]/userLists/[userlist_id]
         * @param content the {@link com.google.api.services.adsdatahub.v1.model.RemoveRecipientsRequest}
         * @since 1.13
         */
        protected RemoveRecipients(java.lang.String userList, com.google.api.services.adsdatahub.v1.model.RemoveRecipientsRequest content) {
          super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.UserList.class);
          this.userList = com.google.api.client.util.Preconditions.checkNotNull(userList, "Required parameter userList must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(USER_LIST_PATTERN.matcher(userList).matches(),
                "Parameter userList must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients set$Xgafv(java.lang.String $Xgafv) {
          return (RemoveRecipients) super.set$Xgafv($Xgafv);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setAccessToken(java.lang.String accessToken) {
          return (RemoveRecipients) super.setAccessToken(accessToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setAlt(java.lang.String alt) {
          return (RemoveRecipients) super.setAlt(alt);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setCallback(java.lang.String callback) {
          return (RemoveRecipients) super.setCallback(callback);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setFields(java.lang.String fields) {
          return (RemoveRecipients) super.setFields(fields);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setKey(java.lang.String key) {
          return (RemoveRecipients) super.setKey(key);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setOauthToken(java.lang.String oauthToken) {
          return (RemoveRecipients) super.setOauthToken(oauthToken);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (RemoveRecipients) super.setPrettyPrint(prettyPrint);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setQuotaUser(java.lang.String quotaUser) {
          return (RemoveRecipients) super.setQuotaUser(quotaUser);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setUploadType(java.lang.String uploadType) {
          return (RemoveRecipients) super.setUploadType(uploadType);
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients setUploadProtocol(java.lang.String uploadProtocol) {
          return (RemoveRecipients) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. Full resource name of the user list to be updated. Has the form of
         * customers/[customer_id]/userLists/[userlist_id]
         */
        @com.google.api.client.util.Key
        private java.lang.String userList;

        /** Required. Full resource name of the user list to be updated. Has the form of
       customers/[customer_id]/userLists/[userlist_id]
         */
        public java.lang.String getUserList() {
          return userList;
        }

        /**
         * Required. Full resource name of the user list to be updated. Has the form of
         * customers/[customer_id]/userLists/[userlist_id]
         */
        @com.google.errorprone.annotations.CanIgnoreReturnValue
        public RemoveRecipients setUserList(java.lang.String userList) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(USER_LIST_PATTERN.matcher(userList).matches(),
                "Parameter userList must conform to the pattern " +
                "^customers/[^/]+/userLists/[^/]+$");
          }
          this.userList = userList;
          return this;
        }

        @com.google.errorprone.annotations.CanIgnoreReturnValue
        @Override
        public RemoveRecipients set(String parameterName, Object value) {
          return (RemoveRecipients) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the Operations collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
   *   {@code AdsDataHub.Operations.List request = adsdatahub.operations().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Operations operations() {
    return new Operations();
  }

  /**
   * The "operations" collection of methods.
   */
  public class Operations {

    /**
     * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to
     * cancel the operation, but success is not guaranteed. If the server doesn't support this method,
     * it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other
     * methods to check whether the cancellation succeeded or whether the operation completed despite
     * cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an
     * operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to
     * `Code.CANCELLED`.
     *
     * Create a request for the method "operations.cancel".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link Cancel#execute()} method to invoke the remote operation.
     *
     * @param name The name of the operation resource to be cancelled.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.CancelOperationRequest}
     * @return the request
     */
    public Cancel cancel(java.lang.String name, com.google.api.services.adsdatahub.v1.model.CancelOperationRequest content) throws java.io.IOException {
      Cancel result = new Cancel(name, content);
      initialize(result);
      return result;
    }

    public class Cancel extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Empty> {

      private static final String REST_PATH = "v1/{+name}:cancel";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^operations/.*$");

      /**
       * Starts asynchronous cancellation on a long-running operation. The server makes a best effort to
       * cancel the operation, but success is not guaranteed. If the server doesn't support this method,
       * it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other
       * methods to check whether the cancellation succeeded or whether the operation completed despite
       * cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an
       * operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to
       * `Code.CANCELLED`.
       *
       * Create a request for the method "operations.cancel".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link Cancel#execute()} method to invoke the remote operation.
       * <p> {@link
       * Cancel#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param name The name of the operation resource to be cancelled.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.CancelOperationRequest}
       * @since 1.13
       */
      protected Cancel(java.lang.String name, com.google.api.services.adsdatahub.v1.model.CancelOperationRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Empty.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel set$Xgafv(java.lang.String $Xgafv) {
        return (Cancel) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setAccessToken(java.lang.String accessToken) {
        return (Cancel) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setAlt(java.lang.String alt) {
        return (Cancel) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setCallback(java.lang.String callback) {
        return (Cancel) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setFields(java.lang.String fields) {
        return (Cancel) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setKey(java.lang.String key) {
        return (Cancel) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setOauthToken(java.lang.String oauthToken) {
        return (Cancel) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Cancel) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setQuotaUser(java.lang.String quotaUser) {
        return (Cancel) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setUploadType(java.lang.String uploadType) {
        return (Cancel) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel setUploadProtocol(java.lang.String uploadProtocol) {
        return (Cancel) super.setUploadProtocol(uploadProtocol);
      }

      /** The name of the operation resource to be cancelled. */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** The name of the operation resource to be cancelled.
       */
      public java.lang.String getName() {
        return name;
      }

      /** The name of the operation resource to be cancelled. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public Cancel setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
        this.name = name;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Cancel set(String parameterName, Object value) {
        return (Cancel) super.set(parameterName, value);
      }
    }
    /**
     * Deletes a long-running operation. This method indicates that the client is no longer interested
     * in the operation result. It does not cancel the operation. If the server doesn't support this
     * method, it returns `google.rpc.Code.UNIMPLEMENTED`.
     *
     * Create a request for the method "operations.delete".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param name The name of the operation resource to be deleted.
     * @return the request
     */
    public Delete delete(java.lang.String name) throws java.io.IOException {
      Delete result = new Delete(name);
      initialize(result);
      return result;
    }

    public class Delete extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Empty> {

      private static final String REST_PATH = "v1/{+name}";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^operations/.*$");

      /**
       * Deletes a long-running operation. This method indicates that the client is no longer interested
       * in the operation result. It does not cancel the operation. If the server doesn't support this
       * method, it returns `google.rpc.Code.UNIMPLEMENTED`.
       *
       * Create a request for the method "operations.delete".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link
       * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param name The name of the operation resource to be deleted.
       * @since 1.13
       */
      protected Delete(java.lang.String name) {
        super(AdsDataHub.this, "DELETE", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.Empty.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete set$Xgafv(java.lang.String $Xgafv) {
        return (Delete) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setAccessToken(java.lang.String accessToken) {
        return (Delete) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setAlt(java.lang.String alt) {
        return (Delete) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setCallback(java.lang.String callback) {
        return (Delete) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setFields(java.lang.String fields) {
        return (Delete) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setKey(java.lang.String key) {
        return (Delete) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setOauthToken(java.lang.String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setQuotaUser(java.lang.String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setUploadType(java.lang.String uploadType) {
        return (Delete) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete setUploadProtocol(java.lang.String uploadProtocol) {
        return (Delete) super.setUploadProtocol(uploadProtocol);
      }

      /** The name of the operation resource to be deleted. */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** The name of the operation resource to be deleted.
       */
      public java.lang.String getName() {
        return name;
      }

      /** The name of the operation resource to be deleted. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public Delete setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
        this.name = name;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Delete set(String parameterName, Object value) {
        return (Delete) super.set(parameterName, value);
      }
    }
    /**
     * Gets the latest state of a long-running operation. Clients can use this method to poll the
     * operation result at intervals as recommended by the API service.
     *
     * Create a request for the method "operations.get".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param name The name of the operation resource.
     * @return the request
     */
    public Get get(java.lang.String name) throws java.io.IOException {
      Get result = new Get(name);
      initialize(result);
      return result;
    }

    public class Get extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+name}";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^operations/.*$");

      /**
       * Gets the latest state of a long-running operation. Clients can use this method to poll the
       * operation result at intervals as recommended by the API service.
       *
       * Create a request for the method "operations.get".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param name The name of the operation resource.
       * @since 1.13
       */
      protected Get(java.lang.String name) {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get set$Xgafv(java.lang.String $Xgafv) {
        return (Get) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setAccessToken(java.lang.String accessToken) {
        return (Get) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setCallback(java.lang.String callback) {
        return (Get) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setUploadType(java.lang.String uploadType) {
        return (Get) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get setUploadProtocol(java.lang.String uploadProtocol) {
        return (Get) super.setUploadProtocol(uploadProtocol);
      }

      /** The name of the operation resource. */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** The name of the operation resource.
       */
      public java.lang.String getName() {
        return name;
      }

      /** The name of the operation resource. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public Get setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
        this.name = name;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Lists operations that match the specified filter in the request. If the server doesn't support
     * this method, it returns `UNIMPLEMENTED`. NOTE: the `name` binding allows API services to override
     * the binding to use different resource name schemes, such as `users/operations`. To override the
     * binding, API services can add a binding such as `"/v1/{name=users}/operations"` to their service
     * configuration. For backwards compatibility, the default name includes the operations collection
     * id, however overriding users must ensure the name binding is the parent resource, without the
     * operations collection id.
     *
     * Create a request for the method "operations.list".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param name The name of the operation's parent resource.
     * @return the request
     */
    public List list(java.lang.String name) throws java.io.IOException {
      List result = new List(name);
      initialize(result);
      return result;
    }

    public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListOperationsResponse> {

      private static final String REST_PATH = "v1/{+name}";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^operations$");

      /**
       * Lists operations that match the specified filter in the request. If the server doesn't support
       * this method, it returns `UNIMPLEMENTED`. NOTE: the `name` binding allows API services to
       * override the binding to use different resource name schemes, such as `users/operations`. To
       * override the binding, API services can add a binding such as `"/v1/{name=users}/operations"` to
       * their service configuration. For backwards compatibility, the default name includes the
       * operations collection id, however overriding users must ensure the name binding is the parent
       * resource, without the operations collection id.
       *
       * Create a request for the method "operations.list".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param name The name of the operation's parent resource.
       * @since 1.13
       */
      protected List(java.lang.String name) {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListOperationsResponse.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations$");
        }
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List set$Xgafv(java.lang.String $Xgafv) {
        return (List) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setAccessToken(java.lang.String accessToken) {
        return (List) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setCallback(java.lang.String callback) {
        return (List) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setUploadType(java.lang.String uploadType) {
        return (List) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setUploadProtocol(java.lang.String uploadProtocol) {
        return (List) super.setUploadProtocol(uploadProtocol);
      }

      /** The name of the operation's parent resource. */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** The name of the operation's parent resource.
       */
      public java.lang.String getName() {
        return name;
      }

      /** The name of the operation's parent resource. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations$");
        }
        this.name = name;
        return this;
      }

      /** The standard list filter. */
      @com.google.api.client.util.Key
      private java.lang.String filter;

      /** The standard list filter.
       */
      public java.lang.String getFilter() {
        return filter;
      }

      /** The standard list filter. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setFilter(java.lang.String filter) {
        this.filter = filter;
        return this;
      }

      /** The standard list page size. */
      @com.google.api.client.util.Key
      private java.lang.Integer pageSize;

      /** The standard list page size.
       */
      public java.lang.Integer getPageSize() {
        return pageSize;
      }

      /** The standard list page size. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setPageSize(java.lang.Integer pageSize) {
        this.pageSize = pageSize;
        return this;
      }

      /** The standard list page token. */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** The standard list page token.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** The standard list page token. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }
    /**
     * Waits until the specified long-running operation is done or reaches at most a specified timeout,
     * returning the latest state. If the operation is already done, the latest state is immediately
     * returned. If the timeout specified is greater than the default HTTP/RPC timeout, the HTTP/RPC
     * timeout is used. If the server does not support this method, it returns
     * `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return
     * the latest state before the specified timeout (including immediately), meaning even an immediate
     * response is no guarantee that the operation is done.
     *
     * Create a request for the method "operations.wait".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link Wait#execute()} method to invoke the remote operation.
     *
     * @param name The name of the operation resource to wait on.
     * @param content the {@link com.google.api.services.adsdatahub.v1.model.WaitOperationRequest}
     * @return the request
     */
    public Wait wait(java.lang.String name, com.google.api.services.adsdatahub.v1.model.WaitOperationRequest content) throws java.io.IOException {
      Wait result = new Wait(name, content);
      initialize(result);
      return result;
    }

    public class Wait extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.Operation> {

      private static final String REST_PATH = "v1/{+name}:wait";

      private final java.util.regex.Pattern NAME_PATTERN =
          java.util.regex.Pattern.compile("^operations/.*$");

      /**
       * Waits until the specified long-running operation is done or reaches at most a specified
       * timeout, returning the latest state. If the operation is already done, the latest state is
       * immediately returned. If the timeout specified is greater than the default HTTP/RPC timeout,
       * the HTTP/RPC timeout is used. If the server does not support this method, it returns
       * `google.rpc.Code.UNIMPLEMENTED`. Note that this method is on a best-effort basis. It may return
       * the latest state before the specified timeout (including immediately), meaning even an
       * immediate response is no guarantee that the operation is done.
       *
       * Create a request for the method "operations.wait".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link Wait#execute()} method to invoke the remote operation. <p>
       * {@link Wait#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param name The name of the operation resource to wait on.
       * @param content the {@link com.google.api.services.adsdatahub.v1.model.WaitOperationRequest}
       * @since 1.13
       */
      protected Wait(java.lang.String name, com.google.api.services.adsdatahub.v1.model.WaitOperationRequest content) {
        super(AdsDataHub.this, "POST", REST_PATH, content, com.google.api.services.adsdatahub.v1.model.Operation.class);
        this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait set$Xgafv(java.lang.String $Xgafv) {
        return (Wait) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setAccessToken(java.lang.String accessToken) {
        return (Wait) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setAlt(java.lang.String alt) {
        return (Wait) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setCallback(java.lang.String callback) {
        return (Wait) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setFields(java.lang.String fields) {
        return (Wait) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setKey(java.lang.String key) {
        return (Wait) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setOauthToken(java.lang.String oauthToken) {
        return (Wait) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Wait) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setQuotaUser(java.lang.String quotaUser) {
        return (Wait) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setUploadType(java.lang.String uploadType) {
        return (Wait) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait setUploadProtocol(java.lang.String uploadProtocol) {
        return (Wait) super.setUploadProtocol(uploadProtocol);
      }

      /** The name of the operation resource to wait on. */
      @com.google.api.client.util.Key
      private java.lang.String name;

      /** The name of the operation resource to wait on.
       */
      public java.lang.String getName() {
        return name;
      }

      /** The name of the operation resource to wait on. */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public Wait setName(java.lang.String name) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
              "Parameter name must conform to the pattern " +
              "^operations/.*$");
        }
        this.name = name;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public Wait set(String parameterName, Object value) {
        return (Wait) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Outages collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdsDataHub adsdatahub = new AdsDataHub(...);}
   *   {@code AdsDataHub.Outages.List request = adsdatahub.outages().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Outages outages() {
    return new Outages();
  }

  /**
   * The "outages" collection of methods.
   */
  public class Outages {

    /**
     * Lists the outages in descending order of outage start timestamp, and the look back window is 130
     * days.
     *
     * Create a request for the method "outages.list".
     *
     * This request holds the parameters needed by the adsdatahub server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdsDataHubRequest<com.google.api.services.adsdatahub.v1.model.ListOutagesResponse> {

      private static final String REST_PATH = "v1/outages";

      /**
       * Lists the outages in descending order of outage start timestamp, and the look back window is
       * 130 days.
       *
       * Create a request for the method "outages.list".
       *
       * This request holds the parameters needed by the the adsdatahub server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdsDataHub.this, "GET", REST_PATH, null, com.google.api.services.adsdatahub.v1.model.ListOutagesResponse.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List set$Xgafv(java.lang.String $Xgafv) {
        return (List) super.set$Xgafv($Xgafv);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setAccessToken(java.lang.String accessToken) {
        return (List) super.setAccessToken(accessToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setCallback(java.lang.String callback) {
        return (List) super.setCallback(callback);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setUploadType(java.lang.String uploadType) {
        return (List) super.setUploadType(uploadType);
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List setUploadProtocol(java.lang.String uploadProtocol) {
        return (List) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Maximum number of items to return. If 0, The server will determine the number of outages to
       * return.
       */
      @com.google.api.client.util.Key
      private java.lang.Integer pageSize;

      /** Maximum number of items to return. If 0, The server will determine the number of outages to return.
       */
      public java.lang.Integer getPageSize() {
        return pageSize;
      }

      /**
       * Maximum number of items to return. If 0, The server will determine the number of outages to
       * return.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setPageSize(java.lang.Integer pageSize) {
        this.pageSize = pageSize;
        return this;
      }

      /**
       * Page token, returned by a previous call, used to request the next page of results, if any.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** Page token, returned by a previous call, used to request the next page of results, if any.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * Page token, returned by a previous call, used to request the next page of results, if any.
       */
      @com.google.errorprone.annotations.CanIgnoreReturnValue
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      @com.google.errorprone.annotations.CanIgnoreReturnValue
      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * Builder for {@link AdsDataHub}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
      setBatchPath(DEFAULT_BATCH_PATH);
    }

    /** Builds a new instance of {@link AdsDataHub}. */
    @Override
    public AdsDataHub build() {
      return new AdsDataHub(this);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setBatchPath(String batchPath) {
      return (Builder) super.setBatchPath(batchPath);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link AdsDataHubRequestInitializer}.
     *
     * @since 1.12
     */
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setAdsDataHubRequestInitializer(
        AdsDataHubRequestInitializer adsdatahubRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(adsdatahubRequestInitializer);
    }

    @Override
    @com.google.errorprone.annotations.CanIgnoreReturnValue
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
